<?php
/*
Plugin Name: CMB2 Field Type: Google Maps
Plugin URI: https://github.com/mustardBees/cmb_field_map
GitHub Plugin URI: https://github.com/mustardBees/cmb_field_map
Description: Google Maps field type for CMB2.
Version: 2.2.0
Author: Phil Wylie
Author URI: https://www.philwylie.co.uk/
License: GPLv2+
*/

/**
 * Class PW_CMB2_Field_Google_Maps.
 */
class PW_CMB2_Field_Google_Maps {

	/**
	 * Current version number.
	 */
	const VERSION = '2.2.0';

	/**
	 * Initialize the plugin by hooking into CMB2.
	 */
	public function __construct() {
		add_filter( 'cmb2_render_pw_map', array( $this, 'render_pw_map' ), 10, 5 );
		add_filter( 'cmb2_sanitize_pw_map', array( $this, 'sanitize_pw_map' ), 10, 4 );
		add_filter( 'pw_google_api_key', array( $this, 'google_api_key_constant' ) );
	}

	/**
	 * Render field.
	 */
	public function render_pw_map( $field, $field_escaped_value, $field_object_id, $field_object_type, $field_type_object ) {

		// Get the Google API key from the field's parameters.
		$api_key = $field->args( 'api_key' );

		// Allow a custom hook to specify the key.
		$api_key = apply_filters( 'pw_google_api_key', $api_key );
        
        
          
          global $jws_option;

        
         if ( isset( $jws_option['google_api'] ) && '' !== $jws_option['google_api'] ) {
           
        		$api_key =  $jws_option['google_api'];
                
        	} else {
        
        		$api_key = '';
          }

        

		$this->setup_admin_scripts( $api_key );
        
        $location = get_post_meta( get_the_ID(), $field->args('_name'), true );
        
 
        $address = '';
        $lat = '';
        $long = '';
       
        if(isset($location) && !empty($location)) {
           $address = $location;

          
           $array = array();
           
           if(function_exists('jws_get_contents')) {
             $geo = jws_get_contents('https://maps.googleapis.com/maps/api/geocode/json?key='.$api_key.'&address='.urlencode($address).'&sensor=false');
		   }else {
		      $geo = ''; 
		   }
   
           // We convert the JSON to an array
           $geo = json_decode($geo, true);
           
          
        
           // If everything is cool
           if ($geo['status'] = 'OK') {
              $lat = $geo['results'][0]['geometry']['location']['lat'];
              $long = $geo['results'][0]['geometry']['location']['lng'];
           }    
        }
        
        
        
		echo '<input type="text" value="'.$address.'" class="large-text pw-map-search" id="' . $field->args( 'id' ) . '" />';
       
        echo '<input class="pw-map-latitude" type="hidden" value="'.$lat.'" />';
        echo '<input class="pw-map-longitude" type="hidden" value="'.$long.'" />';
		echo '<div class="pw-map"></div>';

		$field_type_object->_desc( true, true );


        echo ''.$field_type_object->input( array(
			'type'       => 'hidden',
			'name'       => $field->args('_name'),
			'value'      => isset( $field_escaped_value ) ? $field_escaped_value: '',
			'class'      => 'pw-map-address',
			'desc'       => '',
		));
	}

	/**
	 * Optionally save the latitude/longitude values into two custom fields.
	 */
	public function sanitize_pw_map( $override_value, $value, $object_id, $field_args ) {
		if ( isset( $field_args['split_values'] ) && $field_args['split_values'] ) {

            if ( ! empty( $value ) ) {
				update_post_meta( $object_id, $field_args['id'], $value );
			}
		}

		return $value;
	}

	/**
	 * Enqueue scripts and styles.
	 */
	public function setup_admin_scripts($api_key) {
		wp_register_script( 'pw-google-maps-api', "https://maps.googleapis.com/maps/api/js?key={$api_key}&libraries=places&language=en", null, null );
        wp_enqueue_script( 'cmb2-map', JWS_URI_PATH. '/inc/admin/cmb2/js/script.js', array('pw-google-maps-api'), '', true );
	}

	/**
	 * Default filter to return a Google API key constant if defined.
	 */
	public function google_api_key_constant( $google_api_key = null ) {

		// Allow the field's 'api_key' parameter or a custom hook to take precedence.
		if ( ! empty( $google_api_key ) ) {
			return $google_api_key;
		}

		if ( defined( 'PW_GOOGLE_API_KEY' ) ) {
			$google_api_key = PW_GOOGLE_API_KEY;
		}

		return $google_api_key;
	}
}
$pw_cmb2_field_google_maps = new PW_CMB2_Field_Google_Maps();