<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if (!class_exists('Redux')) {
    return;
}


// This is your option name where all the Redux data is stored.
$opt_name = "jws_option";

// This line is only for altering the demo. Can be easily removed.
$opt_name = apply_filters('jws_option/opt_name', $opt_name);

/*
 *
 * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
 *
 */

$sampleHTML = '';
if (file_exists(dirname(__FILE__) . '/info-html.html')) {
    Redux_Functions::initWpFilesystem();

    global $wp_filesystem;

    $sampleHTML = $wp_filesystem->get_contents(dirname(__FILE__) . '/info-html.html');
}

// Background Patterns Reader
$sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
$sample_patterns_url = ReduxFramework::$_url . '../sample/patterns/';
$sample_patterns = array();

if (is_dir($sample_patterns_path)) {

    if ($sample_patterns_dir = opendir($sample_patterns_path)) {
        $sample_patterns = array();

        while (($sample_patterns_file = readdir($sample_patterns_dir)) !== false) {

            if (stristr($sample_patterns_file, '.png') !== false || stristr($sample_patterns_file, '.jpg') !== false) {
                $name = explode('.', $sample_patterns_file);
                $name = str_replace('.' . end($name), '', $sample_patterns_file);
                $sample_patterns[] = array(
                    'alt' => $name,
                    'img' => $sample_patterns_url . $sample_patterns_file
                );
            }
        }
    }
}

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name' => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version' => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type' => 'menu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => true,
    // Show the sections below the admin menu item or not
    'menu_title' => esc_html__('Theme Setting', 'netfx'),
    'page_title' => esc_html__('Theme Setting', 'netfx'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key' => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography' => false,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar' => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon' => 'dashicons-portfolio',
    // Choose an icon for the admin bar menu
    'admin_bar_priority' => 50,
    // Choose an priority for the admin bar menu
    'global_variable' => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode' => false,
    // Show the time the page took to load, etc
    'update_notice' => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

    // OPTIONAL -> Give you extra features
    'page_priority' => null,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent' => 'themes.php',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions' => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon' => '',
    // Specify a custom URL to an icon
    'last_tab' => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon' => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug' => 'jws_option',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults' => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show' => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark' => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => true,
    // Shows the Import/Export panel when not used as a field.
    'show_options_object' => false,
    // CAREFUL -> These options are for advanced use only
    'transient_time' => 60 * MINUTE_IN_SECONDS,
    'output' => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database' => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn' => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints' => array(
        'icon' => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color' => 'lightgray',
        'icon_size' => 'normal',
        'tip_style' => array(
            'color' => 'red',
            'shadow' => true,
            'rounded' => false,
            'style' => '',
        ),
        'tip_position' => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect' => array(
            'show' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'mouseover',
            ),
            'hide' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'click mouseleave',
            ),
        ),
    )
);

// ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
$args['admin_bar_links'][] = array(
    'id' => 'redux-docs',
    'href' => 'http://docs.reduxframework.com/',
    'title' => esc_html__('Documentation', 'netfx'),
);

$args['admin_bar_links'][] = array(
    //'id'    => 'redux-support',
    'href' => 'https://github.com/ReduxFramework/redux-framework/issues',
    'title' => esc_html__('Support', 'netfx'),
);

$args['admin_bar_links'][] = array(
    'id' => 'redux-extensions',
    'href' => 'reduxframework.com/extensions',
    'title' => esc_html__('Extensions', 'netfx'),
);

// SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
$args['share_icons'][] = array(
    'url' => 'https://github.com/ReduxFramework/ReduxFramework',
    'title' => 'Visit us on GitHub',
    'icon' => 'el el-github'
    //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
);
$args['share_icons'][] = array(
    'url' => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
    'title' => 'Like us on Facebook',
    'icon' => 'el el-facebook'
);
$args['share_icons'][] = array(
    'url' => 'http://twitter.com/reduxframework',
    'title' => 'Follow us on Twitter',
    'icon' => 'el el-twitter'
);
$args['share_icons'][] = array(
    'url' => 'http://www.linkedin.com/company/redux-framework',
    'title' => 'Find us on LinkedIn',
    'icon' => 'el el-linkedin'
);



Redux::setArgs($opt_name, $args);

/*
 * ---> END ARGUMENTS
 */


/*
 * ---> START HELP TABS
 */

$tabs = array(
    array(
        'id' => 'redux-help-tab-1',
        'title' => esc_html__('Theme Information 1', 'netfx'),
        'content' => esc_html__('<p>This is the tab content, HTML is allowed.</p>', 'netfx')
    ),
    array(
        'id' => 'redux-help-tab-2',
        'title' => esc_html__('Theme Information 2', 'netfx'),
        'content' => esc_html__('<p>This is the tab content, HTML is allowed.</p>', 'netfx')
    )
);
Redux::setHelpTab($opt_name, $tabs);

// Set the help sidebar
$content = esc_html__('<p>This is the sidebar content, HTML is allowed.</p>', 'netfx');
Redux::setHelpSidebar($opt_name, $content);


// -> START 
Redux::setSection($opt_name, array(
    'title' => esc_html__('General', 'netfx'),
    'id' => 'general',
    'customizer_width' => '300px',
    'icon' => 'el el-wrench',
    'fields' => array(
        array(
            'id'        => 'favicon',
            'type'      => 'media',
            'url'       => true,
            'title'     => esc_html__('Favicon', 'netfx' ),
            'compiler'  => 'false',
            'subtitle'  => esc_html__('Upload your favicon', 'netfx' ),
        ),
        array(
            'id'       => 'loading',
            'type'     => 'switch', 
            'title'    => esc_html__('Loading Page', 'netfx'),
            'default'  => true,
        ),
        array(
            'id'       => 'less',
            'type'     => 'switch', 
            'title'    => esc_html__('Less To Css', 'netfx'),
            'default'  => false,
        ),
        array(
            'id'        => 'logo',
            'type'      => 'media',
            'url'       => true,
            'title'     => esc_html__('Logo', 'netfx' ),
            'compiler'  => 'false',
            'subtitle'  => esc_html__('Upload your logo', 'netfx' ),
        ),
        array(
            'id' => 'logo_text',
            'type' => 'text',
            'title' => esc_html__('Logo Text', 'netfx'),
        ),
        array(
            'id'       => 'loading',
            'type'     => 'switch', 
            'title'    => esc_html__('Loading Page', 'netfx'),
            'default'  => true,
        ),
        array(
            'id'        => 'logo_loading',
            'type'      => 'media',
            'url'       => true,
            'title'     => esc_html__('Logo Loading', 'netfx' ),
            'compiler'  => 'false',
            'subtitle'  => esc_html__('Upload your logo loading', 'netfx' ),
            'required' => array('loading', '=', true),
            
        ),
         array(
            'id' => 'logo_text_loading',
            'type' => 'text',
            'title' => esc_html__('Logo Text Loading', 'netfx'),
        ),
         array(
            'id'        => 'logo_canvas',
            'type'      => 'media',
            'url'       => true,
            'title'     => esc_html__('Show logo on canvas', 'netfx' ),
            'compiler'  => 'false',
            'subtitle'  => esc_html__('Show logo on canvas', 'netfx' ),
        ),
        array(
            'id'       => 'show_cursor_animation',
            'type'     => 'switch', 
            'title'    => esc_html__('Switch On Popup', 'netfx'),
            'subtitle' => esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => false,
        ),
         array(
            'id'        => 'empty_image',
            'type'      => 'media',
            'url'       => true,
            'title'     => esc_html__('Empty Image', 'netfx' ),
            'compiler'  => 'false',
            'subtitle'  => esc_html__('Show the empty image when blog or product no image', 'netfx' ),
        ),
        array(
            'id'       => 'to-top-layout',
            'type'     => 'select',
            'title'    =>  esc_html__('Select Back To Top Skins', 'netfx'), 
            'options'  => array(
                'with-shadow' => 'With Shadow',
                'with-mancolor' => 'With Main Color',
            ),
            'default'  => 'with-shadow',
        ),
        array(
            'id' => 'to-top-color',
            'type' => 'color',
            'title' => esc_html__('Color', 'netfx'),
            'default' => '#333333',
            'output' => array('.backToTop'),
        ),
    )
));
// -> START API Fields
Redux::setSection($opt_name, array(
    'title' => esc_html__('API And Other Setting', 'netfx'),
    'id' => 'api',
    'customizer_width' => '300px',
    'icon' => 'el el-cogs',
    'fields' => array(
        array(
            'id' => 'google_api',
            'type' => 'text',
            'title' => esc_html__('Google API', 'netfx'),
            'default' => '',
        ),
        array(
            'id' => 'link_verify_email',
            'type' => 'text',
            'default' => 'http://netfx.jwsuperthemes.com/verify-mail',
            'title' => esc_html__('Link verify email', 'netfx'),
        ),
        array(
            'id' => 'login_form_redirect',
            'type' => 'text',
            'default' => 'http://netfx.jwsuperthemes.com/my-account',
            'title' => esc_html__('Login form redirect', 'netfx'),
        ),
        array(
            'id' => 'website_name',
            'type' => 'text',
            'default' => 'netfx',
            'title' => esc_html__('Name of your Website', 'netfx'),
            'subtitle' => esc_html__('Use this name to show when send mail verify account', 'netfx'),
        ),
        array(
            'id' => 'text_share',
            'type' => 'text',
            'default' => 'Share',
            'title' => esc_html__('Text Share', 'netfx'),
            'subtitle' => esc_html__('Use this text to show in share function in blogs, products', 'netfx'),
        ),
    )
));

// -> START Header Fields
Redux::setSection($opt_name, array(
    'title' => esc_html__('Header', 'netfx'),
    'id' => 'header',
    'desc' => esc_html__('Custom Header', 'netfx'),
    'customizer_width' => '400px',
    'icon' => 'el el-credit-card',
    'fields' => array(
          array(
                'id'       => 'header_absolute',
                'type'     => 'switch', 
                'title'    => esc_html__('Header Absolute', 'netfx'),
                'default'  => false,
         ),
         array(
            'id' => 'select-header',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for header', 'netfx'),
            'desc' => esc_html__('Select layout for header from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
        ),
        array(
            'id' => 'select-header-mb1',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for header mobile', 'netfx'),
            'desc' => esc_html__('Select layout for header mobile from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
        ),
           array(
            'id'       => 'header_topbar_slider_option',
            'type'     => 'switch', 
            'title'    => esc_html__('Show Topbar Slider', 'netfx'),
            'default'  => false,
        ),
       array(
            'id'          => 'header_topbar_slider',
            'type'        => 'slides',
            'title'       => esc_html__('Header Topbar Slider', 'netfx'),
            
            'placeholder' => array(
                'title'           => esc_html__('Free shipping on all orders over $50 USD. Free returns within 30 days.', 'netfx'),

            ),
        ),
        array(
            'id' => 'topbar_text',
            'type' => 'typography',
            'subtitle' => esc_html__('Font', 'netfx'),
            'title' => esc_html__('Font text', 'netfx'),
            'google' => true,
            'default' => array(
                'font-size' => '13px',
                'font-family' => 'DM Sans',
                'font-weight' => '400',
                'line-height' => '60px'
            ),
             'output' => array('.top-header-slider .slider-listing-items .top-header-title'),
        ),
        array(         
            'id'       => 'bg_topbar',
            'type'     => 'background',
            'title'    => esc_html__('Background', 'netfx'),
            'subtitle' => esc_html__('background with image, color, etc.', 'netfx'),
            'desc'     => esc_html__('This is the description field, again good for additional info.', 'netfx'),
            'default'  => array(
                'background-color' => '#112164',
            ),
            'output' => array('.top-header-slider'),
        ),
        array(
            'id' => 'icon_close',
            'type' => 'color',
            'title' => esc_html__('Icon close color', 'netfx'),
            'default' => '#ffffff',
            'output' => array('.top-header-slider .close-header-top'),
        ),
    )
));

// -> START Title Bar Fields
Redux::setSection($opt_name, array(
    'title' => esc_html__('Title Bar', 'netfx'),
    'id' => 'title_bar',
    'desc' => esc_html__('Custom title bar', 'netfx'),
    'customizer_width' => '400px',
    'icon' => 'el el-file-edit',
    'fields' => array(
        array(
            'id'       => 'title-bar-switch',
            'type'     => 'switch', 
            'title'    => esc_html__('Switch On Title Bar', 'netfx'),
            'subtitle' => esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id' => 'title_bar_type',
            'type' => 'select',
            'title' => esc_html__('Title Bar Type', 'netfx'),
            'options' => array(
                'standard' => 'Standard',
                '6' => 'Title Left and Breakscumb Right'
               
                
            ),
            'default' => '3',
        ),
        array(         
            'id'       => 'bg_titlebar',
            'type'     => 'background',
            'title'    => esc_html__('Background', 'netfx'),
            'subtitle' => esc_html__('background with image, color, etc.', 'netfx'),
            'desc'     => esc_html__('This is the description field, again good for additional info.', 'netfx'),
            'default'  => array(
                'background-color' => '#f5f5f5',
            ),
            'output' => array('.jws-title-bar-wrap'),
        ),
        array(
            'id' => 'sub_title',
            'type' => 'text',
            'title' => esc_html__('Subtitle', 'netfx'),
            'default' => 'What we believe. The truth about clean beauty.',
        ),
         array(
            'id'       => 'show-breadcrumbs',
            'type'     => 'switch', 
            'title'    => esc_html__('Switch On breadcrumbs', 'netfx'),
            'subtitle' => esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id'             => 'titlebar-spacing',
            'type'           => 'spacing',
            'output'         => array('.jws-title-bar-wrap'),
            'mode'           => 'padding',
            'units'          => array('em', 'px', '%'),
            'units_extended' => 'false',
            'desc'           => esc_html__('You can enable or disable any piece of this field. Top, Right, Bottom, Left, or Units.', 'netfx'),
            'default'            => array(
                'padding-top'     => '5%', 
                'padding-right'   => '', 
                'padding-bottom'  => '5%', 
                'padding-left'    => '',
                'units'          => '%', 
         ),
        
    ),
)));

// -> START footer Fields
Redux::setSection($opt_name, array(
    'title' => esc_html__('Footer', 'netfx'),
    'id' => 'footer',
    'desc' => esc_html__('Custom Footer', 'netfx'),
    'customizer_width' => '400px',
    'icon' => 'el el-credit-card',
    'fields' => array(
        array(
            'id' => 'select-footer',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for footer', 'netfx'),
            'desc' => esc_html__('Select layout for footer from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
        ),
    )
));

// -> START Color Fields
Redux::setSection($opt_name, array(
    'title' => esc_html__('Color Styling', 'netfx'),
    'id' => 'global-color',
    'desc' => esc_html__('These are really color fields!', 'netfx'),
    'customizer_width' => '400px',
    'icon' => 'el el-adjust'
));
Redux::setSection($opt_name, array(
    'title' => esc_html__('Color', 'netfx'),
    'id' => 'color-styling',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'primary_color',
            'type' => 'color',
            'title' => esc_html__('Primary Color', 'netfx'),
            'default' => '#112164',
        ),
        array(
            'id' => 'secondary_color',
            'type' => 'color',
            'title' => esc_html__('Secondary Color', 'netfx'),
            'default' => '#4ddffd',
        ),
        array(
            'id' => 'text_color',
            'type' => 'color',
            'title' => esc_html__('Secondary Color', 'netfx'),
            'default' => '#73729a',
        ),
        array(
            'id' => 'accent_color',
            'type' => 'color',
            'title' => esc_html__('Accent Color', 'netfx'),
            'default' => '#0d99e5',
        ),
        array(
            'id' => 'primary_button_color_text',
            'type' => 'color',
            'title' => esc_html__('Primary Button color text', 'netfx'),
            'default' => '#112164',
        ),
        array(
            'id' => 'primary_button_color_text_hover',
            'type' => 'color',
            'title' => esc_html__('Primary Button color text hover', 'netfx'),
            'default' => '#112164',
        ),
        array(
            'id' => 'primary_button_background',
            'type' => 'color',
            'title' => esc_html__('Primary Button background color', 'netfx'),
            'default' => '#112164',
        ),
        array(
            'id' => 'primary_button_background_hover',
            'type' => 'color',
            'title' => esc_html__('Primary Button background color hover', 'netfx'),
            'default' => '#112164',
        ),
        array(
            'id' => 'secondary_button_color_text',
            'type' => 'color',
            'title' => esc_html__('Secondary Button color text', 'netfx'),
            'default' => '#112164',
        ),
        array(
            'id' => 'secondary_button_color_text_hover',
            'type' => 'color',
            'title' => esc_html__('Secondary Button color text hover', 'netfx'),
            'default' => '#112164',
        ),
        array(
            'id' => 'secondary_button_background',
            'type' => 'color',
            'title' => esc_html__('Secondary Button background color', 'netfx'),
            'default' => '#112164',
        ),
        array(
            'id' => 'secondary_button_background_hover',
            'type' => 'color',
            'title' => esc_html__('Secondary Button background color hover', 'netfx'),
            'default' => '#112164',
        ),
        array(
            'id' => 'menu_color',
            'type' => 'color',
            'title' => esc_html__('Menu color', 'netfx'),
            'default' => '#112164',
        ),
        array(
            'id' => 'menu_color_hover',
            'type' => 'color',
            'title' => esc_html__('Menu hover color', 'netfx'),
            'default' => '#112164',
        ),
        array(
            'id' => 'sub_menu_color',
            'type' => 'color',
            'title' => esc_html__('Sub menu color', 'netfx'),
            'default' => '#112164',
        ),
        array(
            'id' => 'sub_menu_color_hover',
            'type' => 'color',
            'title' => esc_html__('Sub menu color hover', 'netfx'),
            'default' => '#fafafa',
        ),
        array(
            'id' => 'sub_menu_background_color',
            'type' => 'color',
            'title' => esc_html__('Sub menu background color', 'netfx'),
            'default' => '#112164',
        ),
         array(
            'id' => 'special_color',
            'type' => 'color',
            'title' => esc_html__('Specail color', 'netfx'),
            'default' => '#112164',
        ),



    ),
));
// -> START shows Fields
Redux::setSection($opt_name, array(
    'title' => esc_html__('shows', 'netfx'),
    'id' => 'shows',
    'desc' => esc_html__('Select Layout For shows Single global. Default layout11', 'netfx'),
    'customizer_width' => '300px',
    'icon' => 'el el-screen-alt',
    'fields' => array(
        array(
            'id'       => 'show-title-bar-switch',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Switch On Title Bar', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id' => 'select-titlebar-shows',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select titlebar for Shows Page', 'netfx'),
            'desc' => esc_html__('Select layout for footer shop from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',     
        ),
         array(         
            'id'       => 'show_bg_titlebar',
            'type'     => 'background',
            'title'    => esc_html__('Background', 'netfx'),
            'subtitle' => esc_html__('background with image, color, etc.', 'netfx'),
            'desc'     => esc_html__('This is the description field, again good for additional info.', 'netfx'),
            'default'  => array(
                'background-color' => '#333333',
            ),
            'output' => array('body.archive.post-type-archive-shows .jws-title-bar-wrap, body.archive.tax-shows_cat .jws-title-bar-wrap'),
        ),
        array(
            'id'             => 'show-titlebar-spacing',
            'type'           => 'spacing',
            'output'         => array('body.archive.post-type-archive-shows .jws-title-bar-wrap, body.archive.tax-shows_cat .jws-title-bar-wrap'),
            'title'    => esc_html__('Padding', 'netfx'),
            'mode'           => 'padding',
            'units'          => array('em', 'px', '%'),
            'units_extended' => 'false',
            'desc'           => esc_html__('You can enable or disable any piece of this field. Top, Right, Bottom, Left, or Units.', 'netfx'),
            'default'            => array(
                'padding-top'     => '103px', 
                'padding-right'   => '', 
                'padding-bottom'  => '95px', 
                'padding-left'    => '',
                'units'          => 'px', 
         ),
         ),
         array(
            'id' => 'shows_sub_title',
            'type' => 'text',
            'title' => esc_html__('Subtitle', 'netfx'),
            'default' => 'What we believe. The truth about clean beauty.',
        ),
         array(
            'id'       => 'show-show-breadcrumbs',
            'type'     => 'switch', 
            'title'    => esc_html__('Switch On breadcrumbs', 'netfx'),
            'subtitle' => esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => false,
        ),
        array(
        'id' => 'show_display',
        'type' => 'select',
        'default' => 'grid',
        'title' => esc_html__('shows Display', 'netfx'),
        'options' => array(
               'grid' => 'Grid',
                'slider' => 'Slider',
            ),
        
        ),
        array(
            'id'       => 'show_enable_masonry',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Enable Masonsy', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id'       => 'show_enable_animation',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Enable Animation', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
        'id' => 'shows_layout',
        'type' => 'select',
        'title' => esc_html__('Blog Layout', 'netfx'),
        'options' => array(
             'layout1' => 'Layout 1',
                'layout2' => 'Layout 2',
                'layout3' => 'Layout 3',
            ),
        'default' => 'layout3',
        ),
        array(
        'id' => 'show_columns',
        'type' => 'select',
        'title' => esc_html__('Select Columns', 'netfx'),
        'options' => array(
            '12' => '1 Columns',
            '6' => '2 Columns',
            '4' => '3 Columns',
            '3' => '4 Columns',
            '20' => '5 Columns',
            '2' => '6 Columns',
            ),
        'default' => '3',
        ),
        array(
        'id' => 'show_columns_tablet',
        'type' => 'select',
        'title' => esc_html__('Select Columns Tablet', 'netfx'),
        'options' => array(
            '12' => '1 Columns',
            '6' => '2 Columns',
            '4' => '3 Columns',
            '3' => '4 Columns',
            '20' => '5 Columns',
            '2' => '6 Columns',
            ),
        'default' => '3',
        ),
        array(
        'id' => 'show_columns_mobile',
        'type' => 'select',
        'title' => esc_html__('Select Columns Mobile', 'netfx'),
        'options' => array(
            '12' => '1 Columns',
            '6' => '2 Columns',
            '4' => '3 Columns',
            '3' => '4 Columns',
            '20' => '5 Columns',
            '2' => '6 Columns',
            ),
        'default' => '3',
        ),
        array(
            'id' => 'show_position_sidebar',
            'type' => 'select',
            'title' => esc_html__('Select Position Sidebar', 'netfx'),
            'options' => array(
                'left' => 'Left',
                'right' => 'Right',
                'no_sidebar' => 'No Sidebar',
            ),
            'default' => 'right',
        ),
        array(
            'id' => 'select-sidebar-show',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for header', 'netfx'),
            'desc' => esc_html__('Select layout for header from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
            'required' => array('position_sidebar', '!=', 'no_sidebar'),
        ),
         array(
            'id'       => 'show-category',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Switch On Category', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id' => 'show_image_size',
            'type' => 'text',
            'title' => esc_html__('Blog Feature Image Size', 'netfx'),
            'default' => '476x476',
        ),
        array(
            'id' => 'show_image_gallery_list',
            'type' => 'text',
            'title' => esc_html__('Blog Gallery Image Size', 'netfx'),
            'default' => '476x476',
        ),
        array(
            'id' => 'show_per_words',
            'type' => 'text',
            'title' => esc_html__('Posts Per Words', 'netfx'),
            'default' => '23',
        ),
        array(
            'id' => 'shows_per_page',
            'type' => 'text',
            'title' => esc_html__('Posts Per Page', 'netfx'),
            'default' => '6',
        ),
        array(
            'id' => 'shows-excerpt-more',
            'type' => 'text',
            'title' => esc_html__('Excerpt More', 'netfx'),
            'default' => '...',
        ),
        array(
            'id' => 'shows-read-more-text',
            'type' => 'text',
            'title' => esc_html__('Read More Text', 'netfx'),
            'default' => 'Excerpt More',
        ),
    )
));
Redux::setSection($opt_name, array(
    'title' => esc_html__('shows Single', 'netfx'),
    'id' => 'shows-single',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'single-shows-layout',
            'type' => 'select',
            'title' => esc_html__('show Layouts', 'netfx'),
            'options' => array(
                'default' => 'Default',
                'empty_layout' => 'Empty Layout',  
            ),
            'default' => 'default',
        ),
        array(
            'id'       => 'shows-title-bar-switch',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Switch On Title Bar', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id' => 'shows-title-bar-type',
            'type' => 'select',
            'title' => esc_html__('Title Bar Type', 'netfx'),
            'options' => array(
                'type1' => 'Standard',
                'type2' => 'Title Left and Breakscumb Right'
               
                
            ),
            'default' => 'type2',
        ),
        array(         
            'id'       => 'shows-bg-titlebar',
            'type'     => 'background',
            'title'    => esc_html__('Background', 'netfx'),
            'subtitle' => esc_html__('background with image, color, etc.', 'netfx'),
            'desc'     => esc_html__('This is the description field, again good for additional info.', 'netfx'),
            'default'  => array(
                'background' => '#f5f5f5',
            ),
            'output' => array('.single-shows .jws-title-bar-wrap'),
        ),
        array(
            'id'       => 'shows-sticky-content',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Sticky Content', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => false,
        ),
        array(
            'id' => 'shows_sub_title',
            'type' => 'text',
            'title' => esc_html__('Subtitle', 'netfx'),
            'default' => 'What we believe. The truth about clean beauty.',
        ),
         array(
            'id'       => 'shows-show-breadcrumbs',
            'type'     => 'switch', 
            'title'    => esc_html__('Switch On breadcrumbs', 'netfx'),
            'subtitle' => esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id'             => 'shows-titlebar-spacing',
            'type'           => 'spacing',
            'output'         => array('.jws-title-bar-wrap'),
            'mode'           => 'padding',
            'units'          => array('em', 'px', '%'),
            'units_extended' => 'false',
            'desc'           => esc_html__('You can enable or disable any piece of this field. Top, Right, Bottom, Left, or Units.', 'netfx'),
            'default'            => array(
                'padding-top'     => '5%', 
                'padding-right'   => '', 
                'padding-bottom'  => '5%', 
                'padding-left'    => '',
                'units'          => '%', 
         ),
          ),
        array(
            'id' => 'select-header-shows',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for header', 'netfx'),
            'desc' => esc_html__('Select layout for header from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
        ),
        array(
                'id'       => 'header_absolute_shows',
                'type'     => 'switch', 
                'title'    =>  esc_html__('Header Absolute', 'netfx'),
                'default'  => true,
        ),
        array(
                'id'       => 'show-show-feature-image',
                'type'     => 'switch', 
                'title'    => esc_html__('Show Feature Image', 'netfx'),
                'default'  => false,
         ),
         array(
                'id'       => 'show-show-gallery-image',
                'type'     => 'switch', 
                'title'    => esc_html__('Show Gallery Image', 'netfx'),
                'default'  => true,
         ),
        array(
            'id'       => 'show_back',
            'type'     => 'text',
            'title'    =>  esc_html__('Link for buttom back', 'netfx'),
            'default'  => '#'
        ),
        array(
            'id' => 'select-before-footer',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select content before footer', 'netfx'),
            'desc' => esc_html__('Select layout from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
        ),
    
        array(
            'id' => 'select-related-shows',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for Related shows', 'netfx'),
            'desc' => esc_html__('Select layout from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
        ),
        array(
            'id'       => 'show_starring',
            'type'     => 'text',
            'title'    =>  esc_html__('Starring Label', 'netfx'),
            'default'  => 'Client:'
        ),
        array(
            'id'       => 'show_director',
            'type'     => 'text',
            'title'    =>  esc_html__('Director Label', 'netfx'),
            'default'  => 'Client:'
        ),
        array(
            'id'       => 'show_imdb',
            'type'     => 'text',
            'title'    =>  esc_html__('Imdb Label', 'netfx'),
            'default'  => 'Category:'
        ),
        array(
            'id'       => 'date_client',
            'type'     => 'text',
            'title'    =>  esc_html__('Date Label', 'netfx'),
            'default'  => 'DATE:'
        ),
    ),
));

// -> START service Fields
Redux::setSection($opt_name, array(
    'title' => esc_html__('Service', 'netfx'),
    'id' => 'service',
    'customizer_width' => '300px',
    'icon' => 'el el-qrcode',
    'fields' => array(

    )
));

Redux::setSection($opt_name, array(
    'title' => esc_html__('Service Single', 'netfx'),
    'id' => 'service-single',
    'subsection' => true,
    'fields' => array(
       array(
            'id'       => 'services-title-bar-switch',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Switch On Title Bar', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id' => 'select-titlebar-services',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select titlebar for services Page', 'netfx'),
            'desc' => esc_html__('Select layout for footer shop from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',     
        ),
         array(         
            'id'       => 'service_bg_titlebar',
            'type'     => 'background',
            'title'    => esc_html__('Background', 'netfx'),
            'subtitle' => esc_html__('background with image, color, etc.', 'netfx'),
            'desc'     => esc_html__('This is the description field, again good for additional info.', 'netfx'),
            'default'  => array(
                'background-color' => '#333333',
            ),
            'output' => array('body.archive.post-type-archive-services .jws-title-bar-wrap, body.archive.tax-services_cat .jws-title-bar-wrap'),
        ),
        array(
            'id'             => 'service-titlebar-spacing',
            'type'           => 'spacing',
            'output'         => array('body.archive.post-type-archive-services .jws-title-bar-wrap, body.archive.tax-services_cat .jws-title-bar-wrap'),
            'title'    => esc_html__('Padding', 'netfx'),
            'mode'           => 'padding',
            'units'          => array('em', 'px', '%'),
            'units_extended' => 'false',
            'desc'           => esc_html__('You can enable or disable any piece of this field. Top, Right, Bottom, Left, or Units.', 'netfx'),
            'default'            => array(
                'padding-top'     => '103px', 
                'padding-right'   => '', 
                'padding-bottom'  => '95px', 
                'padding-left'    => '',
                'units'          => 'px', 
         ),
         ),
         array(
            'id' => 'services_sub_title',
            'type' => 'text',
            'title' => esc_html__('Subtitle', 'netfx'),
            'default' => 'What we believe. The truth about clean beauty.',
        ),
         array(
            'id'       => 'service-service-breadcrumbs',
            'type'     => 'switch', 
            'title'    => esc_html__('Switch On breadcrumbs', 'netfx'),
            'subtitle' => esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => false,
        ),
         array(
            'id' => 'position_sidebar_service_single',
            'type' => 'select',
            'title' => esc_html__('Select Position Sidebar', 'netfx'),
            'options' => array(
                'left' => 'Left',
                'right' => 'Right',
                'full' => 'No Sidebar',
            ),
            'default' => 'full',
        ),
         array(
            'id' => 'select-sidebar-service-single',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for sidebar', 'netfx'),
            'desc' => esc_html__('Select layout from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
            'required' => array('position_sidebar_service_single', '!=', 'no_sidebar'),
        ),
    ),
));



// -> START Blogs Fields
Redux::setSection($opt_name, array(
    'title' => esc_html__('Blogs', 'netfx'),
    'id' => 'blogs',
    'customizer_width' => '300px',
    'icon' => 'el el-blogger',
    'fields' => array(
      array(
            'id'       => 'blog-title-bar-switch',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Switch On Title Bar', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
          array(
            'id' => 'select-titlebar-blogs',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select titlebar for Blog Page', 'netfx'),
            'desc' => esc_html__('Select layout for footer shop from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',     
        ),
         array(         
            'id'       => 'blog_bg_titlebar',
            'type'     => 'background',
            'title'    => esc_html__('Background', 'netfx'),
            'subtitle' => esc_html__('background with image, color, etc.', 'netfx'),
            'desc'     => esc_html__('This is the description field, again good for additional info.', 'netfx'),
            'default'  => array(
                'background-color' => '#333333',
            ),
            'output' => array('body.archive .jws-title-bar-wrap'),
        ),
         array(
            'id' => 'blogs_sub_title',
            'type' => 'text',
            'title' => esc_html__('Subtitle', 'netfx'),
            'default' => 'What we believe. The truth about clean beauty.',
        ),
         array(
            'id'       => 'blog-show-breadcrumbs',
            'type'     => 'switch', 
            'title'    => esc_html__('Switch On breadcrumbs', 'netfx'),
            'subtitle' => esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => false,
        ),
        array(
        'id' => 'blog_display',
        'type' => 'select',
        'default' => 'grid',
        'title' => esc_html__('Blog Display', 'netfx'),
        'options' => array(
               'grid' => 'Grid',
                'slider' => 'Slider',
            ),
        
        ),
        array(
            'id'       => 'enable_masonry',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Enable Masonsy', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id'       => 'enable_animation',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Enable Animation', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
        'id' => 'blogs_layout',
        'type' => 'select',
        'title' => esc_html__('Blog Layout', 'netfx'),
        'options' => array(
             'layout1' => 'Layout 1',
                'layout2' => 'Layout 2',
                'layout3' => 'Layout 3',
            ),
        'default' => 'layout3',
        ),
        array(
        'id' => 'blog_columns',
        'type' => 'select',
        'title' => esc_html__('Select Columns', 'netfx'),
        'options' => array(
            '12' => '1 Columns',
            '6' => '2 Columns',
            '4' => '3 Columns',
            '3' => '4 Columns',
            '20' => '5 Columns',
            '2' => '6 Columns',
            ),
        'default' => '3',
        ),
        array(
        'id' => 'blog_columns_tablet',
        'type' => 'select',
        'title' => esc_html__('Select Columns Tablet', 'netfx'),
        'options' => array(
            '12' => '1 Columns',
            '6' => '2 Columns',
            '4' => '3 Columns',
            '3' => '4 Columns',
            '20' => '5 Columns',
            '2' => '6 Columns',
            ),
        'default' => '3',
        ),
        array(
        'id' => 'blog_columns_mobile',
        'type' => 'select',
        'title' => esc_html__('Select Columns Mobile', 'netfx'),
        'options' => array(
            '12' => '1 Columns',
            '6' => '2 Columns',
            '4' => '3 Columns',
            '3' => '4 Columns',
            '20' => '5 Columns',
            '2' => '6 Columns',
            ),
        'default' => '3',
        ),
        array(
            'id' => 'position_sidebar',
            'type' => 'select',
            'title' => esc_html__('Select Position Sidebar', 'netfx'),
            'options' => array(
                'left' => 'Left',
                'right' => 'Right',
                'no_sidebar' => 'No Sidebar',
            ),
            'default' => 'right',
        ),
        array(
            'id' => 'select-sidebar-post',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for header', 'netfx'),
            'desc' => esc_html__('Select layout for header from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
            'required' => array('position_sidebar', '!=', 'no_sidebar'),
        ),
         array(
            'id'       => 'blog-category',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Switch On Category', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id'       => 'blog-time',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Switch On Time', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id'       => 'blog-author',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Switch On Author', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id'       => 'blog-title',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Switch On Title', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id'       => 'blog-decription',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Switch On Decription', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id'       => 'blog-readmore',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Switch On Read More', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(
            'id' => 'blog_image_size',
            'type' => 'text',
            'title' => esc_html__('Blog Feature Image Size', 'netfx'),
            'default' => '870x500',
        ),
        array(
            'id' => 'image_gallery_list',
            'type' => 'text',
            'title' => esc_html__('Blog Gallery Image Size', 'netfx'),
            'default' => '870x500',
        ),
        array(
            'id' => 'posts_per_words',
            'type' => 'text',
            'title' => esc_html__('Posts Per Words', 'netfx'),
            'default' => '23',
        ),
        array(
            'id' => 'posts_per_page',
            'type' => 'text',
            'title' => esc_html__('Posts Per Page', 'netfx'),
            'default' => '6',
        ),
        array(
            'id' => 'excerpt-more',
            'type' => 'text',
            'title' => esc_html__('Excerpt More', 'netfx'),
            'default' => '...',
        ),
        array(
            'id' => 'read-more-text',
            'type' => 'text',
            'title' => esc_html__('Read More Text', 'netfx'),
            'default' => 'Excerpt More',
        ),
        
    )
));
Redux::setSection($opt_name, array(
    'title' => esc_html__('Blog Single', 'netfx'),
    'id' => 'blog-single',
    'subsection' => true,
    'fields' => array(
        array(
            'id'       => 'blog-title-bar-switch',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Switch On Title Bar', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(         
            'id'       => 'single_blog_bg_titlebar',
            'type'     => 'background',
            'title'    =>esc_html__('Background', 'netfx'),
            'subtitle' =>esc_html__('background with image, color, etc.', 'netfx'),
            'desc'     =>esc_html__('This is the description field, again good for additional info.', 'netfx'),
            'default'  => array(
                'background-color' => '#333333',
            ),
            'output' => array('body.single-post .jws-title-bar-wrap'),
        ),
             array(
            'id'             => 'titlebar-spacing-blog-single',
            'type'           => 'spacing',
            'output'         => array('.single-post .jws-title-bar-wrap'),
            'mode'           => 'padding',
            'units'          => array('em', 'px', '%'),
            'units_extended' => 'false',
            'desc'           =>esc_html__('You can enable or disable any piece of this field. Top, Right, Bottom, Left, or Units.', 'netfx'),
            'default'            => array(
                 'padding-top'     => '78px', 
                'padding-right'   => '', 
                'padding-bottom'  => '92px', 
                'padding-left'    => '',
                'units'          => 'px', 
         ),
        
    ),
         array(
            'id' => 'single_blog_custom_title',
            'type' => 'text',
            'title' => esc_html__('Custom Title', 'netfx'),
            'default' => 'We love to share our experiences',
        ),
         array(
            'id' => 'single_blog_sub_title',
            'type' => 'text',
            'title' => esc_html__('Subtitle', 'netfx'),
            'default' => 'What we believe. The truth about clean beauty.',
        ),
         array(
            'id'       => 'single-blog-show-breadcrumbs',
            'type'     => 'switch', 
            'title'    =>esc_html__('Switch On breadcrumbs', 'netfx'),
            'subtitle' =>esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => false,
        ),
        array(
            'id' => 'select-titlebar-blog',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for title bar elementor', 'netfx'),
            'desc' => esc_html__('Select layout for title bar elementor from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
            'required' => array('blog-title-bar-switch', '=', true),
        ),
        array(
            'id' => 'select-header-blog',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for header', 'netfx'),
            'desc' => esc_html__('Select layout for header from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
        ),
        array(
                'id'       => 'header_absolute_blog',
                'type'     => 'switch', 
                'title'    =>  esc_html__('Header Absolute', 'netfx'),
                'default'  => true,
        ),
         array(
            'id'       => 'blog_single_layout',
            'type'     => 'select',
            'title'    =>  esc_html__('Select Single Blog Skin', 'netfx'), 
            'subtitle' =>  esc_html__('No validation can be done on this field type', 'netfx'),
            'desc'     =>  esc_html__('Choose layout for single blog (comment,meta, author box...)', 'netfx'),
            'options'  => array(
                'layout1' => 'Layout 1',
                'layout2' => 'Layout 2',
                'layout3' => 'Layout 3',
                'layout4' => 'Layout 4',
                'layout5' => 'Layout 5',
                'layout6' => 'Layout 6',
                'layout7' => 'Layout 7',
                'layout8' => 'Layout 8'
            ),
            'default'  => 'layout6',
        ),
        array(
            'id' => 'select-related-blog',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for Related Post', 'netfx'),
            'desc' => esc_html__('Select layout from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
        ),
        array(
            'id' => 'position_sidebar_blog_single',
            'type' => 'select',
            'title' => esc_html__('Select Position Sidebar', 'netfx'),
            'options' => array(
                'left' => 'Left',
                'right' => 'Right',
                'full' => 'No Sidebar',
            ),
            'default' => 'full',
        ),
         array(
            'id' => 'select-sidebar-post-single',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for sidebar', 'netfx'),
            'desc' => esc_html__('Select layout from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
            'required' => array('position_sidebar_blog_single', '!=', 'no_sidebar'),
        ),
        array(
            'id'       => 'single_blog_imagesize',
            'type'     => 'text',
            'title'    =>  esc_html__('Single Blog Image Size', 'netfx'),
            'default'  => '1170x550'
        ),
    ),
));
// -> START 404
Redux::setSection($opt_name, array(
    'title' => esc_html__('404 Page', 'netfx'),
    'id' => '404-page',
    'customizer_width' => '300px',
    'icon' => 'el el-error-alt',
    'fields' => array(
        array(
            'id'       => '404-title-bar-switch',
            'type'     => 'switch', 
            'title'    =>  esc_html__('Switch On Title Bar', 'netfx'),
            'subtitle' =>  esc_html__('Look, it\'s on!', 'netfx'),
            'default'  => true,
        ),
        array(         
            'id'       => '404_bg_titlebar',
            'type'     => 'background',
            'title'    =>esc_html__('Background', 'netfx'),
            'subtitle' =>esc_html__('background with image, color, etc.', 'netfx'),
            'desc'     =>esc_html__('This is the description field, again good for additional info.', 'netfx'),
            'default'  => array(
                'background-color' => '#333333',
            ),
            'output' => array('body.error404  .jws-title-bar-wrap'),
        ),
             array(
            'id'             => 'titlebar-spacing-404',
            'type'           => 'spacing',
            'output'         => array('.error404 .jws-title-bar-wrap'),
            'mode'           => 'padding',
            'units'          => array('em', 'px', '%'),
            'units_extended' => 'false',
            'desc'           =>esc_html__('You can enable or disable any piece of this field. Top, Right, Bottom, Left, or Units.', 'netfx'),
            'default'            => array(
                 'padding-top'     => '78px', 
                'padding-right'   => '', 
                'padding-bottom'  => '92px', 
                'padding-left'    => '',
                'units'          => 'px', 
                 ),
         ),
         array(         
            'id'       => 'bg_image_404',
            'type'     => 'background',
            'title'    =>esc_html__('Background', 'netfx'),
            'subtitle' =>esc_html__('background with image, color, etc.', 'netfx'),
            'desc'     =>esc_html__('This is the description field, again good for additional info.', 'netfx'),
            'output' => array('body.error404'),
        ),
        array(
            'id' => 'title_404',
            'type' => 'text',
            'title' => esc_html__('Title', 'netfx'),
            'default' => '404',
        ),
        array(
            'id' => 'content_404',
            'type' => 'text',
            'title' => esc_html__('Content', 'netfx'),
            'default' => 'Oops! The page you are looking for does not exist. It might have been moved or deleted.',
        ),
        array(
            'id' => 'button_text_404',
            'type' => 'text',
            'title' => esc_html__('Button Text', 'netfx'),
            'default' => 'Back to home',
        ),
        array(
            'id' => 'button_link_404',
            'type' => 'text',
            'title' => esc_html__('Button Link', 'netfx'),
        ),
    )
));

// -> START Shop
Redux::setSection($opt_name, array(
    'title' => esc_html__('Shop', 'netfx'),
    'id' => 'shop',
    'desc' => esc_html__('Select Layout For Shop Page.', 'netfx'),
    'customizer_width' => '300px',
    'icon' => 'el el-shopping-cart-sign',
));
Redux::setSection($opt_name, array(
    'title' => esc_html__('Shop Page', 'netfx'),
    'id' => 'shop_page',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'shop_max_width',
            'type'      => 'slider',
            'title' => esc_html__('Shop Max Width', 'netfx'),
             "default"   => 1710,
            "min"       => 700,
            "step"      => 10,
            "max"       => 1920,
            'display_value' => 'label'
        ),
        array(
            'id' => 'shop_type',
            'type' => 'select',
            'title' => esc_html__('Shop Type', 'netfx'),
            'options' => array(
                'grid' => 'Grid',
                'masonry' => 'Masonry',
                'metro' => 'Metro',
            ),
            'default' => 'grid',
        ),
        array(
            'id' => 'shop_layout',
            'type' => 'select',
            'title' => esc_html__('Shop Layout', 'netfx'),
            'options' => array(
                'layout1' => 'Layout 1',
                'layout2' => 'Layout 2',
                'layout3' => 'Layout 3',
                'layout_one_column' => 'Layout 4 (apply for layout one column)',
            ),
            'default' => 'layout1',
        ),

        array(
            'id' => 'shop_image_width_size',
            'type' => 'text',
            'title' => esc_html__('Shop Image Width Size', 'netfx'),
            'default' => '372',
        ),
        array(
            'id' => 'shop_image_height_size',
            'type' => 'text',
            'title' => esc_html__('Shop Image Height Size', 'netfx'),
            'default' => '463',
        ),array(
            'id' => 'shop_words_per_product',
            'type' => 'text',
            'title' => esc_html__('Shop Image Height Size', 'netfx'),
            'default' => '7',
        ),
        array(
            'id'       => 'show_shop_titlebar',
            'type'     => 'switch', 
            'title'    =>esc_html__('Show Shop Title bar', 'netfx'),
            'default'  => true,
        ),
        array(         
            'id'       => 'shop_bg_titlebar',
            'type'     => 'background',
            'title'    =>esc_html__('Background', 'netfx'),
            'subtitle' =>esc_html__('background with image, color, etc.', 'netfx'),
            'desc'     =>esc_html__('This is the description field, again good for additional info.', 'netfx'),
            'required' => array('show_shop_titlebar', '=', true),
            'default'  => array(
                'background-color' => '#333333',
            ),
            'output' => array('body.woocommerce-page .jws-title-bar-wrap'),
        ),
         array(
            'id'             => 'shows-titlebar-spacing',
            'type'           => 'spacing',
            'output'         => array('.woocommerce-page .jws-title-bar-wrap'),
            'mode'           => 'padding',
            'units'          => array('em', 'px', '%'),
            'units_extended' => 'false',
            'desc'           =>esc_html__('You can enable or disable any piece of this field. Top, Right, Bottom, Left, or Units.', 'netfx'),
            'default'            => array(
                'padding-top'     => '79px', 
                'padding-right'   => '', 
                'padding-bottom'  => '92px', 
                'padding-left'    => '',
                'units'          => 'px', 
         ),
          ),
        array(
            'id' => 'sub_title_shop',
            'type' => 'text',
            'title' => esc_html__('Sub title shop', 'netfx'),
            'default' => 'What we believe. The truth about clean beauty.',
            'required' => array('show_shop_titlebar', '=', true),
        ),
        array(
            'id'       => 'show_breadcrumbs_shop',
            'type'     => 'switch', 
            'title'    =>esc_html__('Show Breadcrumbs', 'netfx'),
            'default'  => true,
            'required' => array('show_shop_titlebar', '=', true),            
        ),
        array(
            'id' => 'shop_post_number',
            'type' => 'text',
            'title' => esc_html__('Product Per Page', 'netfx'),
            'default' => '10',
        ),
        array(
            'id' => 'shop_columns',
            'type' => 'select',
            'title' => esc_html__('Select Columns', 'netfx'),
            'options' => array(
                '12' => '1 Columns',
                '6' => '2 Columns',
                '4' => '3 Columns',
                '3' => '4 Columns',
                '20' => '5 Columns',
                '2' => '6 Columns',
               
                
            ),
            'default' => '3',
        ),
         array(
            'id' => 'shop_position_sidebar',
            'type' => 'select',
            'title' => esc_html__('Shop Sidebar', 'netfx'),
            'options' => array(
                'left' => 'Left Sidebar',
                'right' => 'Right Sidebar',
                'no_sidebar' => 'No Sidebar',
            ),
            'default' => 'left',
        ),
        array(
            'id' => 'shop_sidebar_column',
            'type' => 'select',
            'title' => esc_html__('Shop Sidebar Coulumn', 'netfx'),
            'options' => array(
                '4' => '1/3 Shop Page',
                '3' => '1/4 Shop Page',
            ),
            'default' => '3',
        ),
        array(
            'id' => 'shop_pagination',
            'type' => 'select',
            'title' => esc_html__('Shop Pagination style', 'netfx'),
            'options' => array(
                'pagination' => 'Pagination',
                'load_more' => 'Load More',
                'infinite' => 'Infinite',
                'no_pagination' => 'No Pagination'
            ),
            'default' => 'load_more',
        ),
        array(
            'id' => 'shop_bottom_banner',
            'type'     => 'switch', 
            'title' => esc_html__('Shop Bottom Banner', 'netfx'),
            'default' => false,
        ),
         array(
            'id' => 'select-bottom-banner',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for banner bottom', 'netfx'),
            'desc' => esc_html__('Select layout for footer from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
            'required' => array('shop_bottom_banner', '=', true),     
        ),
        array(
            'id' => 'select-shop-footer',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for footer shop', 'netfx'),
            'desc' => esc_html__('Select layout for footer shop from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',     
        ),
         array(
            'id' => 'shop_top_filter',
            'type'     => 'switch', 
            'title' => esc_html__('Show Top Filter', 'netfx'),
            'default' => false,
        ),
         array(
            'id' => 'show_shop_review_columns',
            'type'     => 'switch', 
            'title' => esc_html__('Show Shop Review Column', 'netfx'),
            'default' => false,
        ),
         array(
            'id' => 'show_result_count',
            'type'     => 'switch', 
            'title' => esc_html__('Show Result Count', 'netfx'),
            'default' => true,
        ),
        array(
            'id' => 'show_orderby_product',
            'type'     => 'switch', 
            'title' => esc_html__('Show Order By', 'netfx'),
            'default' => true,
        ),
        array(
                'id'       => 'shop_review_columns',
                'type'     => 'checkbox',
                'title'    =>esc_html__('Shop Review Column', 'netfx'), 
                'subtitle' =>esc_html__('No validation can be done on this field type', 'netfx'),
                'desc'     =>esc_html__('This is the description field, again good for additional info.', 'netfx'),
                'required' => array('show_shop_review_columns', '=', true),   
                //Must provide key => value pairs for multi checkbox options
                'options'  => array(
                    'column-1' => '1 Column',
                    'column-2' => '2 Columns',
                    'column-3' => '3 Columns',
                    'column-4' => '4 Columns',
                    'column-5' => '5 Columns',
                    'column-6' => '6 Columns',
                ),

            )    
         
    )
));
// -> Start Single Product
Redux::setSection($opt_name, array(
    'title' => esc_html__('Single Product Page', 'netfx'),
    'id' => 'single_product_page',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'single_product_max_width',
            'type'      => 'slider',
            'title' => esc_html__('Single Product Page Max Width', 'netfx'),
             "default"   => 1710,
            "min"       => 700,
            "step"      => 10,
            "max"       => 1920,
            'display_value' => 'label'
        ),
         array(
            'id'       => 'hero_slider',
            'type'     => 'switch', 
            'title'    =>esc_html__('Show Hero Slider', 'netfx'),
            'default'  => true,
        ),
       array(
            'id'          => 'opt-slides',
            'type'        => 'slides',
            'title'       =>esc_html__('Slides Hero Options', 'netfx'),
            'subtitle'    =>esc_html__('Unlimited slides with drag and drop sortings.', 'netfx'),
            'desc'        =>esc_html__('This field will store all slides values into a multidimensional array to use into a foreach loop.', 'netfx'),
            'placeholder' => array(
                'title'           =>esc_html__('This is a title', 'netfx'),
                'description'     =>esc_html__('Description Here', 'netfx'),
                'url'             =>esc_html__('Give us a link!', 'netfx'),
            ),
        ),
       array(
				'id'       => 'wc-single-style',
				'type'     => 'image_select',
				'class'    => 'single-layout',
				'title'    => esc_html__('Style Product Detail Layout','netfx'),
				'options'  => array(
					'layout1'    => array (
						'alt'  => 'Style 1',
						'img'  => get_template_directory_uri().'/inc/admin/assets/images/style1.jpg',
					),
					'layout2'    => array(
						'alt'  => 'Style 2',
						'img'  => get_template_directory_uri().'/inc/admin/assets/images/style2.jpg',
					),
					'layout3'    => array(
						'alt'  => 'Style 2',
						'img'  => get_template_directory_uri().'/inc/admin/assets/images/style3.jpg',
					),
					'layout4'    => array(
						'alt'  => 'Style 2',
						'img'  => get_template_directory_uri().'/inc/admin/assets/images/style4.jpg',
					),
					'layout5'    => array(
						'alt'  => 'Style 2',
						'img'  => get_template_directory_uri().'/inc/admin/assets/images/style5.jpg',
					),
					'layout6'    => array(
						'alt'  => 'Style 2',
						'img'  => get_template_directory_uri().'/inc/admin/assets/images/style6.jpg',
					)
				),
				'default'  => 'layout1',
        ),
        array(
        	'id' => 'entry_column',
        	'type' => 'select',
        	'title' => esc_html__('Entry Summary Content', 'netfx'),
        	'options' => array(
        		'5' => '5/12',
        		'7' => '7/12',
        		'4' => '1/3',
        		'6' => '6/12',
        		'3' => '1/4',
        	),
        	'default' => '5',
        ),
        array(
        'id'       => 'thumbnail_position',
        'type'     => 'select',
        'title'    =>esc_html__('Thubmnail Position', 'netfx'), 
        'subtitle' =>esc_html__('Aplly for product layout 1', 'netfx'),
        'required' => array('wc-single-style', '=', 'layout1'),   
        'options'  => array(
            	'left' => 'Left',
            	'right' => 'Right',
            	'bottom' => 'Bottom',
            ),
		),	
        array(
            'id'       => 'single_product_shop_titlebar',
            'type'     => 'switch', 
            'title'    =>esc_html__('Show Shop Title bar', 'netfx'),
            'default'  => true,
        ),
        array(         
            'id'       => 'single_product_bg_titlebar',
            'type'     => 'background',
            'title'    =>esc_html__('Background', 'netfx'),
            'subtitle' =>esc_html__('background with image, color, etc.', 'netfx'),
            'desc'     =>esc_html__('This is the description field, again good for additional info.', 'netfx'),
            'required' => array('show_shop_titlebar', '=', true),
            'default'  => array(
                'background-color' => '#333333',
            ),
            'output' => array('body.woocommerce-page .jws-title-bar-wrap'),
        ),
        array(
            'id' => 'sub_title_single_product',
            'type' => 'text',
            'title' => esc_html__('Sub title', 'netfx'),
            'default' => 'What we believe. The truth about clean beauty.',
            'required' => array('show_shop_titlebar', '=', true),
        ),
        array(
            'id'       => 'show_breadcrumbs_single_product',
            'type'     => 'switch', 
            'title'    =>esc_html__('Show Breadcrumbs', 'netfx'),
            'default'  => true,
            'required' => array('show_shop_titlebar', '=', true),            
        ),

        array(
            'id' => 'single_product_bottom_banner',
            'type'     => 'switch', 
            'title' => esc_html__('Shop Bottom Banner', 'netfx'),
            'default' => false,
        ),
        array(
            'id' => 'buy_now_button',
            'type'     => 'switch', 
            'title' => esc_html__('Show buy now button', 'netfx'),
            'default' => true,
        ),
        array(
            'id'       => 'show_recently_product_viewed',
            'type'     => 'switch', 
            'title'    =>esc_html__('Show Recently Product Viewed', 'netfx'),
            'default'  => false,
        ),
         array(
            'id' => 'select-product-page-bottom-banner',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for banner bottom', 'netfx'),
            'desc' => esc_html__('Select layout for footer from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',
            'required' => array('single_product_bottom_banner', '=', true),     
        ),
        array(
            'id' => 'select-product-page-footer',
            'type' => 'select',
            'data' => 'posts',
            'args' => array('post_type' => array('hf_template'), 'posts_per_page' => -1),
            'title' => esc_html__('Select layout for footer Product', 'netfx'),
            'desc' => esc_html__('Select layout for footer Product from: ', 'netfx') . '<a href="' . esc_url(admin_url('/edit.php?post_type=hf_template')) . '" target="_blank">Header Footer Template</a>',     
        ),
        array(
            'id'       => 'show_waitlist_form',
            'type'     => 'switch', 
            'title'    => esc_html__('Show Waitlist Email Subscribe', 'netfx'),
            'default'  => true,
        ),
        array(
            'id' => 'title_form_waitlist',
            'type' => 'text',
            'title' => esc_html__('Title Form', 'netfx'),
            'default' => 'Notify me when this product is available:',
            'required' => array('show_waitlist_form', '=', true),
        ),
         array(
            'id' => 'playholder_input_waitlist',
            'type' => 'text',
            'title' => esc_html__('Playholder Input', 'netfx'),
            'default' => 'Enter your email address...',
            'required' => array('show_waitlist_form', '=', true),
        ),
        array(
            'id' => 'submit_waitlist',
            'type' => 'text',
            'title' => esc_html__('Submit Text', 'netfx'),
            'default' => 'Send',
            'required' => array('show_waitlist_form', '=', true),
        ),
         array(
            'id' => 'successful_message',
            'type' => 'text',
            'title' => esc_html__('Successful Text', 'netfx'),
            'default' => 'You have already registered for this waiting list, we will contact to you when this product is in stock',
            'required' => array('show_waitlist_form', '=', true),
        ),
         array(
            'id' => 'fail_message',
            'type' => 'text',
            'title' => esc_html__('Empty email', 'netfx'),
            'default' => 'Please entry your email',
            'required' => array('show_waitlist_form', '=', true),
        ),
         array(
            'id' => 'registed_email_message',
            'type' => 'text',
            'title' => esc_html__('Email exsit', 'netfx'),
            'default' => 'You registered this email before, please change to another email',
            'required' => array('show_waitlist_form', '=', true),
        ),
         array(
            'id' => 'subject_waitlist_email',
            'type' => 'text',
            'title' => esc_html__('Subject Email', 'netfx'),
            'default' => 'A product you are waiting for is back in stock',
            'required' => array('show_waitlist_form', '=', true),
        ),
         array(
            'id' => 'email_heading_waitlist',
            'type' => 'text',
            'title' => esc_html__('Email heading', 'netfx'),
            'default' => '{product_title} is now back in stock on {blogname}',
            'required' => array('show_waitlist_form', '=', true),
        ),
        array(
            'id' => 'email_content_waitlist',
            'type' => 'editor',
            'title' => esc_html__('Email content', 'netfx'),
            'default' => 'Hi, {product_title} is now back in stock on {blogname}. You have been sent this email because your email address was registered in a waiting list for this product. If you would like to purchase {product_title}, please visit the following link: {product_link}',
            'required' => array('show_waitlist_form', '=', true),
        ),
   
    )
));

// -> START Typography
Redux::setSection($opt_name, array(
    'title' => esc_html__('Typography', 'netfx'),
    'id' => 'typography',
    'desc' => esc_html__('For full documentation on this field, visit: ', 'netfx') . '<a href="//docs.reduxframework.com/core/fields/typography/" target="_blank">docs.reduxframework.com/core/fields/typography/</a>',
    'icon' => 'el el-font',
    'fields' => array(
         array(
            'id' => 'font_body',
            'type' => 'typography',
            'title' => esc_html__('Body', 'netfx'),
            'subtitle' => esc_html__('Basic font.', 'netfx'),
            'google' => true,
            'default' => array(
                'font-size' => '16px',
                'font-family' => 'DM Sans',
                'font-weight' => '400',
                'line-height' => '18px'
            ),
        ),
        array(
            'id' => 'font_h1',
            'type' => 'typography',
            'subtitle' => esc_html__('H1 tag aplly for title page and title post.', 'netfx'),
            'title' => esc_html__('Font H1', 'netfx'),
            'google' => true,
            'default' => array(
                'font-size' => '60px',
                'font-family' => 'DM Sans',
                'font-weight' => '700',
                'line-height' => '69px'
            ),
        ),
        array(
            'id' => 'font_h2',
            'type' => 'typography',
            'title' => esc_html__('Font H2', 'netfx'),
            'subtitle' => esc_html__('H2 tag apply for Headding Titles in each sections.', 'netfx'),
            'google' => true,
            'default' => array(
                'font-size' => '48px',
                'font-family' => 'DM Sans',
                'font-weight' => '700',
                'line-height' => '55px'
            ),
        ),
        array(
            'id' => 'font_h3',
            'type' => 'typography',
            'title' => esc_html__('Font H3', 'netfx'),
            'subtitle' => esc_html__('H3 tag apply for Blog Title in list blog and Title in a listing.', 'netfx'),
            'google' => true,
            'default' => array(
                'font-size' => '36px',
                'font-family' => 'DM Sans',
                'font-weight' => '700',
                'line-height' => '41px'
            ),
        ),
        array(
            'id' => 'font_h4',
            'type' => 'typography',
            'title' => esc_html__('Font H4', 'netfx'),
            'subtitle' => esc_html__('H4 tag apply for Blog Title in list blog and Title in a listing.', 'netfx'),
            'google' => true,
            'default' => array(
                'font-size' => '30px',
                'font-family' => 'DM Sans',
                'font-weight' => '7 00',
                'line-height' => '34px'
            ),
        ),
        array(
            'id' => 'font_h5',
            'type' => 'typography',
            'title' => esc_html__('Font H5', 'netfx'),
            'subtitle' => esc_html__('H5', 'netfx'),
            'google' => true,
            'default' => array(
                'font-size' => '24px',
                'font-family' => 'DM Sans',
                'font-weight' => '700',
                'line-height' => '28px'
            ),
        ),
        array(
            'id' => 'font_h6',
            'type' => 'typography',
            'title' => esc_html__('Font H6', 'netfx'),
            'subtitle' => esc_html__('H6.', 'netfx'),
            'google' => true,
            'default' => array(
                'font-size' => '16px',
                'font-family' => 'DM Sans',
                'font-weight' => '700',
                'line-height' => '18px'
            ),
        ),

        array(
            'id' => 'font_tagline',
            'type' => 'typography',
            'title' => esc_html__('Font Tag Line', 'netfx'),
            'subtitle' => esc_html__('Tag Line font of the site.', 'netfx'),
            'google' => true,
            'default' => array(
                'font-size' => '18px',
                'font-family' => 'DM Sans',
                'font-weight' => '400',
                'line-height' => '21px'
            ),
        ),
        array(
            'id' => 'font_button',
            'type' => 'typography',
            'title' => esc_html__('Font button', 'netfx'),
            'subtitle' => esc_html__('Button font of the site.', 'netfx'),
            'google' => true,
            'default' => array(
                'font-size' => '16',
                'font-family' => 'DM Sans',
                'font-weight' => '500',
                'line-height' => '21px'
            ),
        ),
        array(
            'id'       => 'themecheck_style',
            'type'     => 'switch', 
            'title'    =>esc_html__('Developers Code', 'netfx'),
            'default'  => true,
            'desc' => esc_html__('Functions for developers, Function used to edit code. You should turn off the feature so when using theme','netfx'),
        ),
    )
));
// -> START Typography
Redux::setSection($opt_name, array(
    'title' => esc_html__('Responsive', 'netfx'),
    'id' => 'responsive',
    'desc' => esc_html__('Responsive in each screen: ', 'netfx') . '<a href="//docs.reduxframework.com/core/fields/typography/" target="_blank">docs.reduxframework.com/core/fields/typography/</a>',
    'icon' => 'el el-screen-alt',
));
Redux::setSection($opt_name, array(
    'title' => esc_html__('Laptop (max width 1440px)', 'netfx'),
    'id' => 'laptop_responsive',
    'subsection' => true,
    'fields' => array(

                array(
            'id' => 'font_body_laptop',
            'type' => 'typography',
            'title' => esc_html__('Body', 'netfx'),
            'subtitle' => esc_html__('Basic font.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h1_laptop',
            'type' => 'typography',
            'subtitle' => esc_html__('H1 tag aplly for title page and title post.', 'netfx'),
            'title' => esc_html__('Font H1', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h2_laptop',
            'type' => 'typography',
            'title' => esc_html__('Font H2', 'netfx'),
            'subtitle' => esc_html__('H2 tag apply for Headding Titles in each sections.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h3_laptop',
            'type' => 'typography',
            'title' => esc_html__('Font H3', 'netfx'),
            'subtitle' => esc_html__('H3 tag apply for Blog Title in list blog and Title in a listing.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h4_laptop',
            'type' => 'typography',
            'title' => esc_html__('Font H4', 'netfx'),
            'subtitle' => esc_html__('H4 tag apply for Blog Title in list blog and Title in a listing.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h5_laptop',
            'type' => 'typography',
            'title' => esc_html__('Font H5', 'netfx'),
            'subtitle' => esc_html__('H5', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h6_laptop',
            'type' => 'typography',
            'title' => esc_html__('Font H6', 'netfx'),
            'subtitle' => esc_html__('H6.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_tagline_laptop',
            'type' => 'typography',
            'title' => esc_html__('Font Tag Line', 'netfx'),
            'subtitle' => esc_html__('Tag Line font of the site.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_button_laptop',
            'type' => 'typography',
            'title' => esc_html__('Font button', 'netfx'),
            'subtitle' => esc_html__('Button font of the site.', 'netfx'),
            'google' => true,
        ),
    ),
));
//Ipad Pro
Redux::setSection($opt_name, array(
    'title' => esc_html__('Ipad Pro (1024px)', 'netfx'),
    'id' => 'ipadpro_responsive',
    'subsection' => true,
    'fields' => array(

                array(
            'id' => 'font_body_ipadpro',
            'type' => 'typography',
            'title' => esc_html__('Body', 'netfx'),
            'subtitle' => esc_html__('Basic font.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h1_ipadpro',
            'type' => 'typography',
            'subtitle' => esc_html__('H1 tag aplly for title page and title post.', 'netfx'),
            'title' => esc_html__('Font H1', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h2_ipadpro',
            'type' => 'typography',
            'title' => esc_html__('Font H2', 'netfx'),
            'subtitle' => esc_html__('H2 tag apply for Headding Titles in each sections.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h3_ipadpro',
            'type' => 'typography',
            'title' => esc_html__('Font H3', 'netfx'),
            'subtitle' => esc_html__('H3 tag apply for Blog Title in list blog and Title in a listing.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h4_ipadpro',
            'type' => 'typography',
            'title' => esc_html__('Font H4', 'netfx'),
            'subtitle' => esc_html__('H4 tag apply for Blog Title in list blog and Title in a listing.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h5_ipadpro',
            'type' => 'typography',
            'title' => esc_html__('Font H5', 'netfx'),
            'subtitle' => esc_html__('H5', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h6_ipadpro',
            'type' => 'typography',
            'title' => esc_html__('Font H6', 'netfx'),
            'subtitle' => esc_html__('H6.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_tagline_ipadpro',
            'type' => 'typography',
            'title' => esc_html__('Font Tag Line', 'netfx'),
            'subtitle' => esc_html__('Tag Line font of the site.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_button_ipadpro',
            'type' => 'typography',
            'title' => esc_html__('Font button', 'netfx'),
            'subtitle' => esc_html__('Button font of the site.', 'netfx'),
            'google' => true,
        ),
    ),
));
// IPad
Redux::setSection($opt_name, array(
    'title' => esc_html__('IPad (768px)', 'netfx'),
    'id' => 'ipad_responsive',
    'subsection' => true,
    'fields' => array(

            array(
            'id' => 'font_body_ipad',
            'type' => 'typography',
            'title' => esc_html__('Body', 'netfx'),
            'subtitle' => esc_html__('Basic font.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h1_ipad',
            'type' => 'typography',
            'subtitle' => esc_html__('H1 tag aplly for title page and title post.', 'netfx'),
            'title' => esc_html__('Font H1', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h2_ipad',
            'type' => 'typography',
            'title' => esc_html__('Font H2', 'netfx'),
            'subtitle' => esc_html__('H2 tag apply for Headding Titles in each sections.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h3_ipad',
            'type' => 'typography',
            'title' => esc_html__('Font H3', 'netfx'),
            'subtitle' => esc_html__('H3 tag apply for Blog Title in list blog and Title in a listing.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h4_ipad',
            'type' => 'typography',
            'title' => esc_html__('Font H4', 'netfx'),
            'subtitle' => esc_html__('H4 tag apply for Blog Title in list blog and Title in a listing.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h5_ipad',
            'type' => 'typography',
            'title' => esc_html__('Font H5', 'netfx'),
            'subtitle' => esc_html__('H5', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h6_ipad',
            'type' => 'typography',
            'title' => esc_html__('Font H6', 'netfx'),
            'subtitle' => esc_html__('H6.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_tagline_ipad',
            'type' => 'typography',
            'title' => esc_html__('Font Tag Line', 'netfx'),
            'subtitle' => esc_html__('Tag Line font of the site.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_button_ipad',
            'type' => 'typography',
            'title' => esc_html__('Font button', 'netfx'),
            'subtitle' => esc_html__('Button font of the site.', 'netfx'),
            'google' => true,
        ),
    ),
));
// Mobile
Redux::setSection($opt_name, array(
    'title' => esc_html__('Moblie', 'netfx'),
    'id' => 'mobile_responsive',
    'subsection' => true,
    'fields' => array(

            
            array(
            'id' => 'font_body_mobile',
            'type' => 'typography',
            'title' => esc_html__('Body', 'netfx'),
            'subtitle' => esc_html__('Basic font.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h1_mobile',
            'type' => 'typography',
            'subtitle' => esc_html__('H1 tag aplly for title page and title post.', 'netfx'),
            'title' => esc_html__('Font H1', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h2_mobile',
            'type' => 'typography',
            'title' => esc_html__('Font H2', 'netfx'),
            'subtitle' => esc_html__('H2 tag apply for Headding Titles in each sections.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h3_mobile',
            'type' => 'typography',
            'title' => esc_html__('Font H3', 'netfx'),
            'subtitle' => esc_html__('H3 tag apply for Blog Title in list blog and Title in a listing.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h4_mobile',
            'type' => 'typography',
            'title' => esc_html__('Font H4', 'netfx'),
            'subtitle' => esc_html__('H4 tag apply for Blog Title in list blog and Title in a listing.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h5_mobile',
            'type' => 'typography',
            'title' => esc_html__('Font H5', 'netfx'),
            'subtitle' => esc_html__('H5', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_h6_mobile',
            'type' => 'typography',
            'title' => esc_html__('Font H6', 'netfx'),
            'subtitle' => esc_html__('H6.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_tagline_mobile',
            'type' => 'typography',
            'title' => esc_html__('Font Tag Line', 'netfx'),
            'subtitle' => esc_html__('Tag Line font of the site.', 'netfx'),
            'google' => true,
        ),
        array(
            'id' => 'font_button_mobile',
            'type' => 'typography',
            'title' => esc_html__('Font button', 'netfx'),
            'subtitle' => esc_html__('Button font of the site.', 'netfx'),
            'google' => true,
        ),
    ),
));

// -> START Typography
Redux::setSection($opt_name, array(
    'title' => esc_html__('Speed Test', 'netfx'),
    'id' => 'speedtest',
    'desc' => esc_html__('Add Host For Speedtest function. Remove http or https example: //docs.jwsthemeswp.com , the url is where the folder plugin jws_speedtest is located','netfx'),
    'icon' => 'el el-dashboard',
    'fields' => array(
        array(
            'id'          => 'host_list',
            'type'        => 'slides',
            'title'       =>esc_html__('Host List', 'netfx'),
            'placeholder' => array(
             'title'           =>esc_html__('Host Name.', 'netfx'),
             'url'           =>esc_html__('Host Url. remove http or http example: //exampledemo.com', 'netfx'),
            ),
        ),
    )
));


if (file_exists(dirname(__FILE__) . '/../README.md')) {
    $section = array(
        'icon' => 'el el-list-alt',
        'title' => esc_html__('Documentation', 'netfx'),
        'fields' => array(
            array(
                'id' => '17',
                'type' => 'raw',
                'markdown' => true,
                'content_path' => dirname(__FILE__) . '/../README.md', // FULL PATH, not relative please
                //'content' => 'Raw content here',
            ),
        ),
    );
    Redux::setSection($opt_name, $section);
}
/*
 * <--- END SECTIONS
 */


/*
 *
 * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
 *
 */

/*
*
* --> Action hook examples
*
*/

// If Redux is running as a plugin, this will remove the demo notice and links
//add_action( 'redux/loaded', 'remove_demo' );

// Function to test the compiler hook and demo CSS output.
// Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
//add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

// Change the arguments after they've been declared, but before the panel is created
//add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

// Change the default value of a field after it's been set, but before it's been useds
//add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

// Dynamically add a section. Can be also used to modify sections/fields
//add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

/**
 * This is a test function that will let you see when the compiler hook occurs.
 * It only runs if a field    set with compiler=>true is changed.
 * */
if (!function_exists('compiler_action')) {
    function compiler_action($options, $css, $changed_values)
    {
        echo '<h1>The compiler hook has run!</h1>';
        echo "<pre>";
        print_r($changed_values); // Values that have changed since the last save
        echo "</pre>";
        //print_r($options); //Option values
        //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
    }
}

/**
 * Custom function for the callback validation referenced above
 * */
if (!function_exists('redux_validate_callback_function')) {
    function redux_validate_callback_function($field, $value, $existing_value)
    {
        $error = false;
        $warning = false;

        //do your validation
        if ($value == 1) {
            $error = true;
            $value = $existing_value;
        } elseif ($value == 2) {
            $warning = true;
            $value = $existing_value;
        }

        $return['value'] = $value;

        if ($error == true) {
            $field['msg'] = 'your custom error message';
            $return['error'] = $field;
        }

        if ($warning == true) {
            $field['msg'] = 'your custom warning message';
            $return['warning'] = $field;
        }

        return $return;
    }
}

/**
 * Custom function for the callback referenced above
 */
if (!function_exists('redux_my_custom_field')) {
    function redux_my_custom_field($field, $value)
    {
        print_r($field);
        echo '<br/>';
        print_r($value);
    }
}

/**
 * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
 * so you must use get_template_directory_uri() if you want to use any of the built in icons
 * */
if (!function_exists('dynamic_section')) {
    function dynamic_section($sections)
    {
        //$sections = array();
        $sections[] = array(
            'title' => esc_html__('Section via hook', 'netfx'),
            'desc' => esc_html__('<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'netfx'),
            'icon' => 'el el-paper-clip',
            // Leave this as a blank section, no options just some intro text set above.
            'fields' => array()
        );

        return $sections;
    }
}

/**
 * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
 * */
if (!function_exists('change_arguments')) {
    function change_arguments($args)
    {
        //$args['dev_mode'] = true;

        return $args;
    }
}

/**
 * Filter hook for filtering the default value of any given field. Very useful in development mode.
 * */
if (!function_exists('change_defaults')) {
    function change_defaults($defaults)
    {
        $defaults['str_replace'] = 'Testing filter hook!';

        return $defaults;
    }
}

function get_product_attr() {
        $attributes = array();
        if (class_exists('Woocommerce')) {
            $attributes_tax = wc_get_attribute_taxonomies();
        }else {
            $attributes_tax = '';
        }
        if (class_exists('Woocommerce')) {
        foreach ($attributes_tax as $attribute) {
            $attributes[$attribute->attribute_name] = $attribute->attribute_label;
        }
        return $attributes;
        }
    }

