<?php
namespace Elementor;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Agencys_form extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'jws_agencys_form';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Jws Agencys Form', 'netfx' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-site-search';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'jws-elements' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_agencys_form_setting',
			[
				'label' => esc_html__( 'Setting', 'netfx' ),
			]
		);

        $this->add_control(
			'distance',
			[
				'label' => esc_html__( 'Maximum distance', 'netfx' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' =>1,
				'max' => 1000,
				'step' => 1,
				'default' => 100,
			]
		);
        
        $this->add_control(
			'content_bottom_form',
			[
				'label' => esc_html__( 'Content Bottom Form', 'netfx' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => esc_html__( '', 'netfx' ),
			]
		);

		$this->end_controls_section();
  
		$this->start_controls_section(
			'section_agencys_form_tab1',
			[
				'label' => esc_html__( 'Tabs Has Agencys', 'netfx' ),
			]
		);
        $this->add_control(
			'shortcode_cf7',
			[
				'label' => esc_html__( 'Add Shortcode Contact Form 7 ( when the agency is found )', 'netfx' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__( '', 'netfx' ),
			]
		);
        $this->add_control(
			'content_top',
			[
				'label' => esc_html__( 'Content Top', 'netfx' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => esc_html__( '', 'netfx' ),
				'placeholder' => esc_html__( 'Type your content for form here', 'netfx' ),
			]
		);
        
        $this->add_control(
			'content_bottom_left',
			[
				'label' => esc_html__( 'Content Bottom Left Number Miles', 'netfx' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( '', 'netfx' ),
			]
		);
        $this->add_control(
			'content_bottom_right',
			[
				'label' => esc_html__( 'Content Bottom Right Number Miles', 'netfx' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( '', 'netfx' ),
			]
		);

        $this->end_controls_section();
        
        	$this->start_controls_section(
			'section_agencys_form_tab2',
			[
				'label' => esc_html__( 'Tabs No Agencys', 'netfx' ),
			]
		);
        $this->add_control(
			'shortcode_cf7_2',
			[
				'label' => esc_html__( 'Add Shortcode Contact Form 7 ( when the agency is not found )', 'netfx' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__( '', 'netfx' ),
			]
		);
        $this->add_control(
			'content_top2',
			[
				'label' => esc_html__( 'Content Top', 'netfx' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => esc_html__( '', 'netfx' ),
				'placeholder' => esc_html__( 'Type your content for form here', 'netfx' ),
			]
		);
        $this->end_controls_section();
      
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();;    
        include( 'content.php' );

	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}
}