<?php
namespace Elementor;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Banner extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'jws_banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Jws banner', 'netfx' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-site-search';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'jws-elements' ];
	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
	    $this->start_controls_section(
			'setting_section',
			[
				'label' =>esc_html__( 'Setting', 'netfx' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
			'banner_layout',
			[
				'label' =>esc_html__( 'Layout', 'netfx' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'layout1',
				'options' => [
					'layout1'  =>esc_html__( 'Layout 1', 'netfx' ),
                    'layout2'  =>esc_html__( 'Layout 2', 'netfx' ),
                    'layout3'  =>esc_html__( 'Layout 3', 'netfx' ),
                    'layout4'  =>esc_html__( 'Layout 4', 'netfx' ),
                    'layout5'  =>esc_html__( 'Layout 5', 'netfx' ),
				],
			]
		);
        $this->add_control(
			'button_text',
			[
				'label' =>esc_html__( 'Button Text', 'netfx' ),
				'type' => Controls_Manager::TEXT,
				'default' =>esc_html__( 'Shop now', 'netfx' ),
			]
		);
        $this->add_control(
			'banner_url',
			[
				'label' =>esc_html__( 'Link', 'netfx' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' =>esc_html__( 'https://your-link.com', 'netfx' ),
				'show_external' => true,
				'default' => [
					'url' => '#',
				],
			]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'content_section',
			[
				'label' =>esc_html__( 'Group Text 1', 'netfx' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
			'banner_title',
			[
				'label' =>esc_html__( 'Title', 'netfx' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' =>esc_html__( 'Default title', 'netfx' ),
				'placeholder' =>esc_html__( 'Type your title here', 'netfx' ),
			]
		);
        $this->add_control(
			'banner_content',
			[
				'label' =>esc_html__( 'Content', 'netfx' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' =>esc_html__( 'Default description', 'netfx' ),
				'placeholder' =>esc_html__( 'Type your description here', 'netfx' ),
			]
		);
        $this->add_control(
            'banner_image',
            [
                'label' =>esc_html__('Choose Image', 'netfx'),
                'type' => Controls_Manager::MEDIA,
                
            ]
        );
        $this->add_control(
            'banner_image_size',
            [
                'label' =>esc_html__('Banner Image Size', 'netfx'),
                'type' => Controls_Manager::TEXT,
                
            ]
        );
        
        $this->add_control(
				'align2',
				[
					'label' 		=>esc_html__( 'Align', 'netfx' ),
					'type' 			=> Controls_Manager::CHOOSE,
					'default' 		=> 'left',
					'options' 		=> [
						'left'    		=> [
							'title' 	=>esc_html__( 'Left', 'netfx' ),
							'icon' 		=> 'eicon-h-align-left',
						],
						'center' 		=> [
							'title' 	=>esc_html__( 'Center', 'netfx' ),
							'icon' 		=> 'eicon-h-align-center',
						],
						'right' 		=> [
							'title' 	=>esc_html__( 'Right', 'netfx' ),
							'icon' 		=> 'eicon-h-align-right',
						],
					],
                    'selectors' => [
							'{{WRAPPER}} .jws_banner' => 'text-align: {{VALUE}};',
					],
					'frontend_available' => true,
				]
		);
        $this->end_controls_section();
         $this->start_controls_section(
			'content_group2',
			[
				'label' =>esc_html__( 'Group Text 2', 'netfx' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
			'group2_title',
			[
				'label' =>esc_html__( 'Title', 'netfx' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' =>esc_html__( 'Cosmetic time', 'netfx' ),
				'placeholder' =>esc_html__( 'Type your title here', 'netfx' ),
			]
		);
         $this->add_control(
			'group2_sub_title',
			[
				'label' =>esc_html__( 'Sub title', 'netfx' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' =>esc_html__( 'true natural', 'netfx' ),
				'placeholder' =>esc_html__( 'Type your sub title here', 'netfx' ),
			]
		);
        $this->add_control(
			'number',
			[
				'label' =>esc_html__( 'Number', 'netfx' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' =>esc_html__( '30', 'netfx' ),
				'placeholder' =>esc_html__( 'Type your number here', 'netfx' ),
                'condition' => [
						  'banner_layout!' => 'layout3',
				],
			]
		);
        $this->add_control(
			'unit',
			[
				'label' =>esc_html__( 'Unit', 'netfx' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' =>esc_html__( '%', 'netfx' ),
				'placeholder' =>esc_html__( 'Type your unit here', 'netfx' ),
                'condition' => [
						  'banner_layout!' => 'layout3',
				],
			]
		);
           $this->add_control(
			'text_after',
			[
				'label' =>esc_html__( 'Text after ', 'netfx' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' =>esc_html__( '%', 'netfx' ),
				'placeholder' =>esc_html__( 'Off', 'netfx' ),
                'condition' => [
						  'banner_layout!' => 'layout3',
				],
			]
		);

        
        
        $this->add_control(
				'align',
				[
					'label' 		=>esc_html__( 'Align', 'netfx' ),
					'type' 			=> Controls_Manager::CHOOSE,
					'default' 		=> 'left',
					'options' 		=> [
						'left'    		=> [
							'title' 	=>esc_html__( 'Left', 'netfx' ),
							'icon' 		=> 'eicon-h-align-left',
						],
						'center' 		=> [
							'title' 	=>esc_html__( 'Center', 'netfx' ),
							'icon' 		=> 'eicon-h-align-center',
						],
						'right' 		=> [
							'title' 	=>esc_html__( 'Right', 'netfx' ),
							'icon' 		=> 'eicon-h-align-right',
						],
					],
                    'selectors' => [
							'{{WRAPPER}} .jws_banner' => 'text-align: {{VALUE}};',
					],
					'frontend_available' => true,
				]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'icon_section',
			[
				'label' =>esc_html__( 'Icon', 'netfx' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
				'icon',
				[
					'label' =>esc_html__( 'Icon', 'netfx' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'fab fa-wordpress',
                		'library' => 'fa-brands',
					],
				]
		);
     
		$this->end_controls_section();
        $this->start_controls_section(
			'banner_style',
			[
				'label' =>esc_html__( 'Banner', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        

        $this->start_controls_tabs( 'tabs_background' );

		$this->start_controls_tab(
			'tab_background_normal',
			[
				'label' =>esc_html__( 'Normal', 'netfx' ),
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'types' => [ 'classic', 'gradient', 'slideshow' ],
				'selector' => '{{WRAPPER}} .jws_banner',
				'fields_options' => [
					'background' => [
						'frontend_available' => true,
					],
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_background_hover',
			[
				'label' =>esc_html__( 'Hover', 'netfx' ),
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background_hover',
			     'selector' => '{{WRAPPER}} .jws_banner:hover',
			]
		);

		$this->add_control(
			'background_hover_transition',
			[
				'label' =>esc_html__( 'Transition Duration', 'netfx' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 0.3,
				],
				'range' => [
					'px' => [
						'max' => 3,
						'step' => 0.1,
					],
				],
				'render_type' => 'ui',
				'separator' => 'before',
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();
        $this->add_responsive_control(
					'banner_padding',
					[
						'label' 		=>esc_html__( 'Padding', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws_banner_inner .banner-content-holder' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->add_responsive_control(
					'banner_radius',
					[
						'label' 		=>esc_html__( 'Border Radius', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws_banner_inner .banner-content-holder' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);

		$this->end_controls_section();
        $this->start_controls_section(
			'banner_content_title_style',
			[
				'label' =>esc_html__( 'Content', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'banner_title_style',
			[
				'label' =>esc_html__( 'Title', 'netfx' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
			'title_color',
			[
				'label' =>esc_html__( 'Title Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws_banner .banner_title' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' =>esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws_banner .banner_title',
                'selectors' 	=> [
                '{{WRAPPER}} .jws_banner.layout5 .jws_banner_inner .banner-content-holder .content-group1 .banner_title',
						'{{WRAPPER}} .jws_banner .banner_title',
                        
					],
			]
		);
        $this->add_control(
				'title_spacing',
				[
					'label' 		=>esc_html__( 'Spacing', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .jws_banner .banner_title' => 'margin-bottom: {{SIZE}}px;',
					],
				]
		);
        $this->add_control(
			'banner_content_style',
			[
				'label' =>esc_html__( 'Content', 'netfx' ),
				'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',

			]
		);
        
        $this->add_control(
			'content_color',
			[
				'label' =>esc_html__( 'Content Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws_banner .banner_content' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'label' =>esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws_banner .banner_content',
			]
		);
        
        $this->end_controls_section();
        
        $this->start_controls_section(
			'banner_icon_style',
			[
				'label' =>esc_html__( 'Icon', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'icon_color',
			[
				'label' =>esc_html__( 'Icon Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws_banner .banner_icon' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
				'icon_size',
				[
					'label' 		=>esc_html__( 'Icon Size', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .jws_banner .banner_icon' => 'font-size: {{SIZE}}px;',
					],
				]
		);
        $this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
	   
		$settings = $this->get_settings_for_display();
        $url = $settings['banner_url']['url'];
        $target = $settings['banner_url']['is_external'] ? ' target="_blank"' : '';
		$nofollow = $settings['banner_url']['nofollow'] ? ' rel="nofollow"' : '';  
        
         ?>
            <div class="jws_banner <?php echo esc_attr($settings['banner_layout']); ?>">
                <div class="jws_banner_inner">
                    <?php include( 'layout/'.$settings['banner_layout'].'.php' ); ?>
                </div>
            </div>
        <?php

	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}
}