<?php
namespace Elementor;
use Elementor\Core\Schemes\Color;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Widget_Base;
use Elementor\Group_Control_Border;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Jws_Blog extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'jws_blog';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Jws Blog', 'netfx' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post';
	}
    /**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
    public function get_script_depends() {
		return [ 'isotope'];
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'jws-elements' ];
	}
    
	/**
	 * Register Woo post Grid controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function _register_controls() {

		/* General Tab */
        $this->register_content_general_controls();
        $this->register_content_filter_controls();
		$this->register_content_grid_controls();
        $this->register_content_nav_controls();
        $this->register_content_pagination_controls();
        $this->register_content_slider_controls();
        $this->register_content_post_format_controls();
 
	}

    /**
	 * Register Woo posts General Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	*/
	protected function register_content_general_controls() {

		$this->start_controls_section(
			'section_general_field',
			[
				'label' => esc_html__( 'General', 'netfx' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
            $this->add_control(
				'blog_display',
				[
					'label'     => esc_html__( 'Display', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'grid',
					'options'   => [
						'grid'   => esc_html__( 'Grid', 'netfx' ),
						'slider'   => esc_html__( 'Slider', 'netfx' ),
					],
                    
				]
			);
            $this->add_control(
    			'enable_masonry',
    			[
    				'label' => esc_html__( 'Enable Masonry', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::SWITCHER,
    				'label_on' => esc_html__( 'On', 'netfx' ),
    				'label_off' => esc_html__( 'Off', 'netfx' ),
    				'return_value' => 'yes',
    			]
    		);
            $this->add_control(
    			'enable_animation',
    			[
    				'label' => esc_html__( 'Enable Animation', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::SWITCHER,
    				'label_on' => esc_html__( 'On', 'netfx' ),
    				'label_off' => esc_html__( 'Off', 'netfx' ),
    				'return_value' => 'yes',
    			]
    		);
            $this->add_control(
    			'border_popover_toggle',
    			[
    				'label' => esc_html__( 'Border', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::POPOVER_TOGGLE,
    				'label_off' => esc_html__( 'Default', 'netfx' ),
    				'label_on' => esc_html__( 'Custom', 'netfx' ),
    				'return_value' => 'yes',
    				'default' => 'yes',
    			]
		    );
            $this->add_control(
				'blog_layouts',
				[
					'label'     => esc_html__( 'Layout', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'layout1',
					'options'   => [
						'layout1'   => esc_html__( 'Layout 1', 'netfx' ),
						'layout2'   => esc_html__( 'Layout 2', 'netfx' ),
                        'layout3'   => esc_html__( 'Layout 3', 'netfx' ),
                        'layout4'   => esc_html__( 'Layout 4', 'netfx' ),
                        'layout5'   => esc_html__( 'Layout 5', 'netfx' ),
                        'layout6'   => esc_html__( 'Layout 6', 'netfx' ),
                        'layout7'   => esc_html__( 'Layout 7', 'netfx' ),
                        'layout8'   => esc_html__( 'Layout 8', 'netfx' ),
                        'layout9'   => esc_html__( 'Layout 9', 'netfx' ),       
					],
                    
				]
			);
            $this->add_control(
    			'show_cat',
    			[
    				'label' => esc_html__( 'Show Category', 'netfx' ),
    				'type' => Controls_Manager::SWITCHER,
    				'default' => 'yes',
    				'label_off' => esc_html__( 'Off', 'netfx' ),
    				'label_on' => esc_html__( 'On', 'netfx' ),
    			]
    		);
    		$this->add_control(
    			'show_time',
    			[
    				'label' => esc_html__( 'Show Time', 'netfx' ),
    				'type' => Controls_Manager::SWITCHER,
    				'default' => 'yes',
    				'label_off' => esc_html__( 'Off', 'netfx' ),
    				'label_on' => esc_html__( 'On', 'netfx' ),
    			]
    		);
                $this->add_control(
    			'show_author',
    			[
    				'label' => esc_html__( 'Show Author', 'netfx' ),
    				'type' => Controls_Manager::SWITCHER,
    				'default' => 'yes',
    				'label_off' => esc_html__( 'Off', 'netfx' ),
    				'label_on' => esc_html__( 'On', 'netfx' ),
    			]
    		);
    		$this->add_control(
    			'show_title',
    			[
    				'label' => esc_html__( 'Show Title', 'netfx' ),
    				'type' => Controls_Manager::SWITCHER,
    				'default' => 'yes',
    				'label_off' => esc_html__( 'Off', 'netfx' ),
    				'label_on' => esc_html__( 'On', 'netfx' ),
    			]
    		);
              $this->add_control(
    			'show_category',
    			[
    				'label' => esc_html__( 'Show Category', 'netfx' ),
    				'type' => Controls_Manager::SWITCHER,
    				'default' => 'yes',
    				'label_off' => esc_html__( 'Off', 'netfx' ),
    				'label_on' => esc_html__( 'On', 'netfx' ),
    			]
    		);
    		$this->add_control(
    			'posts_per_words_title',
    			[
    				'label' => esc_html__( 'Posts Per Words', 'netfx' ),
    				'type' => Controls_Manager::NUMBER,
    				'default' => '20',
    				'condition' 	=> [
    					'show_title!'	=> '',
    				],
    				
    			]
    		);
    		$this->add_control(
    			'show_decription',
    			[
    				'label' => esc_html__( 'Show Decription', 'netfx' ),
    				'type' => Controls_Manager::SWITCHER,
    				'default' => 'yes',
    				'label_off' => esc_html__( 'Off', 'netfx' ),
    				'label_on' => esc_html__( 'On', 'netfx' ),
    			]
    		);
            	$this->add_control(
    			'show_readmore',
    			[
    				'label' => esc_html__( 'Show Read More', 'netfx' ),
    				'type' => Controls_Manager::SWITCHER,
    				'default' => 'yes',
    				'label_off' => esc_html__( 'Off', 'netfx' ),
    				'label_on' => esc_html__( 'On', 'netfx' ),
    			]
    		);
            $this->add_control(
				'excerpt_length',
				[
					'label'     => esc_html__( 'Excerpt Length', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => '',
				]
			);
             $this->add_control(
				'excerpt_more',
				[
					'label'     => esc_html__( 'Excerpt More', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => ' ... ',
				]
			);
            $this->add_control(
				'readmore_text',
				[
					'label'     => esc_html__( 'Read More Text', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => 'Read More',
				]
			);
            $this->add_control(
				'icon',
				[
					'label' => esc_html__( 'Read More Icon', 'netfx' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'eva-arrow-forward-outline',
                		'library' => 'fa-brands',
					],
				]
		  );
          $this->add_control(
				'share_text',
				[
					'label'     => esc_html__( 'Share text button', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => 'Share',
				]
			);
          $this->add_control(
				'blog_image_size',
				[
					'label'     => esc_html__( 'Image Size', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => 'full',
				]
		  );
          $this->add_control(
			'post_archive',
			[
				'label' => esc_html__( 'Show Post For Archive Category', 'netfx' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'On', 'netfx' ),
				'label_off' => esc_html__( 'Off', 'netfx' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
        $this->add_control(
			'post_related',
			[
				'label' => esc_html__( 'Show post related for single blog', 'netfx' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'On', 'netfx' ),
				'label_off' => esc_html__( 'Off', 'netfx' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
        $this->add_control(
				'blog_per_page_related',
				[
					'label'     => esc_html__( 'posts Per Page Related', 'netfx' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => '3',
					'condition' => [
						'post_related'  => 'yes',
					],
				]
			);
          $this->add_control(
			'ajax_page',
			[
				'label' => esc_html__( 'ajax_page', 'netfx' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => '',
			]
		  );
          $this->add_control(
    				'post_nav_on',
    				[
    					'label'        => esc_html__( 'Enable Nav', 'netfx' ),
    					'type'         => Controls_Manager::SWITCHER,
    					'label_on'     => esc_html__( 'Yes', 'netfx' ),
    					'label_off'    => esc_html__( 'No', 'netfx' ),
    					'return_value' => 'yes',
    					'description'  => esc_html__( 'Enable nav filter post.', 'netfx' ),
    				]
    	   );
           $this->add_control(
				'post_text_first',
				[
					'label'     => esc_html__( 'Nav Text All', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
                    'default' => 'ALL CATEGORIES',
                    'condition'	=> [
						'post_nav_on' => 'yes',
				    ],
			 ]
		  );  
          $this->add_control(
			'show_override_section',
			[
				'label' => esc_html__( 'Show override section in blog item', 'netfx' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'On', 'netfx' ),
				'label_off' => esc_html__( 'Off', 'netfx' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
          $this->add_control(
			'content_type',
			[
				'label'   => esc_html__( 'Content Type', 'netfx' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'content',
				'options' => $this->get_content_type(),
                 'condition'	=> [
						'show_override_section' => 'yes',
				    ],
			]
		  );
        $this->add_control(
			'ct_content',
			[
				'label'      => esc_html__( 'Description', 'netfx' ),
				'type'       => Controls_Manager::WYSIWYG,
				'default'    => esc_html__( 'Enter content here. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.? Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'netfx' ),
				'rows'       => 10,
				'show_label' => false,
				'dynamic'    => [
					'active' => true,
				],
				'condition'  => [
					'content_type' => 'content',
				],
			]
		);

		$this->add_control(
			'ct_saved_rows',
			[
				'label'     => esc_html__( 'Select Section', 'netfx' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => $this->get_saved_data( 'section' ),
				'default'   => '-1',
				'condition' => [
					'content_type' => 'saved_rows',
				],
			]
		);

		$this->add_control(
			'ct_page_templates',
			[
				'label'     => esc_html__( 'Select Page', 'netfx' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => $this->get_saved_data( 'page' ),
				'default'   => '-1',
				'condition' => [
					'content_type' => 'saved_page_templates',
				],
			]
		);

		$this->add_control(
			'ct_saved_modules',
			[
				'label'     => esc_html__( 'Select Widget', 'netfx' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => $this->get_saved_data( 'widget' ),
				'default'   => '-1',
				'condition' => [
					'content_type' => 'saved_modules',
				],
			]
		);
		$this->end_controls_section();
        $this->start_controls_section(
			'box_style',
			[
				'label' => esc_html__( 'Box', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_responsive_control(
					'blog_padding',
					[
						'label' 		=> esc_html__( 'Padding', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->add_responsive_control(
					'blog_radius',
					[
						'label' 		=> esc_html__( 'Border Radius', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->add_responsive_control(
			'column_gap',
			[
				'label'     => esc_html__( 'Columns Gap', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
				'default'   => [
                    'unit' => 'px',
					'size' => 30,
				],
				'range'     => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
                    '%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-blog-item' => 'padding-right: calc( {{SIZE}}{{UNIT}}/2 ); padding-left: calc( {{SIZE}}{{UNIT}}/2 );',
					'{{WRAPPER}} .jws-blog-element .row' => 'margin-left: calc( -{{SIZE}}{{UNIT}}/2 ); margin-right: calc( -{{SIZE}}{{UNIT}}/2 );',
				],
			]
		);

		$this->add_responsive_control(
			'row_gap',
			[
				'label'     => esc_html__( 'Rows Gap', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-blog-item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .jws-blog-element .row' => 'margin-bottom: -{{SIZE}}{{UNIT}};',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'label' => esc_html__( 'Box Shadow', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws-post-wap',
			]
		);
        $this->add_control(
			'box_bgcolor',
			[
				'label' => esc_html__( 'background Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap , {{WRAPPER}} .jws-blog-element .jws_blog_layout10 .jws-post-wap .jws-post-content , {{WRAPPER}} .jws-blog-element .jws_blog_layout13 .jws-post-wap .jws-post-content' => 'background: {{VALUE}}',
				],
			]
		);
        $this->add_control(
				'box_align',
				[
					'label' 		=> esc_html__( 'Align', 'netfx' ),
					'type' 			=> Controls_Manager::CHOOSE,
					'options' 		=> [
						'left'    		=> [
							'title' 	=> esc_html__( 'Left', 'netfx' ),
							'icon' 		=> 'eicon-h-align-left',
						],
						'center' 		=> [
							'title' 	=> esc_html__( 'Center', 'netfx' ),
							'icon' 		=> 'eicon-h-align-center',
						],
						'right' 		=> [
							'title' 	=> esc_html__( 'Right', 'netfx' ),
							'icon' 		=> 'eicon-h-align-right',
						],
					],
                    'selectors' => [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content' => 'text-align: {{VALUE}};',
					],
					'frontend_available' => true,
				]
		);
        $this->add_control(
				'box_align_quote',
				[
					'label' 		=> esc_html__( 'Align text for qoute and link blog', 'netfx' ),
					'type' 			=> Controls_Manager::CHOOSE,
					'options' 		=> [
						'left'    		=> [
							'title' 	=> esc_html__( 'Left', 'netfx' ),
							'icon' 		=> 'eicon-h-align-left',
						],
						'center' 		=> [
							'title' 	=> esc_html__( 'Center', 'netfx' ),
							'icon' 		=> 'eicon-h-align-center',
						],
						'right' 		=> [
							'title' 	=> esc_html__( 'Right', 'netfx' ),
							'icon' 		=> 'eicon-h-align-right',
						],
					],
                    'selectors' => [
							'{{WRAPPER}} .jws-blog-element .jws-blog-item.link .jws-post-content' => 'text-align: {{VALUE}};',
      	                     '{{WRAPPER}} .jws-blog-element .jws-blog-item.quote .jws-post-content' => 'text-align: {{VALUE}};',
					],
					'frontend_available' => true,
				]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'image_style',
			[
				'label' => esc_html__( 'Image', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
         $this->add_responsive_control(
					'image_radius',
					[
						'label' 		=> esc_html__( 'Border Radius', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);

        $this->end_controls_section();
        $this->start_controls_section(
			'box_title_style',
			[
				'label' => esc_html__( 'Title', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Title Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap h3 a' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'title_color_hover',
			[
				'label' => esc_html__( 'Title Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap h3 a:hover' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws-post-wap h3',
			]
		);

        $this->add_responsive_control(
					'title_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography_hover',
				'label' => esc_html__( 'Typography Hover', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws-post-wap h3:hover',
			]
		);
        $this->add_control(
			'title_underline_color_hover',
			[
				'label' => esc_html__( 'Underline Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap h3 a:hover' => 'text-decoration-color: {{VALUE}}; -webkit-text-decoration-color:{{VALUE}};-moz-text-decoration-color: {{VALUE}}',
				],
			]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'post_meta_style',
			[
				'label' => esc_html__( 'Post meta', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
         $this->add_control(
			'post_meta_color',
			[
				'label' => esc_html__( 'Date Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws-post-meta a' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_responsive_control(
					'post_meta_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-meta' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'date_style',
			[
				'label' => esc_html__( 'Date', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'date_color',
			[
				'label' => esc_html__( 'Date Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .entry-date , {{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .entry-date a , {{WRAPPER}} .jws-blog-element .jws-post-wap .jws_post_image .entry-date a' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'date_color_hover',
			[
				'label' => esc_html__( 'Date Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .entry-date a:hover , {{WRAPPER}} .jws-blog-element .jws-post-wap .jws_post_image .entry-date a:hover' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'date_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws-post-wap .entry-date',
			]
		);
        $this->add_responsive_control(
					'date_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap .entry-date' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->end_controls_section();
        
        $this->start_controls_section(
			'category_style',
			[
				'label' => esc_html__( 'Category', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'category_color',
			[
				'label' => esc_html__( 'Category Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .post_cat,{{WRAPPER}} .jws-blog-element .jws-post-wap .post_cat a' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'              => 'category_bgcolor',
                'label' => esc_html__( 'Category Background Color', 'netfx' ),
				'types'             => [ 'classic', 'gradient' ],
				'selector'          => '{{WRAPPER}} .jws-blog-element .jws-post-wap .post_cat',
			]
	   );
        $this->add_control(
			'category_color_hover',
			[
				'label' => esc_html__( 'Category Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .post_cat a:hover' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'category_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws-post-wap .post_cat',
			]
		);
         $this->add_responsive_control(
					'category_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap .post_cat' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->end_controls_section();
        
        $this->start_controls_section(
			'author_style',
			[
				'label' => esc_html__( 'Author', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'author_color',
			[
				'label' => esc_html__( 'Author Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .post_author , {{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .post_author a' => 'color: {{VALUE}}',
				],
			]
		);
         $this->add_control(
			'author_color_hover',
			[
				'label' => esc_html__( 'Author Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .post_author a:hover' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'author_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .post_author',
			]
		);
         $this->add_responsive_control(
					'author_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .post_author' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->end_controls_section();
        
        $this->start_controls_section(
			'comment_style',
			[
				'label' => esc_html__( 'Comment', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'comment_color',
			[
				'label' => esc_html__( 'Comment Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_meta .entry-comment' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'comment_color_hover',
			[
				'label' => esc_html__( 'Comment Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_meta .entry-comment:hover' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'comment_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_meta .entry-comment',
			]
		);
         $this->add_responsive_control(
					'comment_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_meta .entry-comment' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->end_controls_section();
        
        $this->start_controls_section(
			'like_style',
			[
				'label' => esc_html__( 'Like', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'like_color',
			[
				'label' => esc_html__( 'Like Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_meta .entry-like a' => 'color: {{VALUE}}',
				],
			]
		);
         $this->add_control(
			'like_color_hover',
			[
				'label' => esc_html__( 'Like Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_meta .entry-like a:hover' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'like_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_meta .entry-like',
			]
		);
         $this->add_responsive_control(
					'like_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_meta .entry-like' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'view_style',
			[
				'label' => esc_html__( 'View', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'view_color',
			[
				'label' => esc_html__( 'View Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_meta .entry-view' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'view_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_meta .entry-view',
			]
		);
         $this->add_responsive_control(
					'view_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_meta .entry-view' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'excerpt_style',
			[
				'label' => esc_html__( 'Excerpt', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        $this->add_control(
			'show_excerpt',
			[
				'label' => esc_html__( 'Show Excerpt', 'netfx' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'netfx' ),
				'label_off' => esc_html__( 'Hide', 'netfx' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
        $this->add_control(
			'excerpt_color',
			[
				'label' => esc_html__( 'Excerpt Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-excerpt' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'excerpt_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-excerpt',
			]
		);
        $this->add_responsive_control(
					'excerpt_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-excerpt' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'readmore_style',
			[
				'label' => esc_html__( 'Read More', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			're_color',
			[
				'label' => esc_html__( 'Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_readmore' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			're_color_hover',
			[
				'label' => esc_html__( 'Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_readmore:hover' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'readmore_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_readmore',
			]
		);
        $this->add_responsive_control(
					'readmore_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws-post-wap .jws-post-content .jws_post_readmore' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'share_style',
			[
				'label' => esc_html__( 'Share', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'share_color',
			[
				'label' => esc_html__( 'Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .post-share .social_label' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'share_color_hover',
			[
				'label' => esc_html__( 'Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws-post-wap .post-share .social_label:hover' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'share_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws-post-wap .post-share .social_label',
			]
		);

        $this->end_controls_section();
        $this->start_controls_section(
			'nav_style',
			[
				'label' => esc_html__( 'Slider Nav', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'nav_color',
			[
				'label' => esc_html__( 'Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .custom_navs button' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'nav_color_hover',
			[
				'label' => esc_html__( 'Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .custom_navs button:hover' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
				'nav_size',
				[
					'label' 		=> esc_html__( 'Nav Size', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .custom_navs button' => 'font-size: {{SIZE}}px;',
					],
				]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'loadmore_style',
			[
				'label' => esc_html__( 'Load More', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        $this->add_responsive_control(
					'loadmore_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws_pagination .jws-load-more' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->add_responsive_control(
					'loadmore_padding',
					[
						'label' 		=> esc_html__( 'Padding', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .jws_pagination .jws-load-more' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->add_control(
			'loadmore_color',
			[
				'label' => esc_html__( 'Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws_pagination .jws-load-more' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'loadmore_bgcolor',
			[
				'label' => esc_html__( 'Background Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws_pagination .jws-load-more' => 'background: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'loadmore_color_hover',
			[
				'label' => esc_html__( 'Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws_pagination .jws-load-more:hover' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'loadmore_bgcolor_hover',
			[
				'label' => esc_html__( 'Background Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws_pagination .jws-load-more:hover' => 'background: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'loadmore_border',
				'label' => esc_html__( 'Border', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws_pagination .jws-load-more',
			]
		);
        $this->add_control(
			'loadmore_border_color_hover',
			[
				'label' => esc_html__( 'Border Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .jws_pagination .jws-load-more:hover' => 'border-color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'loadmore_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-blog-element .jws_pagination .jws-load-more',
			]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'pgi_number_style',
			[
				'label' => esc_html__( 'Pagination Number', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        $this->add_control(
			'pgi_number_size',
			[
				'label' => esc_html__( 'Size', 'netfx' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 2,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .jws-pagination-number ul li > a,{{WRAPPER}} .jws-pagination-number ul li > span' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};line-height: {{SIZE}}{{UNIT}};',
				],
			]
		);
        $this->add_responsive_control(
					'pgi_number_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} jws-pagination-number' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->add_responsive_control(
					'pgi_number_padding',
					[
						'label' 		=> esc_html__( 'Padding', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-pagination-number ul li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->add_control(
			'pgi_number_color',
			[
				'label' => esc_html__( 'Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-pagination-number ul li > a,{{WRAPPER}} .jws-pagination-number ul li > span' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'pgi_number_bgcolor',
			[
				'label' => esc_html__( 'Background Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-pagination-number ul li > a,{{WRAPPER}} .jws-pagination-number ul li > span' => 'background: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'pgi_number_color_hover',
			[
				'label' => esc_html__( 'Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-pagination-number ul li > .current , {{WRAPPER}} .jws-pagination-number ul li > a:hover' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'pgi_number_bgcolor_hover',
			[
				'label' => esc_html__( 'Background Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-pagination-number ul li > .current , {{WRAPPER}} .jws-pagination-number ul li > a:hover' => 'background: {{VALUE}}',
				],
			]
		);
        $this->add_responsive_control(
					'pgi_number_radius',
					[
						'label' 		=> esc_html__( 'Border Radius', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-pagination-number ul li > a,{{WRAPPER}} .jws-pagination-number ul li > span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'pgi_number_border',
				'label' => esc_html__( 'Border', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-pagination-number ul li > a,{{WRAPPER}} .jws-pagination-number ul li > span',
			]
		);
        $this->add_control(
			'pgi_number_border_color_hover',
			[
				'label' => esc_html__( 'Border Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-pagination-number ul li > .current , {{WRAPPER}} .jws-pagination-number ul li > a:hover' => 'border-color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'pgi_number_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-pagination-number ul li > a,{{WRAPPER}} .jws-pagination-number ul li > span',
			]
		);
        $this->end_controls_section();
	}
    protected function register_content_nav_controls() {
    $this->start_controls_section(
			'nav_filter',
			[
				'label' => esc_html__( 'Nav Filter', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
                'condition'	=> [
						'post_nav_on' => 'yes',
				],
			]
		);
        $this->add_responsive_control(
				'nav_filter_align',
				[
					'label' 		=> esc_html__( 'Align', 'netfx' ),
					'type' 			=> Controls_Manager::CHOOSE,
					'default' 		=> 'left',
					'options' 		=> [
						'left'    		=> [
							'title' 	=> esc_html__( 'Left', 'netfx' ),
							'icon' 		=> 'eicon-h-align-left',
						],
						'center' 		=> [
							'title' 	=> esc_html__( 'Center', 'netfx' ),
							'icon' 		=> 'eicon-h-align-center',
						],
						'right' 		=> [
							'title' 	=> esc_html__( 'Right', 'netfx' ),
							'icon' 		=> 'eicon-h-align-right',
						],
					],
                    'selectors' => [
							'{{WRAPPER}} .jws-blog-element .post_nav_container' => 'text-align: {{VALUE}};',
					],
					'frontend_available' => true,
				]
		);
        $this->add_responsive_control(
					'nav_filter_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .post_nav' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
		);
        $this->add_responsive_control(
					'nav_filter_padding',
					[
						'label' 		=> esc_html__( 'Padding', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .post_nav' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
		);
        $this->add_control(
			'nav_filter_title',
			[
				'label' => esc_html__( 'Title', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
					'nav_filter_color',
					[
						'label' 	=> esc_html__( 'Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .jws-blog-element .post_nav li a' => 'color: {{VALUE}} !important;',
						],
					]
		);
        $this->add_control(
					'nav_filter_color_active',
					[
						'label' 	=> esc_html__( 'Color Active', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .jws-blog-element .post_nav li a.filter-active' => 'color: {{VALUE}} !important;',
						],
					]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'nav_filter_typography',
				'label' => esc_html__( 'Typography', 'netfx'),
				'selector' => '{{WRAPPER}} .jws-blog-element .post_nav li a',
			]
		);
        $this->add_responsive_control(
					'nav_filter_padding_out',
					[
						'label' 		=> esc_html__( 'Padding Out', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .post_nav li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
		);
        $this->add_responsive_control(
					'nav_filter_padding_in',
					[
						'label' 		=> esc_html__( 'Padding In', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-blog-element .post_nav li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
		);
        $this->add_control(
			'nav_filter_line',
			[
				'label' => esc_html__( 'Line', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
			'line_filter_color',
			[
				'label' => esc_html__( 'Line Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .post_nav #magic_line' => 'background: {{VALUE}}',
                    '{{WRAPPER}} .jws-blog-element .post_nav li a.filter-active' => 'border-color: {{VALUE}}',
				],
			]
		);
         $this->add_responsive_control(
			'line_filter_height',
			[
				'label'     => esc_html__( 'Line Height', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'min' => 0,
						'max' => 20,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .jws-blog-element .post_nav #magic_line' => 'height:{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .jws-blog-element .post_nav li a' => 'border-width:{{SIZE}}{{UNIT}};',
				],
			]
		);

        $this->end_controls_section();
     }   
    	/**
	 * Register Woo posts Filter Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_content_filter_controls() {

		$this->start_controls_section(
			'section_filter_field',
			[
				'label' => esc_html__( 'Query', 'netfx' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
						'post_archive!' => [ 'yes' ],
                        'post_related!' => [ 'yes' ],
				],
			]
		);
        
        $this->add_control(
				'blog_per_page',
				[
					'label'     => esc_html__( 'posts Per Page', 'netfx' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => '8',
					'condition' => [
						'query_type!'  => 'main',
					],
				]
			);
		$this->add_control(
				'query_type',
				[
					'label'   => esc_html__( 'Source', 'netfx' ),
					'type'    => Controls_Manager::SELECT,
					'default' => 'all',
					'options' => [
						'all'    => esc_html__( 'All posts', 'netfx' ),
						'custom' => esc_html__( 'Custom Query', 'netfx' ),
						'manual' => esc_html__( 'Manual Selection', 'netfx' ),
					],
				]
			);

			$this->add_control(
				'category_filter_rule',
				[
					'label'     => esc_html__( 'Category Filter Rule', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'IN',
					'options'   => [
						'IN'     => esc_html__( 'Match Categories', 'netfx' ),
						'NOT IN' => esc_html__( 'Exclude Categories', 'netfx' ),
					],
					'condition' => [
						'query_type' => 'custom',
					],
				]
			);
			$this->add_control(
				'category_filter',
				[
					'label'     => esc_html__( 'Select Categories', 'netfx' ),
					'type'      => Controls_Manager::SELECT2,
					'multiple'  => true,
					'default'   => '',
					'options'   => $this->get_blog_categories(),
					'condition' => [
						'query_type' => 'custom',
					],
				]
			);
            
            
			$this->add_control(
				'tag_filter_rule',
				[
					'label'     => esc_html__( 'Tag Filter Rule', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'IN',
					'options'   => [
						'IN'     => esc_html__( 'Match Tags', 'netfx' ),
						'NOT IN' => esc_html__( 'Exclude Tags', 'netfx' ),
					],
					'condition' => [
						'query_type' => 'custom',
					],
				]
			);
			$this->add_control(
				'tag_filter',
				[
					'label'     => esc_html__( 'Select Tags', 'netfx' ),
					'type'      => Controls_Manager::SELECT2,
					'multiple'  => true,
					'default'   => '',
					'options'   => $this->get_blog_tags(),
					'condition' => [
						'query_type' => 'custom',
					],
				]
			);
			$this->add_control(
				'offset',
				[
					'label'       => esc_html__( 'Offset', 'netfx' ),
					'type'        => Controls_Manager::NUMBER,
					'default'     => 0,
					'description' => esc_html__( 'Number of post to displace or pass over.', 'netfx' ),
					'condition'   => [
						'query_type' => 'custom',
					],
				]
			);

			$this->add_control(
				'query_manual_ids',
				[
					'label'     => esc_html__( 'Select posts', 'netfx' ),
					'type'      => 'jws-query-posts',
					'post_type' => 'post',
					'multiple'  => true,
					'condition' => [
						'query_type' => 'manual',
					],
				]
			);

			/* Exclude */
			$this->add_control(
				'query_exclude',
				[
					'label'     => esc_html__( 'Exclude', 'netfx' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'query_type!' => [ 'manual', 'main' ],
					],
				]
			);
			$this->add_control(
				'query_exclude_ids',
				[
					'label'       => esc_html__( 'Select posts', 'netfx' ),
					'type'        => 'jws-query-posts',
					'post_type'   => 'post',
					'multiple'    => true,
					'description' => esc_html__( 'Select posts to exclude from the query.', 'netfx' ),
					'condition'   => [
						'query_type!' => [ 'manual', 'main' ],
					],
				]
			);
			$this->add_control(
				'query_exclude_current',
				[
					'label'        => esc_html__( 'Exclude Current post', 'netfx' ),
					'type'         => Controls_Manager::SWITCHER,
					'label_on'     => esc_html__( 'Yes', 'netfx' ),
					'label_off'    => esc_html__( 'No', 'netfx' ),
					'return_value' => 'yes',
					'default'      => '',
					'description'  => esc_html__( 'Enable this option to remove current post from the query.', 'netfx' ),
					'condition'    => [
						'query_type!' => [ 'manual', 'main' ],
					],
				]
			);

			/* Advanced Filter */
			$this->add_control(
				'query_advanced',
				[
					'label'     => esc_html__( 'Advanced', 'netfx' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'query_type!' => 'main',
					],
				]
			);
			$this->add_control(
				'filter_by',
				[
					'label'     => esc_html__( 'Filter By', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => '',
					'options'   => [
						''         => esc_html__( 'None', 'netfx' ),
						'featured' => esc_html__( 'Featured', 'netfx' ),
						'sale'     => esc_html__( 'Sale', 'netfx' ),
					],
					'condition' => [
						'query_type!' => 'main',
					],
				]
			);
			$this->add_control(
				'orderby',
				[
					'label'     => esc_html__( 'Order by', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'date',
					'options'   => [
						'date'       => esc_html__( 'Date', 'netfx' ),
						'title'      => esc_html__( 'Title', 'netfx' ),
						'price'      => esc_html__( 'Price', 'netfx' ),
						'popularity' => esc_html__( 'Popularity', 'netfx' ),
						'rating'     => esc_html__( 'Rating', 'netfx' ),
						'rand'       => esc_html__( 'Random', 'netfx' ),
						'menu_order' => esc_html__( 'Menu Order', 'netfx' ),
					],
					'condition' => [
						'query_type!' => 'main',
					],
				]
			);
			$this->add_control(
				'order',
				[
					'label'     => esc_html__( 'Order', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'desc',
					'options'   => [
						'desc' => esc_html__( 'Descending', 'netfx' ),
						'asc'  => esc_html__( 'Ascending', 'netfx' ),
					],
					'condition' => [
						'query_type!' => 'main',
					],
				]
			);

		$this->end_controls_section();
	}
    /**
	 * get content type
	 *
	 * @since 0.0.1
	 * @access protected
	 */
   	public function get_content_type() {
		$content_type = array(
			'content'              => esc_html__( 'Content', 'netfx' ),
			'menu'                 => esc_html__( 'Menu', 'netfx' ),
			'saved_rows'           => esc_html__( 'Saved Section', 'netfx' ),
			'saved_page_templates' => esc_html__( 'Saved Page', 'netfx' ),
			'logo' => esc_html__( 'Logo', 'netfx' ),
			'logout' => esc_html__( 'Logout', 'netfx' ),
			
		);

		if ( defined( 'ELEMENTOR_PRO_VERSION' ) ) {
			$content_type['saved_modules'] = esc_html__( 'Saved Widget', 'netfx' );
		}
		return $content_type;
	}
    /**
	 *  Get Saved Widgets
	 *
	 *  @param string $type Type.
	 *  @since 1.11.0
	 *  @return string
	 */
	public function get_saved_data( $type = 'page' ) {
		$saved_widgets = $this->get_post_template( $type );
		$options[-1]   = esc_html__( 'Select', 'netfx' );
		if ( count( $saved_widgets ) ) {
			foreach ( $saved_widgets as $saved_row ) {
				$options[ $saved_row['id'] ] = $saved_row['name'];
			}
		} else {
			$options['no_template'] = esc_html__( 'It seems that, you have not saved any template yet.', 'netfx' );
		}
		return $options;
	}

	/**
	 *  Get Templates based on category
	 *
	 *  @param string $type Type.
	 *  @since 1.11.0
	 *  @return string
	 */
	public function get_post_template( $type = 'page' ) {
		$posts = get_posts(
			array(
				'post_type'      => 'elementor_library',
				'orderby'        => 'title',
				'order'          => 'ASC',
				'posts_per_page' => '-1',
				'tax_query'      => array(
					array(
						'taxonomy' => 'elementor_library_type',
						'field'    => 'slug',
						'terms'    => $type,
					),
				),
			)
		);

		$templates = array();

		foreach ( $posts as $post ) {
			$templates[] = array(
				'id'   => $post->ID,
				'name' => $post->post_title,
			);
		}

		return $templates;
	}

	/**
	 * Register grid Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_content_grid_controls() {
		$this->start_controls_section(
			'section_grid_options',
			[
				'label'     => esc_html__( 'Grid Options', 'netfx' ),
				'type'      => Controls_Manager::SECTION,
			]
		);
		$this->add_responsive_control(
				'blog_columns',
				[
					'label'          => esc_html__( 'Columns', 'netfx' ),
					'type'           => Controls_Manager::SELECT,
					'default'        => '12',
					'options'        => [
						'12' => '1',
						'6' => '2',
						'4' => '3',
						'3' => '4',
						'20' => '5',
						'2' => '6',
					],
				]
			);
		$this->end_controls_section();
	}
      /**
	 * Register Pagination Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_content_pagination_controls() {

		$this->start_controls_section(
			'section_pagination_field',
			[
				'label'     => esc_html__( 'Pagination', 'netfx' ),
				'tab'       => Controls_Manager::TAB_CONTENT,
                'condition' => [
					'blog_display' => ['grid'],
				],
			]
		);
         $this->add_control(
				'pagination_align',
				[
					'label' 		=> esc_html__( 'Align', 'netfx' ),
					'type' 			=> Controls_Manager::CHOOSE,
					'options' 		=> [
						'left'    		=> [
							'title' 	=> esc_html__( 'Left', 'netfx' ),
							'icon' 		=> 'eicon-h-align-left',
						],
						'center' 		=> [
							'title' 	=> esc_html__( 'Center', 'netfx' ),
							'icon' 		=> 'eicon-h-align-center',
						],
						'right' 		=> [
							'title' 	=> esc_html__( 'Right', 'netfx' ),
							'icon' 		=> 'eicon-h-align-right',
						],
					],
                    'selectors' => [
							'{{WRAPPER}} .jws-pagination-number ul' => 'text-align: {{VALUE}};',
					],
					'frontend_available' => true,
				]
		);
		$this->add_control(
				'pagination_type',
				[
					'label'     => esc_html__( 'Type', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => '',
					'options'   => [
						''              => esc_html__( 'None', 'netfx' ),
                        'load_more' => esc_html__( 'Load More', 'netfx' ),
                        'pagination-number' => esc_html__( 'Number Pagination', 'netfx' ),
					],
				]
		);
        $this->add_control(
				'pagination_loadmore_label',
				[
					'label'     => esc_html__( 'Loadmore Label', 'netfx' ),
					'default'   => esc_html__( 'Load more posts', 'netfx' ),
					'condition' => [
						'pagination_type'      => ['load_more'],
					],
				]
		);
		$this->end_controls_section();
	}
    /**
	 * Register Slider Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_content_slider_controls() {
		$this->start_controls_section(
			'section_slider_options',
			[
				'label'     => esc_html__( 'Slider Options', 'netfx' ),
				'type'      => Controls_Manager::SECTION,
				'condition' => [
					'blog_display' => ['slider'],
				],
			]
		);

		$this->add_control(
			'navigation',
			[
				'label'     => esc_html__( 'Navigation', 'netfx' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'both',
				'options'   => [
                    'both' => esc_html__( 'Arrows And Dots', 'netfx' ),
					'arrows' => esc_html__( 'Arrows', 'netfx' ),
                    'dots' => esc_html__( 'Dots', 'netfx' ),
					'none'   => esc_html__( 'None', 'netfx' ),
				],
			]
		);
        $this->add_control(
			'arrow_style',
			[
				'label'     => esc_html__( 'Arrow Style', 'netfx' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
                    'default' => esc_html__( 'Default', 'netfx' ),
					'style2' => esc_html__( 'Style 2', 'netfx' ),
				],
			]
		);
        $this->add_control('arrow_position', [
                'label' => esc_html__('Arrow position', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT,
                'default' => 'arrow-center',
                'options' => [
                    'arrow-top' => esc_html__('Top', 'netfx'),
                    'arrow-center' => esc_html__('Middle', 'netfx'),
                ],
        ]);
		$this->add_responsive_control(
			'slides_to_show',
			[
				'label'          => esc_html__( 'posts to Show', 'netfx' ),
				'type'           => Controls_Manager::NUMBER,
				'default'        => 1,
				'tablet_default' => 1,
				'mobile_default' => 1,
			]
		);

		$this->add_responsive_control(
			'slides_to_scroll',
			[
				'label'          => esc_html__( 'posts to Scroll', 'netfx' ),
				'type'           => Controls_Manager::NUMBER,
				'default'        => 1,
				'tablet_default' => 1,
				'mobile_default' => 1,
			]
		);
        
		$this->add_control(
			'autoplay',
			[
				'label'        => esc_html__( 'Autoplay', 'netfx' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => '',
			]
		);
		$this->add_control(
			'autoplay_speed',
			[
				'label'     => esc_html__( 'Autoplay Speed', 'netfx' ),
				'type'      => Controls_Manager::NUMBER,
				'default'   => 5000,
				'selectors' => [
					'{{WRAPPER}} .slick-slide-bg' => 'animation-duration: calc({{VALUE}}ms*1.2); transition-duration: calc({{VALUE}}ms)',
				],
				'condition' => [
					'autoplay'             => 'yes',
				],
			]
		);
		$this->add_control(
			'pause_on_hover',
			[
				'label'        => esc_html__( 'Pause on Hover', 'netfx' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition'    => [
					'autoplay'             => 'yes',
				],
			]
		);

		$this->add_control(
			'infinite',
			[
				'label'        => esc_html__( 'Infinite Loop', 'netfx' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);
        $this->add_control(
			'rtl',
			[
				'label'        => esc_html__( 'Right To Left', 'netfx' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => '',
			]
		);
		$this->add_control(
			'transition_speed',
			[
				'label'     => esc_html__( 'Transition Speed (ms)', 'netfx' ),
				'type'      => Controls_Manager::NUMBER,
				'default'   => 500,
			]
		);
		$this->end_controls_section();
	}
    /**
	 * Register Post Format Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_content_post_format_controls() {

		$this->start_controls_section(
			'section_post_format_field',
			[
				'label'     => esc_html__( 'Posr Format Setting', 'netfx' ),
				'tab'       => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
				'gallery_heading',
				[
					'label'     => esc_html__( 'Gallery', 'netfx' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
				]
		);
        $this->add_control(
				'post_format_image_size',
				[
					'label'     => esc_html__( 'Image Size', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => '770x450',
				]
		);
		$this->end_controls_section();
	}
    /**
	 * Get WooCommerce post Categories.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function get_blog_categories() {

		$blog_cat = array();

		$cat_args = array(
			'orderby'    => 'name',
			'order'      => 'asc',
			'hide_empty' => false,
		);

		$blog_categories = get_terms( 'category', $cat_args );

		if ( ! empty( $blog_categories ) ) {

			foreach ( $blog_categories as $key => $category ) {
				$blog_cat[ $category->term_id ] = $category->name;
			}
		}

		return $blog_cat;
	}
    /**
	 * Get WooCommerce post Tags.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function get_blog_tags() {

		$blog_tag = array();

		$tag_args = array(
			'orderby'    => 'name',
			'order'      => 'asc',
			'hide_empty' => false,
		);

		$blog_tag = get_terms( 'post_tag', $tag_args );

		if ( ! empty( $blog_tag ) ) {

			foreach ( $blog_tag as $key => $tag ) {

				$blog_tag[ $tag->term_id ] = $tag->name;
			}
		}

		return $blog_tag;
	}
    	/**
	 * Render Content Type classes names.
	 *
	 * @since 1.11.0
	 * @param array $settings The settings array.
	 * @param int   $node_id The node id.
	 * @return string Concatenated string of classes
	 * @access public
	 */
	public function get_override_content() {
	   $settings = $this->get_settings();
		$content_type     = $settings['content_type'];
		$dynamic_settings = $this->get_settings_for_display();

		switch ( $content_type ) {
			case 'content':
				global $wp_embed;
				return '<div class="jws-text-editor elementor-inline-editing" data-elementor-setting-key="ct_content" data-elementor-inline-editing-toolbar="advanced">' . wpautop( $wp_embed->autoembed( $settings['ct_content'] ) ) . '</div>';
			break;

			case 'menu':
				$menu_content = $this->get_menu_html( $settings);
				return $menu_content;
			break;

			case 'saved_rows':
				return \Elementor\Plugin::$instance->frontend->get_builder_content_for_display( $settings['ct_saved_rows'] );
			break;

			case 'saved_modules':
				return \Elementor\Plugin::$instance->frontend->get_builder_content_for_display( $settings['ct_saved_modules'] );

			case 'saved_page_templates':
				return \Elementor\Plugin::$instance->frontend->get_builder_content_for_display( $settings['ct_page_templates'] );
			break;
			default:
				return;
			break;
		}
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings();


			global $post;

			$query_args = [
				'post_type'      => 'post',
				'post_status'    => 'publish',
				'posts_per_page' => -1,
				'paged'          => 1,
				'post__not_in'   => array(),
			];
            // Default ordering args.
			$query_args['orderby'] = $settings['orderby'];
			$query_args['order']   = $settings['order'];
		    if ( $settings['blog_per_page'] > 0 ) {
					$query_args['posts_per_page'] = $settings['blog_per_page'];
			}
			if ( '' !== $settings['pagination_type'] ) {

					$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : '1';


					$query_args['paged'] = $paged;
                    
			}


			if ( 'custom' === $settings['query_type'] ) {

				if ( ! empty( $settings['category_filter'] ) ) {

					$cat_operator = $settings['category_filter_rule'];

					$query_args['tax_query'][] = [
						'taxonomy' => 'category',
						'field'    => 'id',
						'terms'    => $settings['category_filter'],
						'operator' => $cat_operator,
					];
				}

				if ( ! empty( $settings['tag_filter'] ) ) {

					$tag_operator = $settings['tag_filter_rule'];

					$query_args['tax_query'][] = [
						'taxonomy' => 'post_tag',
						'field'    => 'id',
						'terms'    => $settings['tag_filter'],
						'operator' => $tag_operator,
					];
				}

				if ( 0 < $settings['offset'] ) {

					/**
					 * Offset break the pagination. Using WordPress's work around
					 *
					 * @see https://codex.wordpress.org/Making_Custom_Queries_using_Offset_and_Pagination
					 */
					$query_args['offset_to_fix'] = $settings['offset'];
				}
			}

			if ( 'manual' === $settings['query_type'] ) {

				$manual_ids = $settings['query_manual_ids'];

				$query_args['post__in'] = $manual_ids;
			}

			if ( 'manual' !== $settings['query_type'] && 'main' !== $settings['query_type'] ) {

				if ( '' !== $settings['query_exclude_ids'] ) {

					$exclude_ids = $settings['query_exclude_ids'];

					$query_args['post__not_in'] = $exclude_ids;
				}

				if ( 'yes' === $settings['query_exclude_current'] && isset($post->ID) ) {

					$query_args['post__not_in'][] = $post->ID;
				}
			}


			$blog = new \WP_Query( $query_args );
            
            
        
      $class_row = 'row blog-content';  
      $class_row .= ' jws-blog-'.$settings['blog_layouts'].'';
      $class_row .= ' blog-ajax-'.$this->get_id().'';
      $class_row.= ' jws-isotope'; 
      if ( $blog->max_num_pages > 1) { $class_row.= ' jws_has_pagination'; }
      
      $class_column = 'jws-blog-item';
      
           $class_column .= ' col-xl-'.$settings['blog_columns'].'';
          $class_column .= (!empty($settings['blog_columns_tablet'])) ? ' col-md-'.$settings['blog_columns_tablet'].'' : ' col-md-'.$settings['blog_columns'].'' ;
          $class_column .= (!empty($settings['blog_columns_mobile'])) ? ' col-'.$settings['blog_columns_mobile'].'' :  ' col-'.$settings['blog_columns'].'';
     
 
      
      if($settings['blog_display'] == 'slider') {
            $class_row .= ' jws_blog_'.$settings['blog_display'].'';
            $class_row .= ' ' . $settings['arrow_position'];
            $class_column .= ' slick-slide';
            $dots = ($settings['navigation'] == 'dots' || $settings['navigation'] == 'both') ? 'true' : 'false';
            $arrows = ($settings['navigation'] == 'arrows' || $settings['navigation'] == 'both') ? 'true' : 'false';
            $autoplay = ($settings['autoplay'] == 'yes') ? 'true' : 'false';
            $pause_on_hover = ($settings['pause_on_hover'] == 'yes') ? 'true' : 'false';
            $infinite = ($settings['infinite'] == 'yes') ? 'true' : 'false';
            $rtl = ($settings['rtl'] == 'yes') ? 'true' : 'false';
            
            $autoplay_speed = ($settings['autoplay_speed']) ? $settings['autoplay_speed'] : '0';
            $data_slick = 'data-slick=\'{"slidesToShow":'.$settings['slides_to_show'].' ,"slidesToScroll": '.$settings['slides_to_scroll'].',"rtl":'.$rtl.', "autoplay": '.$autoplay.',"arrows": '.$arrows.', "dots":'.$dots.', "autoplaySpeed": '.$autoplay_speed.',"pauseOnHover":'.$pause_on_hover.',"infinite":'.$infinite.',
            "speed": '.$settings['transition_speed'].', "responsive":[{"breakpoint": 1024,"settings":{"slidesToShow": '.$settings['slides_to_show_tablet'].',"slidesToScroll": '.$settings['slides_to_scroll_tablet'].'}},
            {"breakpoint": 768,"settings":{"slidesToShow": '.$settings['slides_to_show_mobile'].',"slidesToScroll": '.$settings['slides_to_scroll_mobile'].'}}]}\''; 
       }else {
            $data_slick = '';
             
       }
       if($settings['enable_masonry'] == 'yes') {
            $class_row .= ' has-masonry';
       }
       
       if($settings['enable_animation'] == 'yes') {
            $class_row .= ' has-animation';
            $class_column .= ' jws-ani-item';
       }
        $order=1;
        
        if($settings['blog_layouts'] == 'layout3'){
            wp_enqueue_script('addthis-widget'); 
        }
       
      ?>
        
        
		
		<div class="jws-blog-element<?php if($settings['post_nav_on'] == 'yes') echo esc_attr(' has-nav'); ?>">
            <?php if($settings['post_nav_on'] == 'yes') : 
                wp_enqueue_script('anime');
                $taxonomy_names = get_object_taxonomies('post');
                if((isset($settings['category_filter_rule']) && $settings['category_filter_rule'] != 'IN') && 'custom' === $settings['query_type']) {
                   $cats = get_categories(array(
                       'orderby' => 'name',
                       'exclude' => $settings['category_filter'],
                   ));  
                } elseif((isset($settings['category_filter_rule']) && $settings['category_filter_rule'] == 'IN') && 'custom' === $settings['query_type']) {
                   $cats = get_categories( array(
                       'orderby' => 'name',
                       'include' => $settings['category_filter'],
                    ));
                }else {
                    $cats  = get_categories( array(
                        'orderby' => 'name',
                        'parent'  => 0
                    ) );
                }
                
            ?>
            <div class="post-nav-container">
                <ul class="post-nav">
                    <li><a href="#" data-filter="*" class="filter-active"><?php echo (!empty($settings['post_text_first'])) ? $settings['post_text_first'] : esc_html__('All CATEGORIES', 'netfx'); ?></a></li>
                    <?php
                        foreach ($cats as $cat) {
                            ?>
                                <li><a href="#" data-filter="<?php echo "." . esc_attr($cat->slug); ?>"><?php echo esc_html($cat->name); ?></a></li>
                            <?php
                        }
                    ?>
                </ul>
            </div>   
            <?php endif; ?> 
            <div class="<?php echo esc_attr($class_row); ?>" <?php echo wp_kses_post($data_slick); ?>>
                <?php 
                    if($settings['post_archive'] == 'yes') {
                       if (have_posts()) {
                            while ( have_posts() ) :
                        			the_post();
                                     
                                     $format = has_post_format() ? get_post_format() : 'no_format';  
                                     $has_image= (!has_post_thumbnail()&&$format!='link' && $format!='quote' && $format!='audio')? ' no-image': ' has-image';
                                      echo '<article class="'.$class_column.' '.$format.$has_image.'">';
                         
                                               include( 'layout/'.$settings['blog_layouts'].'.php' );
                                               if ($order==3):?>
                                    
                                             <div class="get_override_content">
                                                	<?php echo do_shortcode( $this->get_override_content( $settings['content_type']) ); ?>
                                                    <span class="close-popup">
                                                            <i aria-hidden="true" class="lnr lnr-cross"></i>                            
                                                    </span>
                                            </div>
   
                                        <?php endif;  echo '</article>';
                                        $order++;
                            endwhile;    
                            wp_reset_postdata();      
                       }else{
                            get_template_part( 'template-parts/content/content', 'none' );
                       }
                    }elseif($settings['post_related'] == 'yes'){

                        $related = get_posts( array( 'category__in' => wp_get_post_categories($post->ID), 'numberposts' => 100,'post_type' => 'post','posts_per_page' => $settings['blog_per_page_related'], 'post__not_in' => array($post->ID) ) );
              
                        if( isset($related[0]) ) foreach( $related as $post ) {
                        setup_postdata($post); 
                         $format = has_post_format() ? get_post_format() : 'no_format';  
                        $has_image= (!has_post_thumbnail()&&$format!='link' && $format!='quote' && $format!='audio')? ' no-image': ' has-image';
                          echo '<article class="'.$class_column.' '.$format.$has_image.'">';
                                               include( 'layout/'.$settings['blog_layouts'].'.php' );
                            echo '</article>';      
                        
                        }
                        wp_reset_postdata();     
                    }else {
                     $i = 1; if ($blog->have_posts()) :
                            while ( $blog->have_posts() ) :
                        			$blog->the_post();
                                    $class_slug = '';
                                    if($settings['post_nav_on'] == 'yes') {
                                        $item_cats = get_the_terms(get_the_ID(), 'category');
                                        if ($item_cats):
                                            foreach ($item_cats as $item_cat) {
                                                $class_slug .= ' '.$item_cat->slug;
                                            }
                                        endif;    
                                    }
                                    $format = has_post_format() ? get_post_format() : 'no_format';  
                                    $has_image= (!has_post_thumbnail()&&$format!='link' && $format!='quote' && $format!='audio')? ' no-image': ' has-image';
                                        echo '<article class="'.$class_column.' '.$format.$class_slug.$has_image.'">';
                         
                                               include( 'layout/'.$settings['blog_layouts'].'.php' );
                                               
                                        echo '</article>';
                             if ($i == 9) {
                                  $i = 1;
                             } else {
                                  $i++;
                             } endwhile;    
                            wp_reset_postdata();
                           
                       endif;  
                    }
                     
                ?>
            </div>
            
            <?php
                global $wp_query;
                if($settings['post_archive'] == 'yes') { 
                   $number_page = $wp_query->max_num_pages;
                   $pagi_number = jws_query_pagination($wp_query);
                   $url = get_next_posts_page_link( $wp_query->max_num_pages );
                }else {
                   $number_page = $blog->max_num_pages;
                   $pagi_number = jws_query_pagination($blog);
                   $url = get_next_posts_page_link( $wp_query->max_num_pages ); 
                }
 
           ?>
            <?php if ( $number_page > 1 && $settings['pagination_type'] == 'load_more' ) {
                 wp_enqueue_script( 'masonry');
                 $load_attr = 'data-ajaxify-options=\'{"wrapper":".blog_ajax_'.$this->get_id().'","items":"> .jws-blog-item","trigger":"click"}\''; 
                ?>
                <div class="jws_pagination jws_ajax">
                    <a class="jws-load-more" data-ajaxify="true"  href="<?php echo add_query_arg( 'ajaxify', '1', $url); ?>" <?php echo wp_kses_post($load_attr); ?>>
                        <span class="has-loading"><?php echo esc_html($settings['pagination_loadmore_label']); ?></span>
                       <span class="has-loaded"><?php echo esc_html__('All items loaded ','netfx'); ?></span> 
                </a>
                </div>
            <?php }elseif($number_page > 1 && $settings['pagination_type'] == 'pagination-number'){
                      echo wp_kses_post($pagi_number);   
                  }  
            ?>
        </div>

	<?php }
    
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}
}