<?php

namespace Elementor;
use Elementor\Core\Schemes\Typography;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Color;

/**
 * CleverblogAdvanced
 *
 * @author CleverSoft <hello.cleversoft@gmail.com>
 * @package jws
 */
if (class_exists('WooCommerce')):
    final class Blog_Tab extends Widget_Base
    {
        /**
         * @return string
         */
        function get_name()
        {
            return 'jws_blog_tab';
        }

        /**
         * @return string
         */
        function get_title()
        {
            return esc_html__('Jws Blog Tab', 'netfx');
        }

        /**
         * @return string
         */
        function get_icon()
        {
            return 'cs-font clever-icon-cart-3';
        }
        /**
         * @return array
         */
        public function get_categories()
        {
            return ['clever-woocommerce-elements'];
        }
        /**
         * Register controls
         */
        protected function _register_controls()
        {
            $this->start_controls_section(
                'section_setting', [
                'label' => esc_html__('Setting', 'netfx')
            ]);

            $this->add_control('title', [
                'label' => esc_html__('Title', 'netfx'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Jws Blog', 'netfx'),
            ]);

            $this->add_control('layout_type', [
                'label' => esc_html__('layout_type', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT,
                'default' => 'grid',
                'options' => [
                    'grid' => esc_html__('Grid', 'netfx'),
                    'carousel' => esc_html__('Carousel', 'netfx'),
                ],
            ]);
            	$this->add_control(
				'blogs_layouts',
                
				[
					'label'     => esc_html__( 'Layouts', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'layout1',
					'options'   => [
						'layout1'   => esc_html__( 'layout 1', 'netfx' ),
						'layout2'   => esc_html__( 'layout 2', 'netfx' ),
                        'layout3'   => esc_html__( 'layout 3', 'netfx' ),
					],
				]
			);
            $this->add_control('display', [
                'label' => esc_html__('Display', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT,
                'default' => 'blog',
                'options' => [
                    'blog' => esc_html__('Blog', 'netfx'),
                    'rent' => esc_html__('Rental', 'netfx'),
                ],
            ]);

            $this->add_control('tab_blogs', [
                'label' => esc_html__('tab', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none' => esc_html__('None', 'netfx'),
                    'cate' => esc_html__('Category', 'netfx'),
                    'asset' => esc_html__('Asset type', 'netfx'),
                ],

            ]);
            $this->add_control(
				'title_length',
				[
					'label'     => esc_html__( 'Title Length', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => '',
				]
			);
            $this->add_control(
				'blog_image_size',
				[
					'label'     => esc_html__( 'Image Size', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => 'full',
				]
		  );
            $this->add_control(
				'post_format_image_size',
				[
					'label'     => esc_html__( 'Image Size', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => '420x250',
				]
		);
          $this->add_control(
    			'show_readmore',
    			[
    				'label' => esc_html__( 'Show Read More', 'netfx' ),
    				'type' => Controls_Manager::SWITCHER,
    				'default' => 'yes',
    				'label_off' => esc_html__( 'Off', 'netfx' ),
    				'label_on' => esc_html__( 'On', 'netfx' ),
    			]
    		);
            $this->add_control(
				'excerpt_length',
				[
					'label'     => esc_html__( 'Excerpt Length', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => '',
				]
			);
             $this->add_control(
				'excerpt_more',
				[
					'label'     => esc_html__( 'Excerpt More', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => ' ... ',
				]
			);
            $this->add_control(
				'readmore_text',
				[
					'label'     => esc_html__( 'Read More Text', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => 'Read More',
				]
			);
            $this->add_control(
				'icon',
				[
					'label' => esc_html__( 'Read More Icon', 'netfx' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'fab fa-wordpress',
                		'library' => 'fa-brands',
					],
				]
		  );
            $this->end_controls_section();

            $this->start_controls_section(
                'section_options', [
                'label' => esc_html__('Options', 'netfx')
            ]);
            //Cate
            $this->add_control('tab_categories', [
                'label' => esc_html__('Categories', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT2,
                'default' => '',
                'multiple' => true,
                'options' => $this->get_categories_for_jws('category', 2),
                'condition' => [
                    'tab_blogs' => ['none', 'cate'],
                ],
            ]);
            $this->add_control('default_category', [
                'label' => esc_html__('Default categories', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => $this->get_categories_for_jws('category'),
                'condition' => [
                    'tab_blogs' => 'cate',
                ],
            ]);
            $this->add_control( 'ajax_load', [
                'label'   => esc_html__( 'Ajax Load', 'netfx' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'condition'     => [
                    'tab_blogs' => 'cate',
                ],
            ] );
            $this->add_control('asset_type', [
                'label' => esc_html__('Asset type', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT,
                'default' => 'all',
                'options' => $this->get_woo_asset_type_for_jws(),
                'condition' => [
                    'tab_blogs' => ['none', 'cate'],
                ],
            ]);

            // Asset
            $this->add_control('tab_assets', [
                'label' => esc_html__('Asset type', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT2,
                'default' => '',
                'multiple' => true,
                'options' => $this->get_woo_asset_type_for_jws(2),
                'condition' => [
                    'tab_blogs' => 'asset',
                ],
            ]);
            $this->add_control('default_asset', [
                'label' => esc_html__('Default asset', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT,
                'default' => '',
                'options' => $this->get_woo_asset_type_for_jws(),
                'condition' => [
                    'tab_blogs' => 'asset',
                ],
            ]);
            $this->add_control('tab_categories_for_asset', [
                'label' => esc_html__('Categories', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT2,
                'default' => '',
                'multiple' => true,
                'options' => $this->get_categories_for_jws('category', 2),
                'condition' => [
                    'tab_blogs' => 'asset',
                ],
            ]);

            // tab default
            $this->add_control('blog_ids', [
                'label' => esc_html__(' Blog IDs', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->get_list_posts('blog'),
            ]);
            	$this->add_control(
				'query_exclude_ids',
				[
					'label'       => esc_html__( 'Select posts exclude', 'netfx' ),
					'type'        => 'jws-query-posts',
					'post_type'   => 'post',
					'multiple'    => true,
					'description' => esc_html__( 'Select posts to exclude from the query.', 'netfx' ),
					
				]
			);
            $this->add_control('orderby', [
                'label' => esc_html__('Order by', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => $this->get_blog_order_by_for_jws(),
            ]);
            $this->add_control('order', [
                'label' => esc_html__('Order', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => $this->get_woo_order_for_jws(),
            ]);

            $this->add_control('posts_per_page', [
                'label' => esc_html__('blogs per pages', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::NUMBER,
                'default' => 6,
            ]);
            // Grid
            $this->add_responsive_control('columns', [
                'label' => esc_html__('Columns for row', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT,
                'default' => '4',
                'options' => [
                    '12' => esc_html__('1', 'netfx'),
                    '6' => esc_html__('2', 'netfx'),
                    '4' => esc_html__('3', 'netfx'),
                    '3' => esc_html__('4', 'netfx'),
                    '20' => esc_html__('5', 'netfx'),
                    '2' => esc_html__('6', 'netfx'),
                ],

            ]);

            $this->add_control('pagination', [
                'label' => esc_html__('Pagination', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none' => esc_html__('None', 'netfx'),
                    'numeric' => esc_html__('Numeric', 'netfx'),
                    'ajaxload' => esc_html__('Ajax Load More', 'netfx'),
                    'infinity' => esc_html__('Infinity Scroll', 'netfx'),
                ],
                'condition' => [
                    'layout_type' => 'grid',
                    'tab_blogs' => 'none',
                ],
            ]);
             // Carousel
            $this->add_responsive_control('slides_to_show', [
                'label' => esc_html__('Slides to Show', 'netfx'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 10,
                    ]
                ],
                'devices' => ['desktop', 'tablet', 'mobile'],
                'desktop_default' => [
                    'size' => 4,
                    'unit' => 'px',
                ],
                'tablet_default' => [
                    'size' => 3,
                    'unit' => 'px',
                ],
                'mobile_default' => [
                    'size' => 2,
                    'unit' => 'px',
                ],
                'condition' => [
                    'layout_type' => 'carousel',
                ],

            ]);


            $this->add_control('speed', [
                'label' => esc_html__('Carousel: Speed to Scroll', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'layout_type' => 'carousel',
                ],

            ]);
            $this->add_control('scroll', [
                'label' => esc_html__('Carousel: Slide to Scroll', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::NUMBER,
                'default' => 1,
                'condition' => [
                    'layout_type' => 'carousel',
                ],
            ]);
            $this->add_responsive_control('autoplay', [
                'label' => esc_html__('Carousel: Auto Play', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'netfx'),
                'label_off' => esc_html__('Hide', 'netfx'),
                'return_value' => 'true',
                'default' => 'true',
                'condition' => [
                    'layout_type' => 'carousel',
                ],
            ]);
            $this->add_responsive_control('show_pag', [
                'label' => esc_html__('Carousel: Pagination', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'netfx'),
                'label_off' => esc_html__('Hide', 'netfx'),
                'return_value' => 'true',
                'default' => 'true',
                'condition' => [
                    'layout_type' => 'carousel',
                ],
            ]);
            $this->add_responsive_control('show_nav', [
                'label' => esc_html__('Carousel: Navigation', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'netfx'),
                'label_off' => esc_html__('Hide', 'netfx'),
                'return_value' => 'true',
                'default' => 'true',
                'condition' => [
                    'layout_type' => 'carousel',
                ],
            ]);
            $this->add_control('nav_position', [
                'label' => esc_html__('Carousel: Navigation position', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT,
                'default' => 'arrow-center',
                'options' => [
                    'arrow-top' => esc_html__('Top', 'netfx'),
                    'arrow-center' => esc_html__('Middle', 'netfx'),
                ],
                'condition' => [
                    'show_nav' => 'true',
                    'layout_type' => 'carousel',
                ],

            ]);

            $this->end_controls_section();
            $this->register_content_pagination_controls();   
             $this->register_style_pagination_controls();  
            $this->start_controls_section(
			'section_design_layout',
			[
				'label' => esc_html__( 'layout_type', 'netfx' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'column_gap',
			[
				'label'     => esc_html__( 'Columns Gap', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
				'default'   => [
                    'unit' => 'px',
					'size' => 30,
				],
				'range'     => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
                    '%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .blogs .jws-blog-item' => 'padding-right: calc( {{SIZE}}{{UNIT}}/2 ); padding-left: calc( {{SIZE}}{{UNIT}}/2 );',
					'{{WRAPPER}} .blogs' => 'margin-left: calc( -{{SIZE}}{{UNIT}}/2 ); margin-right: calc( -{{SIZE}}{{UNIT}}/2 );',
                    '{{WRAPPER}} .blogs .slick-slide' => 'padding-top:0; padding-bottom:0;',
				],
			]
		);

		$this->add_responsive_control(
			'row_gap',
			[
				'label'     => esc_html__( 'Rows Gap', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
				'default'   => [
					'size' => 35,
				],
				'range'     => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .blogs .jws-blog-item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);
        $this->add_responsive_control('content_inner_padding', [
                'label' => esc_html__('Content Inner Padding', 'netfx'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .jws-blog-item .jws-blog-item-inner .blog-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);


		$this->end_controls_section();
            $this->start_controls_section(
                'normal_style_settings', [
                'label' => esc_html__('Heading style', 'netfx'),
                'netfx' => Controls_Manager::TAB_STYLE,
            ]);

            $this->add_control('title_colors', [
                'label' => esc_html__('Color', 'netfx'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .jws-title' => 'color: {{VALUE}};'
                ]
            ]);
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'selector' => '{{WRAPPER}} .jws-title',
                    'scheme' => Typography::TYPOGRAPHY_1,
                ]
            );
            $this->add_control('title_background', [
                'label' => esc_html__('Background', 'netfx'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .jws-title' => 'background: {{VALUE}};'
                ]
            ]);


            $this->end_controls_section();
           	
            $this->start_controls_section(
                'tab_style_settings', [
                'label' => esc_html__('tab style', 'netfx'),
                'netfx' => Controls_Manager::TAB_STYLE,
            ]);
            $this->add_responsive_control(
                'tab_align',
                [
                    'label' => esc_html__('Align', 'netfx'),
                    'type' => Controls_Manager::CHOOSE,
                    'options' => [
                        'left' => [
                            'title' => esc_html__('Left', 'netfx'),
                            'icon' => 'fa fa-align-left',
                        ], 'center' => [
                            'title' => esc_html__('Center', 'netfx'),
                            'icon' => 'fa fa-align-center',
                        ],
                        'right' => [
                            'title' => esc_html__('Right', 'netfx'),
                            'icon' => 'fa fa-align-right',
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .jws-head-blog-tab' => 'text-align: {{VALUE}};'
                    ]
                ]
            );
            $this->add_control('tab_color', [
                'label' => esc_html__('Color', 'netfx'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .jws-head-blog-tab a' => 'color: {{VALUE}};'
                ]
            ]);
            $this->add_control('tab_active_color', [
                'label' => esc_html__('Active Color', 'netfx'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .jws-head-blog-tab a.active, {{WRAPPER}} .jws-head-blog-tab a:hover' => 'color: {{VALUE}};'
                ]
            ]);
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'tab_typography',
                    'selector' => '{{WRAPPER}} .jws-head-blog-tab a',
                    'scheme' => Typography::TYPOGRAPHY_1,
                ]
            );

            $this->add_responsive_control('tab_space', [
                'label' => esc_html__('Space', 'netfx'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .jws-head-blog-tab li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);
            $this->add_responsive_control('tab_padding', [
                'label' => esc_html__('Padding', 'netfx'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .jws-head-blog-tab' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);
            $this->end_controls_section();
            $this->start_controls_section(
                'carousel_style_settings', [
                'label' => esc_html__('Carousel style', 'netfx'),
                'netfx' => Controls_Manager::TAB_STYLE,
            ]);
            $this->add_control('arrow_style', [
                'label' => esc_html__('Arrow', 'netfx'),
                'type' => Controls_Manager::HEADING,
            ]);
            $this->add_control('arrow_color', [
                'label' => esc_html__('Color', 'netfx'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .jws_blogs_slider .jws_blogs_slider-btn' => 'color: {{VALUE}};'
                ]
            ]);
            $this->add_control(
				'arrow_postion',
				[
					'label'     => esc_html__( 'Arrow Postion', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'arrow-top',
					'options'   => [
						'arrow-top'   => esc_html__( 'Top', 'netfx' ),
						'arrow-center'   => esc_html__( 'Center', 'netfx' ),
					],
                    
				]
			);            
            $this->add_control('arrow_hover_color', [
                'label' => esc_html__('Hover Color', 'netfx'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .jws_blogs_slider .jws_blogs_slider-btn:hover' => 'color: {{VALUE}};'
                ]
            ]);
            $this->add_control('arrow_size', [
                'label' => esc_html__('Size', 'netfx'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .jws_blogs_slider .jws_blogs_slider-btn' => 'padding-left: {{SIZE}}{{UNIT}};',
                ],
            ]);
            $this->add_control('dotted_style', [
                'label' => esc_html__('Dotted', 'netfx'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]);
            $this->add_control('dotted_color', [
                'label' => esc_html__('Color', 'netfx'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .jws_blogs_slider ul.slick-dots li' => 'background: {{VALUE}};'
                ]
            ]);
            $this->add_control('dotted_hover_color', [
                'label' => esc_html__('Hover & Active Color', 'netfx'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .jws_blogs_slider ul.slick-dots li:hover, {{WRAPPER}} .jws_blogs_slider ul.slick-dots li.slick-active' => 'background: {{VALUE}};'
                ]
            ]);
            $this->add_control('dotted_size', [
                'label' => esc_html__('Size', 'netfx'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .jws_blogs_slider ul.slick-dots li' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .jws_blogs_slider ul.slick-dots li.slick-active' => 'width: calc({{SIZE}}{{UNIT}} * 3);',
                ],
            ]);
            $this->add_control('dotted_radius', [
                'label' => esc_html__('Border radius', 'netfx'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .jws_blogs_slider ul.slick-dots li' => 'border-radius: {{SIZE}}{{UNIT}};'
                ],
            ]);
            $this->end_controls_section();
            
             $this->register_style_info_controls();  
        }
        
            protected function register_style_info_controls() {
		$this->start_controls_section(
			'section_design_info',
			[
				'label' => esc_html__( 'blog Item', 'netfx' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
        $this->start_controls_tabs( 'info_tabs_style' );

		$this->start_controls_tab(
				'info_normal',
				[
					'label'     => esc_html__( 'Normal', 'netfx' ),
				]
		);
        $this->add_control(
					'background_color_item',
					[
						'label' 	=> esc_html__( 'Background Color blog Item', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws-blog-item-inner' => 'color: {{VALUE}};',
                            '{{WRAPPER}} .jws-blog-item-inner' => 'background: {{VALUE}};',
						],
					]
		);
        $this->add_control(
					'cat_color',
					[
						'label' 	=> esc_html__( 'Category Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .cat-list a ' => 'color: {{VALUE}};',
                            '{{WRAPPER}} .cat-list span' => 'background: {{VALUE}};',
						],
					]
		);
        $this->add_control(
					'title_color',
					[
						'label' 	=> esc_html__( 'Title Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .woocommerce-loop-blog__title a' => 'color: {{VALUE}};',
						],
					]
		);
       
        $this->add_control(
			'blog_select',
			[
				'label' => esc_html__( 'Button Select Size', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition' => [
    				'blogs_layouts' => ['layout6'],
    			],
			]
		);
        $this->add_control(
					'select_color',
					[
						'label' 	=> esc_html__( 'Button Select Size Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_blogs .jws_blogs_item .jws_content_blog .jws_choose_option' => 'color: {{VALUE}};',
						],
                        'condition' => [
    					   'blogs_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_control(
					'select_bgcolor',
					[
						'label' 	=> esc_html__( 'Button Select Size Background Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_blogs .jws_blogs_item .jws_content_blog .jws_choose_option' => 'background-color: {{VALUE}};',
						],
                        'condition' => [
    					   'blogs_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'select_border',
					'label' 	=> esc_html__( 'Button Select Size Border', 'netfx' ),
					'selector' => 	'{{WRAPPER}} .jws_blogs .jws_blogs_item .jws_content_blog .jws_choose_option , {{WRAPPER}} .jws_blogs .jws_blogs_item.selectoptions-show .jws_item_inner .selectoptions-swap .variations',
                    'condition' => [
					   'blogs_layouts' => ['layout6'],
				    ],
				]
		);
        $this->add_control(
					'select_sub_color',
					[
						'label' 	=> esc_html__( 'Sub Option Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_blogs .jws_blogs_item.selectoptions-show .jws_item_inner .selectoptions-swap .variations .tawcvs-swatches .swatch' => 'color: {{VALUE}};',
						],
                        'condition' => [
    					   'blogs_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_control(
					'select_sub_bgcolor',
					[
						'label' 	=> esc_html__( 'Sub Option Background', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_blogs .jws_blogs_item.selectoptions-show .jws_item_inner .selectoptions-swap .variations' => 'background-color: {{VALUE}};',
						],
                        'condition' => [
    					   'blogs_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_control(
					'select_sub_avtive_color',
					[
						'label' 	=> esc_html__( 'Sub ACtive Option Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_blogs .jws_blogs_item.selectoptions-show .jws_item_inner .selectoptions-swap .variations  .tawcvs-swatches .swatch.selected' => 'color: {{VALUE}};',
						],
                        'condition' => [
    					   'blogs_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_control(
					'select_sub_avtive_bgcolor',
					[
						'label' 	=> esc_html__( 'Sub ACtive Option Background', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_blogs .jws_blogs_item.selectoptions-show .jws_item_inner .selectoptions-swap .variations  .tawcvs-swatches .swatch.selected' => 'background-color: {{VALUE}};',
						],
                        'condition' => [
    					   'blogs_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_control(
					'wishlist_color',
					[
						'label' 	=> esc_html__( 'Wishlist Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
                            '{{WRAPPER}} .jws_blogs_item .jws_image_thumbnail_blog .blog-wishlist-button a' => 'color: {{VALUE}};',
						],
					]
		);
        $this->add_control(
					'overlay',
					[
						'label' 	=> esc_html__( 'Overlay Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_blogs .jws_blogs_item .jws_image_thumbnail_blog .overlay_image_thumbnail_blog' => 'background: {{VALUE}};',
						],
					]
		);
        $this->end_controls_tab();

		$this->start_controls_tab(
				'info_hover',
				[
					'label'     => esc_html__( 'Hover', 'netfx' ),
				]
		);
         $this->add_control(
					'cat_color_hover',
					[
						'label' 	=> esc_html__( 'Category Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .cat-list a:hover ' => 'color: {{VALUE}};',
						],
					]
		);
        $this->add_control(
					'title_color_hover',
					[
						'label' 	=> esc_html__( 'Title Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .woocommerce-loop-blog__title a:hover' => 'color: {{VALUE}};',
						],
					]
		);
        $this->add_control(
			'blog_icon_hover',
			[
				'label' => esc_html__( 'Icon', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
					'icon_color_hover',
					[
						'label' 	=> esc_html__( 'Icon Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_blogs_item  .jws_inner_button li a:hover' => 'color: {{VALUE}};',
                            '{{WRAPPER}} .jws_blogs.jws_blogs_layout3 .jws_blogs_item .add_to_cart_button:hover' => 'color: {{VALUE}};',
						],
					]
		);
        $this->add_control(
					'icon_bgcolor_hover',
					[
						'label' 	=> esc_html__( 'Icon Background Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_blogs_item .jws_inner_button li a:hover' => 'background-color: {{VALUE}};',
                            '{{WRAPPER}} .jws_blogs.jws_blogs_layout3 .jws_blogs_item .add_to_cart_button:hover' => 'background-color: {{VALUE}};',
						],
					]
		);
        $this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'icon_border_hover',
					'label' 	=> esc_html__( 'Icon Border', 'netfx' ),
					'selector' 	=> '{{WRAPPER}} .jws_blogs_item  .jws_inner_button li a:hover',
				]
		);
        $this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'icon_border_2_hover',
					'label' 	=> esc_html__( 'Icon Border', 'netfx' ),
					'selector' => 	'{{WRAPPER}} .jws_blogs.jws_blogs_layout3 .jws_blogs_item .add_to_cart_button:hover',
                    'condition' => [
					   'blogs_layouts' => 'layout3',
				    ],
				]
		);
       
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->add_control(
			'blog_title',
			[
				'label' => esc_html__( 'Title', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'blog_title_typography',
				'label' => esc_html__( 'Typography', 'netfx'),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .jws_blogs .jws_blogs_item .jws_content_blog .jws_content_center_blog h2 a',
			]
		);
        $this->add_control(
			'category',
			[
				'label' => esc_html__( 'Category', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'category_typography',
				'label' => esc_html__( 'Typography', 'netfx'),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .cat-list a',

			]
		);
       
		$this->end_controls_section();
	}
     	protected function register_content_pagination_controls() {

		$this->start_controls_section(
			'section_pagination_field',
			[
				'label'     => esc_html__( 'Pagination', 'netfx' ),
				'tab'       => Controls_Manager::TAB_CONTENT,
			]
		);

			$this->add_control(
				'pagination_type',
				[
					'label'     => esc_html__( 'Type', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => '',
					'options'   => [
						''              => esc_html__( 'None', 'netfx' ),
						'numbers'       => esc_html__( 'Numbers', 'netfx' ),
						'arrow' => esc_html__( 'Pre/Next Arrow', 'netfx' ),
                        'load_more' => esc_html__( 'Load More', 'netfx' ),
                        'view_all' => esc_html__( 'View All', 'netfx' ),
					],
				]
			);
             $this->add_control(
    			'show_line_pagination',
    			[
    				'label' => esc_html__( 'Show line', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::SWITCHER,
    				'label_on' => esc_html__( 'Show', 'netfx' ),
    				'label_off' => esc_html__( 'Hide', 'netfx' ),
    				'return_value' => 'yes',
    				'default' => 'yes',
                    'condition' => [
						'pagination_type'      => ['view_all'],
					],
    			]
    		);
            $this->add_control(
				'pagination_loadmore_label',
				[
					'label'     => esc_html__( 'Loadmore & View All Label', 'netfx' ),
					'default'   => esc_html__( 'MORE blogS', 'netfx' ),
					'condition' => [
						'pagination_type'      => ['load_more','view_all'],
					],
				]
			);
            $this->add_control(
			'view_link',
			[
				'label' => esc_html__( 'Link', 'netfx' ),
				'type' => Controls_Manager::URL,
				'placeholder' => esc_html__( 'View All Url', 'netfx' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
                'condition' => [
						'pagination_type'      => 'view_all',
				],
			]
		);
            $this->add_control(
				'pagination_loadmore_label2',
				[
					'label'     => esc_html__( 'All blog Loaded.', 'netfx' ),
					'default'   => esc_html__( 'All blogs are displayed', 'netfx' ),
					'condition' => [
						'pagination_type'      => 'load_more',
					],
				]
			);
            $this->add_control(
				'arrow_layouts',
				[
					'label'     => esc_html__( 'layouts', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'layout1',
					'options'   => [
						'layout1'   => esc_html__( 'layout 1', 'netfx' ),
						'layout2'   => esc_html__( 'layout 2', 'netfx' ),
					],
                    'condition' => [
    						'pagination_type'      => 'arrow',
					],
				]
			);
            $this->add_control(
				'icon_spacing',
				[
					'label' 		=> esc_html__( 'Icon Spacing', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 150,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .jws_blog_pagination' => 'top: -{{SIZE}}px;',
					],
                    'condition' => [
    						'pagination_type'      => 'arrow',
                            'arrow_layouts' => 'layout1'
					],
				]
		  );
			$this->add_control(
					'icon_prev',
					[
						'label' 		=> esc_html__( 'Icon Prev', 'netfx' ),
						'type' 			=> Controls_Manager::ICON,
						'label_block' 	=> false,
						'default' 		=> 'fa fa-chevron-left',
                        'condition' => [
    						'pagination_type'      => 'arrow',
					   ],
					]
		  );
		  	$this->add_control(
					'icon_next',
					[
						'label' 		=> esc_html__( 'Icon Next', 'netfx' ),
						'type' 			=> Controls_Manager::ICON,
						'label_block' 	=> false,
						'default' 		=> 'fa fa-chevron-right',
                        'condition' => [
    						'pagination_type'      => 'arrow',
					   ],
					]
		  );

		$this->end_controls_section();
	}
    protected function register_style_pagination_controls() {

$this->start_controls_section(
	'section_design_pagination',
	[
		'label'     => esc_html__( 'Pagination', 'netfx' ),
		'tab'       => Controls_Manager::TAB_STYLE,
		'condition' => [
			
			'pagination_type!'     => '',
		],
	]
);

$this->start_controls_tabs( 'pagination_tabs_style' );

	$this->start_controls_tab(
		'pagination_normal',
		[
			'label'     => esc_html__( 'Normal', 'netfx' ),
			'condition' => [
				
				'pagination_type!'     => '',
			],
		]
	);

		$this->add_control(
			'pagination_color',
			[
				'label'     => esc_html__( 'Text Color', 'netfx' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => Color::get_type(),
					'value' => Color::COLOR_4,
				],
				'selectors' => [
					'{{WRAPPER}} .jws_blog_pagination  .jws-blogs-load-more a , {{WRAPPER}} .jws_blog_pagination .jws-blogs-view-all a , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li a , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li' => 'color: {{VALUE}};',
				],
				'condition' => [
					
					'pagination_type!'     => '',
				],
			]
		);

		$this->add_control(
			'pagination_background_color',
			[
				'label'     => esc_html__( 'Background Color', 'netfx' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws_blog_pagination .jws-blogs-load-more a , {{WRAPPER}} .jws_blog_pagination .jws-blogs-view-all a , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					
					'pagination_type!'     => '',
				],
			]
		);

		$this->add_control(
			'pagination_border_color',
			[
				'label'     => esc_html__( 'Border Color', 'netfx' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => Color::get_type(),
					'value' => Color::COLOR_4,
				],
				'selectors' => [
					'{{WRAPPER}} .jws_blog_pagination  .jws-blogs-load-more span , {{WRAPPER}} .jws_blog_pagination .jws-blogs-view-all span' => 'border-color: {{VALUE}};',
				],
				'condition' => [
					
					'pagination_type!'     => '',
				],
			]
		);

	$this->end_controls_tab();

	$this->start_controls_tab(
		'pagination_hover',
		[
			'label'     => esc_html__( 'Hover', 'netfx' ),
			'condition' => [
				
				'pagination_type!'     => '',
			],
		]
	);

		$this->add_control(
			'pagination_hover_color',
			[
				'label'     => esc_html__( 'Text Active / Hover Color', 'netfx' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .jws_blog_pagination  .jws-blogs-load-more span:hover , {{WRAPPER}} .jws_blog_pagination .jws-blogs-view-all span:hover , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li .current  , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li .prev , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li .next , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li a:hover ' => 'color: {{VALUE}};',
				],
				'condition' => [
					
					'pagination_type!'     => '',
				],
			]
		);

		$this->add_control(
			'pagination_background_hover_color',
			[
				'label'     => esc_html__( 'Background Hover Color', 'netfx' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => Color::get_type(),
					'value' => Color::COLOR_4,
				],
				'selectors' => [
					'{{WRAPPER}} .jws_blog_pagination .jws-blogs-load-more span:hover , {{WRAPPER}} .jws_blog_pagination .jws-blogs-view-all span:hover , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li .current, {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li .prev , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li .next, {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li a:hover' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					
					'pagination_type!'     => '',
				],
			]
		);

		$this->add_control(
			'pagination_border_hover_color',
			[
				'label'     => esc_html__( 'Border Hover Color', 'netfx' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => Color::get_type(),
					'value' => Color::COLOR_4,
				],
				'selectors' => [
					'{{WRAPPER}} .jws_blog_pagination .jws-blogs-load-more span:hover , {{WRAPPER}} .jws_blog_pagination .jws-blogs-view-all span:hover' => 'border-color: {{VALUE}};',
				],
				'condition' => [
					
					'pagination_type!'     => '',
				],
			]
		);

	$this->end_controls_tab();
    
    $this->end_controls_tabs();
    
    $this->add_group_control(
    	Group_Control_Typography::get_type(),
    	[
    		'name'      => 'pagination_typography',
    		'selector'  => '{{WRAPPER}} .jws_blog_pagination .jws-blogs-load-more span ,{{WRAPPER}} .jws_blog_pagination .jws-blogs-load-more span:before, {{WRAPPER}} .jws_blog_pagination .jws-blogs-view-all span, {{WRAPPER}} .jws_blog_pagination .jws-blogs-view-all span:before',
    		'condition' => [
    			
    			'pagination_type!'     => '',
    		],
    
    	]
    );
    
    $this->add_group_control(
    	Group_Control_Border::get_type(),
    	[
    		'name' => 'pagination_blog_border',
    		'label' => esc_html__( 'Border', 'netfx' ),
    		'selector' => '{{WRAPPER}} .jws_blog_pagination  .jws-blogs-load-more span , {{WRAPPER}} .jws_blog_pagination .jws-blogs-view-all span',
    	]
    );
    $this->add_control(
    			'pagination_radius',
    			[
    				'type' 			=> Controls_Manager::DIMENSIONS,
    				'label' 		=> esc_html__( 'Border Radius', 'netfx' ),
    				'size_units' 	=> [ 'px', '%' ],
    				'selectors' 	=> [
    					'{{WRAPPER}} .jws_blog_pagination  .jws-blogs-load-more span , {{WRAPPER}} .jws_blog_pagination .jws-blogs-view-all span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
    				],
    			]
    );
     $this->add_control(
    			'pagination_padding',
    			[
    				'type' 			=> Controls_Manager::DIMENSIONS,
    				'label' 		=> esc_html__( 'Padding', 'netfx' ),
    				'size_units' 	=> [ 'px', '%' ],
    				'selectors' 	=> [
    					'{{WRAPPER}} .jws_blog_pagination  .jws-blogs-load-more span , {{WRAPPER}} .jws_blog_pagination .jws-blogs-view-all span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
    				],
    			]
    );
    $this->add_control(
    			'pagination_margin',
    			[
    				'type' 			=> Controls_Manager::DIMENSIONS,
    				'label' 		=> esc_html__( 'Margin', 'netfx' ),
    				'size_units' 	=> [ 'px', '%' ],
    				'selectors' 	=> [
    					'{{WRAPPER}} .jws_blog_pagination' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
    				],
    			]
    );
    $this->add_control(
    'pagination_blog_align',
    		[
    			'label' 		=> esc_html__( 'Align', 'netfx' ),
    			'type' 			=> Controls_Manager::CHOOSE,
    			'default' 		=> 'left',
    			'options' 		=> [
    				'left'    		=> [
    					'title' 	=> esc_html__( 'Left', 'netfx' ),
    					'icon' 		=> 'eicon-h-align-left',
    				],
    				'center' 		=> [
    					'title' 	=> esc_html__( 'Center', 'netfx' ),
    					'icon' 		=> 'eicon-h-align-center',
    				],
    				'right' 		=> [
    					'title' 	=> esc_html__( 'Right', 'netfx' ),
    					'icon' 		=> 'eicon-h-align-right',
    				],
    			],
    			'selectors' => [
    					'{{WRAPPER}} .jws_blog_pagination' => 'text-align: {{VALUE}};',
    			],
    			'frontend_available' => true,
    		]
    );
    $this->end_controls_section();
    }

        /**
         * Load style
         */
        public function get_style_depends()
        {
            return ['jws-style'];
        }

        /**
         * Retrieve the list of scripts the image carousel widget depended on.
         *
         * Used to set scripts dependencies required to run the widget.
         *
         * @since 1.3.0
         * @access public
         *
         * @return array Widget scripts dependencies.
         */
        public function get_script_depends()
        {
            return ['jws-script'];
        }
              protected function get_categories_for_jws($taxonomy, $select = 1)
        {
            $data = array();
    
            $query = new \WP_Term_Query(array(
                'hide_empty' => true,
                'taxonomy'   => $taxonomy,
            ));
            if ($select == 1) {
                $data['all'] = 'All';
            }
    
            if (! empty($query->terms)) {
                foreach ($query->terms as $cat) {
                    $data[ $cat->slug ] = $cat->name;
                }
            }
    
            return $data;
        }
        protected function get_woo_asset_type_for_jws($select = 1)
        {
        if ($select == 1) {
            $asset_type = array(
                'all'          => esc_html__('All', 'netfx'),
                'latest'       => esc_html__('New Arrivals', 'netfx'),
                'featured'     => esc_html__('Featured', 'netfx'),
                'onsale'       => esc_html__('On sale', 'netfx'),
                'deal'         => esc_html__('Deal', 'netfx'),
                'best-selling' => esc_html__('Best Seller', 'netfx'),
                'toprate'      => esc_html__('Top Rate', 'netfx'),
            );
        } else {
            $asset_type = array(
                'latest'       => esc_html__('New Arrivals', 'netfx'),
                'featured'     => esc_html__('Featured', 'netfx'),
                'onsale'       => esc_html__('On sale', 'netfx'),
                'deal'         => esc_html__('Deal', 'netfx'),
                'best-selling' => esc_html__('Best Seller', 'netfx'),
                'toprate'      => esc_html__('Top Rate', 'netfx'),
            );
        }

        return $asset_type;
        }
        protected function get_list_posts($post_type = 'post')
        {
            $args = array(
                'post_type'        => $post_type,
                'suppress_tabs' => true,
                'posts_per_page'   => 300,
                'no_found_rows'    => true,
            );
    
            $the_query = new \WP_Query($args);
            $results   = [];
    
            if (is_array($the_query->posts) && count($the_query->posts)) {
                foreach ($the_query->posts as $post) {
                    $results[ $post->ID ] = sanitize_text_field($post->post_title);
                }
            }
    
            return $results;
        }
            /**
     * Get oder by
     *
     * @return array oder_by
     */
    protected function get_blog_order_by_for_jws()
    {
        $order_by = array(
            'date'       => esc_html__('Date', 'netfx'),
            'menu_order' => esc_html__('Menu order', 'netfx'),
            'title'      => esc_html__('Title', 'netfx'),
            'rand'       => esc_html__('Random', 'netfx'),
        );

        return $order_by;
    }

    /**
     * Get oder
     *
     * @return array order
     */
    protected function get_woo_order_for_jws()
    {
        $order = array(
            'desc' => esc_html__('DESC', 'netfx'),
            'asc'  => esc_html__('ASC', 'netfx'),
        );

        return $order;
    }
        /**
         * Render
         */
        protected function render()
        {
            // default settings
            $settings = array_merge([
                'title' => '',
                'tab_blogs' => 'cate',
                'tab_categories' => '',
                'default_category' => '',
                'asset_type' => 'all',
                'tab_assets' => '',
                'default_asset' => '',
                'blog_ids' => '',
                'orderby' => 'date',
                'order' => 'desc',
                'posts_per_page' => 6,
                'columns' => '',
                'pagination' => '',
                'slides_to_show' => 4,
                'speed' => 5000,
                'scroll' => 1,
                'autoplay' => 'true',
                'show_pag' => 'true',
                'show_nav' => 'true',
                'nav_position' => 'middle-nav',
               

            ], $this->get_settings_for_display());

            $this->add_inline_editing_attributes('title');

            $this->add_render_attribute('title', 'class', 'jws-title');

            include 'content.php';
        }
    }
endif;