<?php
namespace Elementor;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Heading_Content extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'jws_heading_content';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Jws Heading and Content section', 'netfx' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-site-search';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'jws-elements' ];
	}


	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
	    $this->start_controls_section(
			'setting_section',
			[
				'label' => esc_html__( 'Setting', 'netfx' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        
        $this->end_controls_section();
        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'netfx' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
			'heading_tagline',
			[
				'label' => esc_html__( 'Tagline', 'netfx' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Default title', 'netfx' ),
				'placeholder' => esc_html__( 'Type your title here', 'netfx' ),
			]
		);
        $this->add_control(
			'heading_tagline_tag',
			[
				'label' => esc_html__( 'Layout', 'netfx' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'span',
				'options' => [
					'h1'  => esc_html__( 'H1', 'netfx' ),
                    'h2'  => esc_html__( 'H2', 'netfx' ),
                    'h3'  => esc_html__( 'H3', 'netfx' ),
                    'h4'  => esc_html__( 'H4', 'netfx' ),
                    'h5'  => esc_html__( 'H5', 'netfx' ),
                    'h6'  => esc_html__( 'H6', 'netfx' ),
                    'span'  => esc_html__( 'span', 'netfx' ),
                    'p'  => esc_html__( 'p', 'netfx' ),
				],
			]
		);
        $this->add_control(
			'heading_title',
			[
				'label' => esc_html__( 'Title', 'netfx' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'default' => esc_html__( 'Default title', 'netfx' ),
				'placeholder' => esc_html__( 'Type your title here', 'netfx' ),
			]
		);
        $this->add_control(
			'heading_title_tag',
			[
				'label' => esc_html__( 'Layout', 'netfx' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'h2',
				'options' => [
					'h1'  => esc_html__( 'H1', 'netfx' ),
                    'h2'  => esc_html__( 'H2', 'netfx' ),
                    'h3'  => esc_html__( 'H3', 'netfx' ),
                    'h4'  => esc_html__( 'H4', 'netfx' ),
                    'h5'  => esc_html__( 'H5', 'netfx' ),
                    'h6'  => esc_html__( 'H6', 'netfx' ),
                    'span'  => esc_html__( 'span', 'netfx' ),
                    'p'  => esc_html__( 'p', 'netfx' ),
				],
			]
		);
        
        $this->add_control(
			'heading_content',
			[
				'label' => esc_html__( 'Content', 'netfx' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => esc_html__( 'Default description', 'netfx' ),
				'placeholder' => esc_html__( 'Type your description here', 'netfx' ),
			]
		);
        
        $this->add_control(
			'entrance_animation',
			[
				'label' => esc_html__( 'Entrance Animation Scroll Down', 'netfx' ),
				'type' => \Elementor\Controls_Manager::ANIMATION,
                'default' => 'fadeInDown'
			]
		);

         $this->add_control(
    			'show_tagline',
    			[
    				'label' => esc_html__( 'Show Tag Line', 'netfx' ),
    				'type' => Controls_Manager::SWITCHER,
    				'default' => 'yes',
    				'label_off' => esc_html__( 'Off', 'netfx' ),
    				'label_on' => esc_html__( 'On', 'netfx' ),
    			]
    		);
            $this->add_control(
    			'show_heading_title',
    			[
    				'label' => esc_html__( 'Show Heading Title', 'netfx' ),
    				'type' => Controls_Manager::SWITCHER,
    				'default' => 'yes',
    				'label_off' => esc_html__( 'Off', 'netfx' ),
    				'label_on' => esc_html__( 'On', 'netfx' ),
    			]
    		);
            $this->add_control(
    			'show_content',
    			[
    				'label' => esc_html__( 'Show Content', 'netfx' ),
    				'type' => Controls_Manager::SWITCHER,
    				'default' => 'off',
    				'label_off' => esc_html__( 'Off', 'netfx' ),
    				'label_on' => esc_html__( 'On', 'netfx' ),
    			]
    		);
            
            
        $this->add_responsive_control(
				'align',
				[
					'label' 		=> esc_html__( 'Align', 'netfx' ),
					'type' 			=> Controls_Manager::CHOOSE,
					'default' 		=> 'center',
					'options' 		=> [
						'left'    		=> [
							'title' 	=> esc_html__( 'Left', 'netfx' ),
							'icon' 		=> 'eicon-h-align-left',
						],
						'center' 		=> [
							'title' 	=> esc_html__( 'Center', 'netfx' ),
							'icon' 		=> 'eicon-h-align-center',
						],
						'right' 		=> [
							'title' 	=> esc_html__( 'Right', 'netfx' ),
							'icon' 		=> 'eicon-h-align-right',
						],
					],
                    'selectors' => [
							'{{WRAPPER}} .jws_heading' => 'text-align: {{VALUE}};',
					],
					'frontend_available' => true,
				]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'icon_section',
			[
				'label' => esc_html__( 'Icon', 'netfx' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
				'icon',
				[
					'label' => esc_html__( 'Icon', 'netfx' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'fab fa-wordpress',
                		'library' => 'fa-brands',
					],
				]
		);
     
		$this->end_controls_section();
        $this->start_controls_section(
			'heading_style',
			[
				'label' => esc_html__( 'heading', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        $this->add_control(
			'heading_background',
			[
				'label' => esc_html__( 'Background', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws_heading' => 'background: {{VALUE}}',
				],
			]
		);
        $this->add_responsive_control(
					'heading_padding',
					[
						'label' 		=> esc_html__( 'Padding', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws_heading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->add_responsive_control(
					'heading_radius',
					[
						'label' 		=> esc_html__( 'Border Radius', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws_heading' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'heading_shadow',
				'label' => esc_html__( 'heading Shadow', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws_heading',
			]
		);
		$this->end_controls_section();
        $this->start_controls_section(
			'heading_content_tagline_style',
			[
				'label' => esc_html__( 'Tagline', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'heading_tagline_style',
			[
				'label' => esc_html__( 'Tagline', 'netfx' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
			'tagline_color',
			[
				'label' => esc_html__( 'Tagline Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws_heading .heading-tagline' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'tagline_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws_heading .heading-tagline',
			]
		);
        $this->add_control(
				'tagline_opacity',
				[
					'label' 		=> esc_html__( 'Opacity', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .jws_heading .heading-tagline' => 'opacity: {{SIZE}}1;',
					],
				]
		);
        $this->add_responsive_control(
				'tagline_spacing',
				[
					'label' 		=> esc_html__( 'Spacing', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .jws_heading .heading-tagline' => 'margin-bottom: {{SIZE}}px;',
					],
				]
		);
        $this->add_responsive_control(
					'tagline_padding',
					[
						'label' 		=> esc_html__( 'Tagline Padding', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws_tagline' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->end_controls_section();
        //heading title
        $this->start_controls_section(
			'heading_title_style',
			[
				'label' => esc_html__( 'Title', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Title Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws_heading .heading-title' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws_heading .heading-title',
			]
		);
        $this->add_responsive_control(
				'title_spacing',
				[
					'label' 		=> esc_html__( 'Spacing', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .jws_heading .heading-title' => 'margin-bottom: {{SIZE}}px;',
					],
				]
		);
        $this->add_responsive_control(
					'title_padding',
					[
						'label' 		=> esc_html__( 'Title Padding', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .heading-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->end_controls_section();
       
        //Content
        $this->start_controls_section(
			'content_content_style',
			[
				'label' => esc_html__( 'Content', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'content_style',
			[
				'label' => esc_html__( 'Conent', 'netfx' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
			'content_color',
			[
				'label' => esc_html__( 'Conent Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '',
				'selectors' => [
					'{{WRAPPER}} .jws_heading .content' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws_heading .content',
			]
		);
        $this->add_responsive_control(
				'content_spacing',
				[
					'label' 		=> esc_html__( 'Spacing', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .jws_heading .content' => 'margin-top: {{SIZE}}px;',
					],
				]
		);
        $this->add_responsive_control(
					'content_padding',
					[
						'label' 		=> esc_html__( 'Content Padding', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->end_controls_section();
       
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
	   
		$settings = $this->get_settings_for_display();
         if ( !empty ($settings['entrance_animation'] )) {
            $animation = $settings['entrance_animation'];
        }else {
            $animation = 'none';
        } 

        ?>
            <div class="jws_heading" data-animations="<?php echo esc_attr($animation) ?>">
                <div class="jws_heading_inner">
                   
                 <?php if ($settings['show_tagline'] && $settings['heading_tagline'] && !empty($settings['heading_tagline'])):?>
                    
                    <?php echo '<'.$settings['heading_tagline_tag'] ?> class="heading-tagline">
                        <?php echo ''.$settings['heading_tagline']; ?>
                      <?php echo '</'.$settings['heading_tagline_tag'].'>' ?>
                <?php endif;?>
                
              
                <?php if ($settings['show_heading_title'] && $settings['heading_title'] && !empty($settings['heading_title'])):?>
                     <?php echo '<'.$settings['heading_title_tag'] ?> class="heading-title">
                       <?php echo ''.$settings['heading_title']; ?>
                      <?php echo '</'.$settings['heading_title_tag'].'>' ?>
                <?php endif;?>
                <?php if ($settings['show_content'] && $settings['heading_content'] && !empty($settings['heading_content'])):?>
                    <div class="content">
                        <?php echo wp_kses_post($settings['heading_content']); ?>
                    </div>
                <?php endif;?>
                
                </div>

            </div>
        <?php

	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}
}