<?php
namespace Elementor;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Jws_Gallery extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'jws_gallery';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Jws Gallery', 'netfx' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-gallery-grid';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'jws-elements' ];
	}
 

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
	    $this->start_controls_section(
			'setting_section',
			[
				'label' => esc_html__( 'Setting', 'netfx' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
				'gallery_display',
				[
					'label'     => esc_html__( 'Display', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'grid',
					'options'   => [
						'grid'   => esc_html__( 'Grid', 'netfx' ),
                        'metro'   => esc_html__( 'Metro', 'netfx' ),
						'slider'   => esc_html__( 'Slider', 'netfx' ),
					],
                    
				]
		);
        $this->add_control(
				'link_action',
				[
					'label'     => esc_html__( 'Link Action', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'lightbox',
					'options'   => [
						'lightbox'   => esc_html__( 'Light Box', 'netfx' ),
                        'linkurl'   => esc_html__( 'Link Href', 'netfx' ),
					],
                    
				]
	     );
        $this->add_control(
			'gallery_layout',
			[
				'label' => esc_html__( 'Layout', 'netfx' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'layout1',
				'options' => [
					'layout1'  => esc_html__( 'Layout 1', 'netfx' ),
                    'layout2'  => esc_html__( 'Layout Demo', 'netfx' ),
				],
			]
		);
        $this->add_responsive_control(
				'gallery_columns',
				[
					'label'          => esc_html__( 'Columns', 'netfx' ),
					'type'           => Controls_Manager::SELECT,
					'default'        => '12',
					'options'        => [
						'12' => '1',
						'6' => '2',
						'4' => '3',
						'3' => '4',
						'20' => '5',
						'2' => '6',
					],
				]
		);
        $this->add_control(
				'image_size',
				[
					'label'     => esc_html__( 'Image Size', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => '770x450',
				]
		);
        $this->add_control(
				'image_size2',
				[
					'label'     => esc_html__( 'Image Size 2', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => '770x450',
                    'condition'	=> [
						'gallery_display' => ['metro'],
				    ],
				]
		);
        $this->add_control(
				'image_size3',
				[
					'label'     => esc_html__( 'Image Size 3', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => '770x450',
                    'condition'	=> [
						'gallery_display' => ['metro'],
				    ],
				]
		);
        $this->end_controls_section();   
	    $this->start_controls_section(
			'setting_section_list',
			[
				'label' => esc_html__( 'gallery List', 'netfx' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);   
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
			'image',
			[
				'label' => esc_html__( 'Choose Image', 'netfx' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);
        
        $repeater->add_control(
			'link_url',
			[
				'label' => esc_html__( 'Link', 'netfx' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'netfx' ),
				'show_external' => true,
				'default' => [
					'url' => '#',
				],
			]
		);
        
        
        $this->add_control(
			'list',
			[
				'label' => esc_html__( 'Menu List', 'netfx' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				
			]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'setting_navigation',
			[
				'label' => esc_html__( 'Setting Navigation', 'netfx' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
    				'enable_nav',
    				[
    					'label'        => esc_html__( 'Enable Nav', 'netfx' ),
    					'type'         => Controls_Manager::SWITCHER,
    					'label_on'     => esc_html__( 'Yes', 'netfx' ),
    					'label_off'    => esc_html__( 'No', 'netfx' ),
    					'return_value' => 'yes',
    					'default'      => 'yes',
    					'description'  => esc_html__( 'Enable nav arrow.', 'netfx' ),
    				]
    	);
        $this->add_control(
			'nav_position',
			[
				'label'     => esc_html__( 'Nav Position', 'netfx' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'out',
				'options'   => [
                    'out' => esc_html__( 'Out Side', 'netfx' ),
					'in' => esc_html__( 'In Side', 'netfx' ),
				],
                'condition'	=> [
					'enable_nav' => 'yes',
				],
			]
		);
        $this->add_control(
    				'enable_dots',
    				[
    					'label'        => esc_html__( 'Enable Dots', 'netfx' ),
    					'type'         => Controls_Manager::SWITCHER,
    					'label_on'     => esc_html__( 'Yes', 'netfx' ),
    					'label_off'    => esc_html__( 'No', 'netfx' ),
    					'return_value' => 'yes',
    					'default'      => 'yes',
    					'description'  => esc_html__( 'Enable dot.', 'netfx' ),
    				]
    	);
        $this->add_control(
			'dots_position',
			[
				'label'     => esc_html__( 'Dots Position', 'netfx' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'out',
				'options'   => [
                    'out' => esc_html__( 'Out Side', 'netfx' ),
					'in' => esc_html__( 'In Side', 'netfx' ),
				],
                'condition'	=> [
				    'enable_dots' => 'yes',
				],
			]
		);
        $this->add_control(
			'dots_color',
			[
				'label' => esc_html__( 'Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws_gallery_element .jws_gallery .flickity-page-dots li.is-selected' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .jws_gallery_element .jws_gallery .flickity-page-dots li:before' => 'background: {{VALUE}}',
				],
			]
		);
        $this->end_controls_section();  
        $this->start_controls_section(
			'box_style',
			[
				'label' => esc_html__( 'Box', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_responsive_control(
			'column_gap',
			[
				'label'     => esc_html__( 'Columns Gap', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .jws_gallery .jws_gallery_item' => 'padding-right: calc( {{SIZE}}{{UNIT}}/2 ); padding-left: calc( {{SIZE}}{{UNIT}}/2 );',
					'{{WRAPPER}} .jws_gallery_element .row' => 'margin-left: calc( -{{SIZE}}{{UNIT}}/2 ); margin-right: calc( -{{SIZE}}{{UNIT}}/2 );',
				],
			]
		);

		$this->add_responsive_control(
			'row_gap',
			[
				'label'     => esc_html__( 'Rows Gap', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .jws_gallery .jws_gallery_item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);
        $this->end_controls_section();
        	$this->start_controls_section(
			'section_slider_options',
			[
				'label'     => esc_html__( 'Slider Options', 'netfx' ),
				'type'      => Controls_Manager::SECTION,
				'condition' => [
					'gallery_display' => ['slider'],
				],
			]
		);

		$this->add_control(
			'navigation',
			[
				'label'     => esc_html__( 'Navigation', 'netfx' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'both',
				'options'   => [
                    'both' => esc_html__( 'Arrows And Dots', 'netfx' ),
					'arrows' => esc_html__( 'Arrows', 'netfx' ),
                    'dots' => esc_html__( 'Dots', 'netfx' ),
					'none'   => esc_html__( 'None', 'netfx' ),
				],
			]
		);
        
        $this->add_control(
			'cssEase',
			[
				'label'     => esc_html__( 'cssEase', 'netfx' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'linear',
				'options'   => [
                    'linear' => esc_html__( 'Linear', 'netfx' ),
					'ease' => esc_html__( 'Ease', 'netfx' ),
                    'ease-in-out' => esc_html__( 'Ease in out', 'netfx' ),
					'ease-in'   => esc_html__( 'Ease in', 'netfx' ),
                    'ease-out'   => esc_html__( 'Ease out', 'netfx' ),
				],
			]
		);

		$this->add_responsive_control(
			'slides_to_show',
			[
				'label'          => esc_html__( 'posts to Show', 'netfx' ),
				'type'           => Controls_Manager::NUMBER,
				'default'        => 1,
				'tablet_default' => 1,
				'mobile_default' => 1,
			]
		);

		$this->add_responsive_control(
			'slides_to_scroll',
			[
				'label'          => esc_html__( 'posts to Scroll', 'netfx' ),
				'type'           => Controls_Manager::NUMBER,
				'default'        => 1,
				'tablet_default' => 1,
				'mobile_default' => 1,
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'        => esc_html__( 'Autoplay', 'netfx' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => '',
			]
		);
		$this->add_control(
			'autoplay_speed',
			[
				'label'     => esc_html__( 'Autoplay Speed', 'netfx' ),
				'type'      => Controls_Manager::NUMBER,
				'default'   => 5000,
				'selectors' => [
					'{{WRAPPER}} .slick-slide-bg' => 'animation-duration: calc({{VALUE}}ms*1.2); transition-duration: calc({{VALUE}}ms)',
				],
				'condition' => [
					'autoplay'             => 'yes',
				],
			]
		);
		$this->add_control(
			'pause_on_hover',
			[
				'label'        => esc_html__( 'Pause on Hover', 'netfx' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition'    => [
					'autoplay'             => 'yes',
				],
			]
		);

		$this->add_control(
			'infinite',
			[
				'label'        => esc_html__( 'Infinite Loop', 'netfx' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$this->add_control(
			'transition_speed',
			[
				'label'     => esc_html__( 'Transition Speed (ms)', 'netfx' ),
				'type'      => Controls_Manager::NUMBER,
				'default'   => 500,
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
	   
		$settings = $this->get_settings_for_display();
        if($settings['gallery_display'] != 'slider') {
           wp_enqueue_script('isotope');
        }   
        
          $class_column = 'jws_gallery_item';
          $class_column .= ' col-xl-'.$settings['gallery_columns'].'';
          $class_column .= (!empty($settings['gallery_columns_tablet'])) ? ' col-lg-'.$settings['gallery_columns_tablet'].'' : ' col-lg-'.$settings['gallery_columns'].'' ;
          $class_column .= (!empty($settings['gallery_columns_mobile'])) ? ' col-'.$settings['gallery_columns_mobile'].'' :  ' col-'.$settings['gallery_columns'].''; 
          $class_row = 'jws_gallery gallery row '.$settings['gallery_layout']; 
          $class_row .= ' '.$settings['gallery_display']; 
          
          $class_row .= ' dots-'.$settings['dots_position'];
          $class_row .= ' navs-'.$settings['nav_position'];

          
          if($settings['gallery_display'] == 'slider') {
                $class_row .= ' jws-slider';
                $class_column .= ' slider-item'; 
                $dots = ($settings['navigation'] == 'dots' || $settings['navigation'] == 'both') ? 'true' : 'false';
                $arrows = ($settings['navigation'] == 'arrows' || $settings['navigation'] == 'both') ? 'true' : 'false';
                $autoplay = ($settings['autoplay'] == 'yes') ? 'true' : 'false';
                $pause_on_hover = ($settings['pause_on_hover'] == 'yes') ? 'true' : 'false';
                $infinite = ($settings['infinite'] == 'yes') ? 'true' : 'false';
                $autoplay_speed = ($settings['autoplay_speed']) ? $settings['autoplay_speed'] : '0';
                $data_slick = 'data-slick=\'{"slidesToShow":'.$settings['slides_to_show'].' ,"cssEase":"'.$settings['cssEase'].'","slidesToScroll": '.$settings['slides_to_scroll'].', "autoplay": '.$autoplay.',"arrows": '.$arrows.', "dots":'.$dots.', "autoplaySpeed": '.$autoplay_speed.',"pauseOnHover":'.$pause_on_hover.',"infinite":'.$infinite.',
                "speed": '.$settings['transition_speed'].', "responsive":[{"breakpoint": 1024,"settings":{"slidesToShow": '.$settings['slides_to_show_tablet'].',"slidesToScroll": '.$settings['slides_to_scroll_tablet'].'}},
                {"breakpoint": 768,"settings":{"slidesToShow": '.$settings['slides_to_show_mobile'].',"slidesToScroll": '.$settings['slides_to_scroll_mobile'].'}}]}\''; 
           }else {
                $data_slick = '';   
           }
          

          if($settings['enable_dots'] == 'yes') {
            $class_row .= ' has-dots';
          }  
         ?>
         <div class="jws_gallery_element">
            <div class="<?php echo esc_attr($class_row); ?>" <?php echo wp_kses_post( $data_slick); ?> data-gallery="jws-custom-<?php echo esc_attr($this->get_id()); ?>">
              
                <?php $i = 1; $n = 0; foreach (  $settings['list'] as $index => $item ) {
                 $link_key = 'link' . $index;   
                 if($settings['link_action'] == 'linkurl') {
                   if($item['link_url']['is_external']) $this->add_render_attribute( $link_key, 'rel',  'nofollow' );
                   if($item['link_url']['nofollow']) $this->add_render_attribute( $link_key, 'target',  '_blank' );  
                   $this->add_render_attribute( $link_key, 'href',  $item['link_url']['url'] ); 
                 }else {
                   $this->add_render_attribute( $link_key, 'class', 'jws-popup-global' );
                   if($settings['gallery_display'] != 'slider') {
                        $this->add_render_attribute( $link_key, 'href',  $item['image']['url'] );  
                   }  
                 }
 
                 if($settings['gallery_display'] == 'metro') {
                                        
                                       if($i == '1' || $i == '5') {
                                          $class_column = 'jws_gallery_item col-xl-5 col-lg-6'; 
                                          $image_size = $settings['image_size'];
                                        
                                        }elseif($i == '3') {
                                          $class_column = 'jws_gallery_item col-xl-4 col-lg-6'; 
                                          $image_size = $settings['image_size3'];
                                        }else {
                                           $image_size = $settings['image_size2'];
                                           $class_column = 'jws_gallery_item col-xl-3 col-lg-3'; 
                                        }  
                                        
                                        
                                        if ($i == 5) {
                                            $i = 1;
                                        } else {
                                            $i++;
                                        }
                                        
                  }else {
                    $image_size = $settings['image_size'];
                  }
                    ?>
                        <div class="<?php echo esc_attr($class_column); ?>" <?php if($settings['link_action'] == 'lightbox' && $settings['gallery_display'] != 'slider') : ?> data-gallery-image data-gallery-item="<?php echo esc_attr($n);?>" <?php endif; ?>>
                        <div class="jws_gallery_image">
                            <a <?php echo wp_kses_post($this->get_render_attribute_string($link_key)); ?>>
                                <?php
                          
                                     $attach_id = $item['image']['id'];
                                     $img = jws_getImageBySize(array('attach_id' => $attach_id, 'thumb_size' => $image_size, 'class' => 'attachment-large wp-post-image'));
                                     echo wp_kses_post($img['thumbnail']);
                                ?>
                            </a>
                        </div>
                    </div>
                <?php $n++; } ?>
            </div>
            <?php if($settings['link_action'] == 'lightbox' && $settings['gallery_display'] != 'slider') : ?>
             <div class="jws-gallery-opened-sc clb-popup clb-gallery-lightbox" id="jws-custom-<?php echo esc_attr($this->get_id()); ?>">
            	<div class="close close-bar">
            	    <div class="clb-close btn-round round-animation circle-animation">
            	        <i class="lnr lnr-cross"></i>
            	    </div>
            	    <div class="expand btn-round round-animation circle-animation vc_hidden-xs">
            	        <i class="lnr lnr-frame-expand"></i>
            	    </div>
            	</div>
                <div class="clb-popup-holder"></div>
               <nav class="custom-navs">
                    <button class="nav_left"><span class="icon-arrow-left2"></span></button>
                    <button class="nav_right"><span class="icon-arrow-right2"></span></button>
              </nav>
            </div>
            <?php endif; ?>

         </div>   
        <?php

	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}
}