<?php
namespace Elementor;
use Elementor\Core\Schemes\Color;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Widget_Base;
use Elementor\Group_Control_Border;
use Elementor\Controls_Manager;
use ElementorPro\Modules\Woocommerce\Classes\Products_Renderer;
use ElementorPro\Modules\Woocommerce\Classes\Current_Query_Renderer;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Product_Listing extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'jws_product_listing';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'JWS Product Listing', 'netfx' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-site-search';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'jws-elements' ];
	}
    /**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'countdown-js' ];
	}
	/**
	 * Register Woo Product Grid controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function _register_controls() {

		/* General Tab */
        $this->register_content_layout_controls();
        $this->register_content_general_controls();
        $this->register_content_filter_controls();
		$this->register_content_grid_controls();
		$this->register_content_slider_controls();
		$this->register_content_pagination_controls();
        
		/* Style Tab */
        $this->register_style_layout_controls();
        $this->register_style_info_controls();
		$this->register_style_pagination_controls();
		$this->register_style_navigation_controls();
        
	}
    /**
	 * Register Woo Products General Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	*/
	protected function register_content_layout_controls() {

		$this->start_controls_section(
			'section_layouts_field',
			[
				'label' => esc_html__( 'layouts', 'netfx' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

			$this->add_control(
				'products_layouts',
                
				[
					'label'     => esc_html__( 'Layouts', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'content-layout1',
					'options'   => [
						'content-layout1'   => esc_html__( 'layout 1', 'netfx' ),
						'content-layout2'   => esc_html__( 'layout 2', 'netfx' ),
                        'content-layout3'   => esc_html__( 'layout 3', 'netfx' ),
                        'content-layout4'   => esc_html__( 'layout 4', 'netfx' ),
                        'content-layout5'   => esc_html__( 'layout 5 ( Image Left )', 'netfx' ),
                        'content-layout6'   => esc_html__( 'layout 6', 'netfx' ),
                        'content-layout7'   => esc_html__( 'layout 7', 'netfx' ),
                        'content-layout8'   => esc_html__( 'layout 8', 'netfx' ),
                        'content-layout9'   => esc_html__( 'layout 9', 'netfx' ),
                        'content-layout10'   => esc_html__( 'layout 10', 'netfx' ),
					],
				]
			);
		$this->end_controls_section();
	}
    /**
	 * Register Woo Products General Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	*/
	protected function register_content_general_controls() {

		$this->start_controls_section(
			'section_general_field',
			[
				'label' => esc_html__( 'General', 'netfx' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

			$this->add_control(
				'products_layout_type',
				[
					'label'     => esc_html__( 'Layout', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'grid',
					'options'   => [
						'grid'   => esc_html__( 'Grid', 'netfx' ),
						'slider' => esc_html__( 'Carousel', 'netfx' ),
                        'masonry'   => esc_html__( 'Masonry', 'netfx' ),
						'metro' => esc_html__( 'Metro', 'netfx' ),
					],
				]
			);
             $this->add_control(
    			'show_filter_product_by_category',
    			[
    				'label' => esc_html__( 'Show Filter Product by Category', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::SWITCHER,
    				'label_on' => esc_html__( 'Show', 'netfx' ),
    				'label_off' => esc_html__( 'Hide', 'netfx' ),
    				'return_value' => 'yes',
    				'default' => 'no',
    			]
    		);
              $this->add_control(
				'attr_filter',
				[
					'label'     => esc_html__( 'Select Swatch', 'netfx' ),
					'type'      => Controls_Manager::SELECT2,
					'multiple'  => false,
					'default'   => '',
					'options'   => $this->get_product_attr(),
				]
			);
            $this->add_control(
				'text_before_countdown',
				[
					'label'     => esc_html__( 'Text Before CountDown', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => 'HURRY UP! OFFER ENDS IN:',
                    'condition' => [
						'products_layouts' => 'layout7',
				    ],
				]
			);
            $this->add_control(
				'text_before_price',
				[
					'label'     => esc_html__( 'Text Before Price', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => 'Starting at:',
                    'condition' => [
						'products_layouts' => 'layout7',
				    ],
				]
			);
            $this->add_control(
    			'show_countdown',
    			[
    				'label' => esc_html__( 'Show CountDown', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::SWITCHER,
    				'label_on' => esc_html__( 'Show', 'netfx' ),
    				'label_off' => esc_html__( 'Hide', 'netfx' ),
    				'return_value' => 'yes',
    				'default' => 'none',
                    'condition' => [
						'products_layouts' => 'layout7',
				    ],
    			]
    		);
            $this->add_control(
    			'show_sold',
    			[
    				'label' => esc_html__( 'Show Sold', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::SWITCHER,
    				'label_on' => esc_html__( 'Show', 'netfx' ),
    				'label_off' => esc_html__( 'Hide', 'netfx' ),
    				'return_value' => 'yes',
    				'default' => 'none',
                    'condition' => [
						'products_layouts' => 'layout7',
				    ],
    			]
    		);
            $this->add_control(
    			'show_rating',
    			[
    				'label' => esc_html__( 'Show Rating', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::SWITCHER,
    				'label_on' => esc_html__( 'Show', 'netfx' ),
    				'label_off' => esc_html__( 'Hide', 'netfx' ),
    				'return_value' => 'yes',
    				'default' => 'yes',
    			]
    		);
            $this->add_control(
    			'show_add_to_cart',
    			[
    				'label' => esc_html__( 'Show Add To Cart', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::SWITCHER,
    				'label_on' => esc_html__( 'Show', 'netfx' ),
    				'label_off' => esc_html__( 'Hide', 'netfx' ),
    				'return_value' => 'true',
    				'default' => 'true',
                    'condition' => [
						'products_layouts' => ['layout7','layout8'],
				    ],
    			]
    		);
            $this->add_control(
    			'show_wishlist',
    			[
    				'label' => esc_html__( 'Show Wishlist', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::SWITCHER,
    				'label_on' => esc_html__( 'Show', 'netfx' ),
    				'label_off' => esc_html__( 'Hide', 'netfx' ),
    				'return_value' => 'true',
    				'default' => 'false',
                    'condition' => [
						'products_layouts' => ['layout7','layout8'],
				    ],
    			]
    		);
            $this->add_control(
    			'show_compare',
    			[
    				'label' => esc_html__( 'Show Compare', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::SWITCHER,
    				'label_on' => esc_html__( 'Show', 'netfx' ),
    				'label_off' => esc_html__( 'Hide', 'netfx' ),
    				'return_value' => 'true',
    				'default' => 'false',
                    'condition' => [
						'products_layouts' => ['layout7','layout8'],
				    ],
    			]
    		);
            $this->add_control(
    			'show_cat',
    			[
    				'label' => esc_html__( 'Show Category', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::SWITCHER,
    				'label_on' => esc_html__( 'Show', 'netfx' ),
    				'label_off' => esc_html__( 'Hide', 'netfx' ),
    				'return_value' => 'yes',
    				'default' => 'yes',
    			]
    		);
            $this->add_control(
    			'show_price',
    			[
    				'label' => esc_html__( 'Show Price', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::SWITCHER,
    				'label_on' => esc_html__( 'Show', 'netfx' ),
    				'label_off' => esc_html__( 'Hide', 'netfx' ),
    				'return_value' => 'yes',
    				'default' => 'yes',
    			]
    		);
        	$this->add_control(
			'image_size_type',
			[
				'label'     => esc_html__( 'Image Size', 'netfx' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'full_size'   => esc_html__( 'Full size', 'netfx' ),
					'custom_size' => esc_html__( 'Custom Size', 'netfx' ),
				],
			]
			);
            $this->add_control(
			'full_height',
			[
				'label'     => esc_html__( 'Full Height', 'netfx' ),
				'type'      => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
			]
			);
            $this->add_control(
				'image_width',
				[
					'label'     => esc_html__( 'Width (px)', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
                    'condition' => [
						'image_size_type' => ['custom_size'],
				    ],
				]
			);
             $this->add_control(
				'image_height',
				[
					'label'     => esc_html__( 'Height (px)', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
                    'condition' => [
						'image_size_type' => ['custom_size'],
				    ],
				]
			);
            $this->add_control(
			'ajax_page',
			[
				'label' => esc_html__( 'ajax_page', 'netfx' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => '', 
			]
		  );
		$this->end_controls_section();
	}
    	/**
	 * Register Woo Products Filter Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_content_filter_controls() {

		$this->start_controls_section(
			'section_filter_field',
			[
				'label' => esc_html__( 'Query', 'netfx' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

			$this->add_control(
				'query_type',
				[
					'label'   => esc_html__( 'Source', 'netfx' ),
					'type'    => Controls_Manager::SELECT,
					'default' => 'all',
					'options' => [
						'all'    => esc_html__( 'All Products', 'netfx' ),
						'custom' => esc_html__( 'Custom Query', 'netfx' ),
						'manual' => esc_html__( 'Manual Selection', 'netfx' ),
					],
				]
			);

			$this->add_control(
				'category_filter_rule',
				[
					'label'     => esc_html__( 'Category Filter Rule', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'IN',
					'options'   => [
						'IN'     => esc_html__( 'Match Categories', 'netfx' ),
						'NOT IN' => esc_html__( 'Exclude Categories', 'netfx' ),
					],
					'condition' => [
						'query_type' => 'custom',
					],
				]
			);
			$this->add_control(
				'category_filter',
				[
					'label'     => esc_html__( 'Select Categories', 'netfx' ),
					'type'      => Controls_Manager::SELECT2,
					'multiple'  => true,
					'default'   => '',
					'options'   => $this->get_product_categories(),
					'condition' => [
						'query_type' => 'custom',
					],
				]
			);
            
            
			$this->add_control(
				'tag_filter_rule',
				[
					'label'     => esc_html__( 'Tag Filter Rule', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'IN',
					'options'   => [
						'IN'     => esc_html__( 'Match Tags', 'netfx' ),
						'NOT IN' => esc_html__( 'Exclude Tags', 'netfx' ),
					],
					'condition' => [
						'query_type' => 'custom',
					],
				]
			);
			$this->add_control(
				'tag_filter',
				[
					'label'     => esc_html__( 'Select Tags', 'netfx' ),
					'type'      => Controls_Manager::SELECT2,
					'multiple'  => true,
					'default'   => '',
					'options'   => $this->get_product_tags(),
					'condition' => [
						'query_type' => 'custom',
					],
				]
			);
			$this->add_control(
				'offset',
				[
					'label'       => esc_html__( 'Offset', 'netfx' ),
					'type'        => Controls_Manager::NUMBER,
					'default'     => 0,
					'description' => esc_html__( 'Number of post to displace or pass over.', 'netfx' ),
					'condition'   => [
						'query_type' => 'custom',
					],
				]
			);

			$this->add_control(
				'query_manual_ids',
				[
					'label'     => esc_html__( 'Select Products', 'netfx' ),
					'type'      => 'jws-query-posts',
					'post_type' => 'product',
					'multiple'  => true,
					'condition' => [
						'query_type' => 'manual',
					],
				]
			);

			/* Exclude */
			$this->add_control(
				'query_exclude',
				[
					'label'     => esc_html__( 'Exclude', 'netfx' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'query_type!' => [ 'manual', 'main' ],
					],
				]
			);
			$this->add_control(
				'query_exclude_ids',
				[
					'label'       => esc_html__( 'Select Products', 'netfx' ),
					'type'        => 'jws-query-posts',
					'post_type'   => 'product',
					'multiple'    => true,
					'description' => esc_html__( 'Select products to exclude from the query.', 'netfx' ),
					'condition'   => [
						'query_type!' => [ 'manual', 'main' ],
					],
				]
			);
			$this->add_control(
				'query_exclude_current',
				[
					'label'        => esc_html__( 'Exclude Current Product', 'netfx' ),
					'type'         => Controls_Manager::SWITCHER,
					'label_on'     => esc_html__( 'Yes', 'netfx' ),
					'label_off'    => esc_html__( 'No', 'netfx' ),
					'return_value' => 'yes',
					'default'      => '',
					'description'  => esc_html__( 'Enable this option to remove current product from the query.', 'netfx' ),
					'condition'    => [
						'query_type!' => [ 'manual', 'main' ],
					],
				]
			);

			/* Advanced Filter */
			$this->add_control(
				'query_advanced',
				[
					'label'     => esc_html__( 'Advanced', 'netfx' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'query_type!' => 'main',
					],
				]
			);
			$this->add_control(
				'filter_by',
				[
					'label'     => esc_html__( 'Filter By', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => '',
					'options'   => [
						''         => esc_html__( 'None', 'netfx' ),
						'featured' => esc_html__( 'Featured', 'netfx' ),
						'sale'     => esc_html__( 'Sale', 'netfx' ),
					],
					'condition' => [
						'query_type!' => 'main',
					],
				]
			);
			$this->add_control(
				'orderby',
				[
					'label'     => esc_html__( 'Order by', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'date',
					'options'   => [
						'date'       => esc_html__( 'Date', 'netfx' ),
						'title'      => esc_html__( 'Title', 'netfx' ),
						'price'      => esc_html__( 'Price', 'netfx' ),
						'popularity' => esc_html__( 'Popularity', 'netfx' ),
						'rating'     => esc_html__( 'Rating', 'netfx' ),
						'rand'       => esc_html__( 'Random', 'netfx' ),
						'menu_order' => esc_html__( 'Menu Order', 'netfx' ),
					],
					'condition' => [
						'query_type!' => 'main',
					],
				]
			);
			$this->add_control(
				'order',
				[
					'label'     => esc_html__( 'Order', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'desc',
					'options'   => [
						'desc' => esc_html__( 'Descending', 'netfx' ),
						'asc'  => esc_html__( 'Ascending', 'netfx' ),
					],
					'condition' => [
						'query_type!' => 'main',
					],
				]
			);

		$this->end_controls_section();
	}
    
    /**
	 * Register Pagination Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_content_pagination_controls() {

		$this->start_controls_section(
			'section_pagination_field',
			[
				'label'     => esc_html__( 'Pagination', 'netfx' ),
				'tab'       => Controls_Manager::TAB_CONTENT,
				'condition' => [
					 'products_layout_type' => ['grid','masonry','metro'],
				],
			]
		);

			$this->add_control(
				'pagination_type',
				[
					'label'     => esc_html__( 'Type', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => '',
					'options'   => [
						''              => esc_html__( 'None', 'netfx' ),
						'numbers'       => esc_html__( 'Numbers', 'netfx' ),
						'arrow' => esc_html__( 'Pre/Next Arrow', 'netfx' ),
                        'load_more' => esc_html__( 'Load More', 'netfx' ),
                        'view_all' => esc_html__( 'View All', 'netfx' ),
					],
					'condition' => [
					    'products_layout_type' => ['grid','masonry','metro'],
					],
				]
			);
            $this->add_control(
				'pagination_loadmore_label',
				[
					'label'     => esc_html__( 'Loadmore & View All Label', 'netfx' ),
					'default'   => esc_html__( 'MORE PRODUCTS', 'netfx' ),
					'condition' => [
						 'products_layout_type' => ['grid','masonry','metro'],
						'pagination_type'      => ['load_more','view_all'],
					],
				]
			);
            $this->add_control(
			'view_link',
			[
				'label' => esc_html__( 'Link', 'netfx' ),
				'type' => Controls_Manager::URL,
				'placeholder' => esc_html__( 'View All Url', 'netfx' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
                'condition' => [
						 'products_layout_type' => ['grid','masonry','metro'],
						'pagination_type'      => 'view_all',
				],
			]
		);
            $this->add_control(
				'pagination_loadmore_label2',
				[
					'label'     => esc_html__( 'All Product Loaded.', 'netfx' ),
					'default'   => esc_html__( 'All products are displayed', 'netfx' ),
					'condition' => [
						 'products_layout_type' => ['grid','masonry','metro'],
						'pagination_type'      => 'load_more',
					],
				]
			);
            $this->add_control(
				'arrow_layouts',
				[
					'label'     => esc_html__( 'layouts', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'layout1',
					'options'   => [
						'layout1'   => esc_html__( 'layout 1', 'netfx' ),
						'layout2'   => esc_html__( 'layout 2', 'netfx' ),
					],
                    'condition' => [
    						 'products_layout_type' => ['grid','masonry','metro'],
    						'pagination_type'      => 'arrow',
					],
				]
			);
            $this->add_control(
				'icon_spacing',
				[
					'label' 		=> esc_html__( 'Icon Spacing', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 150,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .jws_product_pagination ' => 'top: -{{SIZE}}px;',
					],
                    'condition' => [
    						 'products_layout_type' => ['grid','masonry','metro'],
    						'pagination_type'      => 'arrow',
                            'arrow_layouts' => 'layout1'
					],
				]
		  );
			$this->add_control(
					'icon_prev',
					[
						'label' 		=> esc_html__( 'Icon Prev', 'netfx' ),
						'type' 			=> Controls_Manager::ICON,
						'label_block' 	=> false,
						'default' 		=> 'fa fa-chevron-left',
                        'condition' => [
    						 'products_layout_type' => ['grid','masonry','metro'],
    						'pagination_type'      => 'arrow',
					   ],
					]
		  );
		  	$this->add_control(
					'icon_next',
					[
						'label' 		=> esc_html__( 'Icon Next', 'netfx' ),
						'type' 			=> Controls_Manager::ICON,
						'label_block' 	=> false,
						'default' 		=> 'fa fa-chevron-right',
                        'condition' => [
    						 'products_layout_type' => ['grid','masonry','metro'],
    						'pagination_type'      => 'arrow',
					   ],
					]
		  );

		$this->end_controls_section();
	}

	/**
	 * Register grid Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_content_grid_controls() {
		$this->start_controls_section(
			'section_grid_options',
			[
				'label'     => esc_html__( 'Grid Options', 'netfx' ),
				'type'      => Controls_Manager::SECTION,
				'condition' => [
					'products_layout_type!' => 'slider',
				],
			]
		);
			$this->add_responsive_control(
				'products_columns',
				[
					'label'          => esc_html__( 'Columns', 'netfx' ),
					'type'           => Controls_Manager::SELECT,
					'default'        => '3',
					'tablet_default' => '4',
					'mobile_default' => '12',
					'options'        => [
						'12' => '1',
						'6' => '2',
						'4' => '3',
						'3' => '4',
						'20' => '5',
						'2' => '6',
					],
					'condition'      => [
						'products_layout_type' => ['grid','masonry','metro'],
					],
                    'prefix_class' => 'ee-grid-columns%s-',
				]
			);

			$this->add_control(
				'products_per_page',
				[
					'label'     => esc_html__( 'Products Per Page', 'netfx' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => '8',
					'condition' => [
						'products_layout_type' => ['grid','masonry','metro'],
						'query_type!'          => 'main',
					],
				]
			);

		$this->end_controls_section();
	}
    
	/**
	 * Register Slider Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_content_slider_controls() {
		$this->start_controls_section(
			'section_slider_options',
			[
				'label'     => esc_html__( 'Slider Options', 'netfx' ),
				'type'      => Controls_Manager::SECTION,
				'condition' => [
					'products_layout_type' => 'slider',
				],
			]
		);
        $this->add_control(
			'navigation',
			[
				'label'     => esc_html__( 'Navigation', 'netfx' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'both',
				'options'   => [
					'arrows' => esc_html__( 'Arrows', 'netfx' ),
					'dots'   => esc_html__( 'Dots', 'netfx' ),
					'none'   => esc_html__( 'None', 'netfx' ),
				],
				'condition' => [
					'products_layout_type' => 'slider',
				],
			]
		);
        $this->add_control('nav_position', [
                'label' => esc_html__('Arrow position Veritcal', 'netfx'),
                'description' => esc_html__('', 'netfx'),
                'type' => Controls_Manager::SELECT,
                'default' => 'arrow-center',
                'options' => [
                    'arrow-top' => esc_html__('Top', 'netfx'),
                    'arrow-center' => esc_html__('Middle', 'netfx'),
                ],
                'condition' => [
                    'products_layout_type' => 'slider',
                    'navigation' => 'arrows',
                ],

        ]);
        $this->add_control(
			'navigation_position',
			[
				'label'     => esc_html__( 'Arrow Position Horizontal', 'netfx' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'outside',
				'options'   => [
					'outside' => esc_html__( 'Outside', 'netfx' ),
					'inside'   => esc_html__( 'Inside', 'netfx' ),
				],
				'condition' => [
					'products_layout_type' => 'slider',
                    'navigation' => 'arrows',
				],
			]
		);
        $this->add_control(
				'slider_layouts',
				[
					'label'     => esc_html__( 'layouts', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'layout1',
					'options'   => [
						'layout1'   => esc_html__( 'layout 1', 'netfx' ),
						'layout2'   => esc_html__( 'layout 2', 'netfx' ),
					],
                    'condition' => [
    						'products_layout_type' => 'slider',
                            'navigation' => 'arrows'
					],
				]
			);
            $this->add_control(
				'iconslider_spacing',
				[
					'label' 		=> esc_html__( 'Icon Spacing', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 150,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .jws_product_nav_slider' => 'top: -{{SIZE}}px;',
					],
                    'condition' => [
    						'products_layout_type' => 'slider',
                            'navigation' => 'arrows'
					],
				]
		  );
			$this->add_control(
					'iconslider_prev',
					[
						'label' 		=> esc_html__( 'Icon Prev', 'netfx' ),
						'type' 			=> Controls_Manager::ICON,
						'label_block' 	=> false,
						'default' 		=> 'fa fa-chevron-left',
                        'condition' => [
    						'products_layout_type' => 'slider',
                            'navigation' => 'arrows'
					   ],
					]
		  );
		  	$this->add_control(
					'iconslider_next',
					[
						'label' 		=> esc_html__( 'Icon Next', 'netfx' ),
						'type' 			=> Controls_Manager::ICON,
						'label_block' 	=> false,
						'default' 		=> 'fa fa-chevron-right',
                        'condition' => [
    						'products_layout_type' => 'slider',
                            'navigation' => 'arrows'
					   ],
					]
		  );
		$this->add_control(
			'slider_products_per_page',
			[
				'label'     => esc_html__( 'Total Products', 'netfx' ),
				'type'      => Controls_Manager::NUMBER,
				'default'   => '8',
				'condition' => [
					'products_layout_type' => 'slider',
					'query_type!'          => 'main',
				],
			]
		);

		$this->add_responsive_control(
			'slides_to_show',
			[
				'label'          => esc_html__( 'Products to Show', 'netfx' ),
				'type'           => Controls_Manager::NUMBER,
				'default'        => 4,
				'tablet_default' => 3,
				'mobile_default' => 1,
				'condition'      => [
					'products_layout_type' => 'slider',
				],
			]
		);

		$this->add_responsive_control(
			'slides_to_scroll',
			[
				'label'          => esc_html__( 'Products to Scroll', 'netfx' ),
				'type'           => Controls_Manager::NUMBER,
				'default'        => 1,
				'tablet_default' => 1,
				'mobile_default' => 1,
				'condition'      => [
					'products_layout_type' => 'slider',
				],
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'        => esc_html__( 'Autoplay', 'netfx' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => '',
				'condition'    => [
					'products_layout_type' => 'slider',
				],
			]
		);
		$this->add_control(
			'autoplay_speed',
			[
				'label'     => esc_html__( 'Autoplay Speed', 'netfx' ),
				'type'      => Controls_Manager::NUMBER,
				'default'   => 5000,
				'selectors' => [
					'{{WRAPPER}} .slick-slide-bg' => 'animation-duration: calc({{VALUE}}ms*1.2); transition-duration: calc({{VALUE}}ms)',
				],
				'condition' => [
					'products_layout_type' => 'slider',
					'autoplay'             => 'yes',
				],
			]
		);
		$this->add_control(
			'pause_on_hover',
			[
				'label'        => esc_html__( 'Pause on Hover', 'netfx' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition'    => [
					'products_layout_type' => 'slider',
					'autoplay'             => 'yes',
				],
			]
		);

		$this->add_control(
			'infinite',
			[
				'label'        => esc_html__( 'Infinite Loop', 'netfx' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition'    => [
					'products_layout_type' => 'slider',
				],
			]
		);

		$this->add_control(
			'transition_speed',
			[
				'label'     => esc_html__( 'Transition Speed (ms)', 'netfx' ),
				'type'      => Controls_Manager::NUMBER,
				'default'   => 500,
				'condition' => [
					'products_layout_type' => 'slider',
				],
			]
		);
		$this->end_controls_section();
	}
    
    /**
	 * Style Tab
	 */
	/**
	 * Register Layout Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_style_layout_controls() {
		$this->start_controls_section(
			'section_design_layout',
			[
				'label' => esc_html__( 'Layout', 'netfx' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'column_gap',
			[
				'label'     => esc_html__( 'Columns Gap', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
				'default'   => [
                    'unit' => 'px',
					'size' => 30,
				],
				'range'     => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
                    '%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .products .product-item' => 'padding-right: calc( {{SIZE}}{{UNIT}}/2 ); padding-left: calc( {{SIZE}}{{UNIT}}/2 );',
					'{{WRAPPER}} .products' => 'margin-left: calc( -{{SIZE}}{{UNIT}}/2 ); margin-right: calc( -{{SIZE}}{{UNIT}}/2 );',
                    '{{WRAPPER}} .products .slick-slide' => 'padding-top:0; padding-bottom:0;',
				],
			]
		);

		$this->add_responsive_control(
			'row_gap',
			[
				'label'     => esc_html__( 'Rows Gap', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
				'default'   => [
					'size' => 35,
				],
				'range'     => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .products .product-item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .products' => 'margin-bottom: -{{SIZE}}{{UNIT}};',
				],
			]
		);
        $this->add_responsive_control('product_inner_padding', [
                'label' => esc_html__('Product Inner Padding', 'netfx'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .product-item .product-inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);
        $this->add_responsive_control('content_inner_padding', [
                'label' => esc_html__('Content Inner Padding', 'netfx'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .product-item .product-inner .product-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);



		$this->end_controls_section();
	}
    protected function register_style_info_controls() {
		$this->start_controls_section(
			'section_design_info',
			[
				'label' => esc_html__( 'Product Item', 'netfx' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
        $this->start_controls_tabs( 'info_tabs_style' );

		$this->start_controls_tab(
				'info_normal',
				[
					'label'     => esc_html__( 'Normal', 'netfx' ),
				]
		);
        $this->add_control(
					'background_color_item',
					[
						'label' 	=> esc_html__( 'Background Color Product Item', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .product-inner' => 'color: {{VALUE}};',
                            '{{WRAPPER}} .product-inner' => 'background: {{VALUE}};',
						],
					]
		);
        $this->add_control(
					'cat_color',
					[
						'label' 	=> esc_html__( 'Category Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .cat-list a ' => 'color: {{VALUE}};',
                            '{{WRAPPER}} .cat-list span' => 'background: {{VALUE}};',
						],
					]
		);
        $this->add_control(
					'title_color',
					[
						'label' 	=> esc_html__( 'Title Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .woocommerce-loop-product__title a' => 'color: {{VALUE}};',
						],
					]
		);
        $this->add_control(
					'text_before_countdown_color',
					[
						'label' 	=> esc_html__( 'Text Before CountDown Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .bf_countdown' => 'color: {{VALUE}};',
						],
                            'condition' => [
                            'show_countdown' => 'yes',
    						'products_layouts' => 'layout7',
				        ],
					]
		);
        $this->add_control(
					'text_countdown_color',
					[
						'label' 	=> esc_html__( 'Text Before CountDown Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '#333333',
						'selectors' => [
							'{{WRAPPER}} .jws_product_sale_time' => 'color: {{VALUE}};',
						],
                            'condition' => [
                            'show_countdown' => 'yes',
    						'products_layouts' => 'layout7',
				        ],
					]
		);
        $this->add_control(
					'text_countdown_bgcolor',
					[
						'label' 	=> esc_html__( 'Text Before CountDown Background Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '#fed900',
						'selectors' => [
							'{{WRAPPER}} .jws_product_sale_time .jws-box-countdown .wrapper span' => 'background-color: {{VALUE}};',
						],
                            'condition' => [
                            'show_countdown' => 'yes',
    						'products_layouts' => 'layout7',
				        ],
					]
		);
        $this->add_control(
					'text_sold_bgcolor',
					[
						'label' 	=> esc_html__( 'Sold Background Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '#fed900',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .jws_content_action_product .progress_bar_sold .line span' => 'background: {{VALUE}};',
						],
                            'condition' => [
                            'show_sold' => 'yes',
    						'products_layouts' => 'layout7',
				        ],
					]
		);
        $this->add_control(
					'text_sold_color',
					[
						'label' 	=> esc_html__( 'Sold Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '#333333',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .jws_content_action_product .progress_bar_sold .sold_count span' => 'color: {{VALUE}};',
						],
                            'condition' => [
                            'show_sold' => 'yes',
    						'products_layouts' => 'layout7',
				        ],
					]
		);
        $this->add_control(
					'text_sold_color2',
					[
						'label' 	=> esc_html__( 'Sold Color Count', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '#0174f5',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .jws_content_action_product .progress_bar_sold .sold_count' => 'color: {{VALUE}};',
						],
                            'condition' => [
                            'show_sold' => 'yes',
    						'products_layouts' => 'layout7',
				        ],
					]
		);
        $this->add_control(
					'text_before_price_color',
					[
						'label' 	=> esc_html__( 'Text Before Price Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .bf_t' => 'color: {{VALUE}};',
						],
                            'condition' => [
    						'products_layouts' => 'layout7',
				        ],
					]
		);
        $this->add_control(
					'price_sale_color',
					[
						'label' 	=> esc_html__( 'Price Sale Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .price del' => 'color: {{VALUE}};',
						],
					]
		);
        $this->add_control(
					'price_color',
					[
						'label' 	=> esc_html__( 'Price Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .price' => 'color: {{VALUE}};',
						],
					]
		);
        $this->add_control(
			'product_image',
			[
				'label' => esc_html__( 'Image', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_responsive_control('image_padding', [
                'label' => esc_html__('Image Padding', 'netfx'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .product-item .product-inner .product-image' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);
          $this->add_control(
			'product_description',
			[
				'label' => esc_html__( 'Description', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_responsive_control('description_margin', [
                'label' => esc_html__('Description Margin', 'netfx'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .product-item .product-inner .short-description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]);
              $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'product_description_typography',
				'label' => esc_html__( 'Typography', 'netfx'),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .product-item .product-inner .short-description',
			]
		);
        $this->add_control(
			'product_icon',
			[
				'label' => esc_html__( 'Icon', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
					'icon_color',
					[
						'label' 	=> esc_html__( 'Icon Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products_item  .jws_inner_button li a' => 'color: {{VALUE}};',
                            '{{WRAPPER}} .jws_products.jws_products_layout3 .jws_products_item .add_to_cart_button' => 'color: {{VALUE}};',
						],
					]
		);
        $this->add_control(
					'icon_bgcolor',
					[
						'label' 	=> esc_html__( 'Icon Background Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products_item  .jws_inner_button li a' => 'background-color: {{VALUE}};',
                            '{{WRAPPER}} .jws_products.jws_products_layout3 .jws_products_item .add_to_cart_button' => 'background-color: {{VALUE}};',
						],
					]
		);
        $this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'icon_border',
					'label' 	=> esc_html__( 'Icon Border', 'netfx' ),
					'selector' => 	'{{WRAPPER}} .jws_products_item  .jws_inner_button li a',
                    'condition' => [
					   'products_layouts!' => 'layout3',
				    ],
				]
		);
        $this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'icon_border_2',
					'label' 	=> esc_html__( 'Icon Border', 'netfx' ),
					'selector' => 	'{{WRAPPER}} .jws_products.jws_products_layout3 .jws_products_item .add_to_cart_button',
                    'condition' => [
					   'products_layouts' => 'layout3',
				    ],
				]
		);
        $this->add_control(
			'product_addcart',
			[
				'label' => esc_html__( 'Button Add To Cart', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition' => [
    				'products_layouts' => ['layout4','layout6','layout7','layout8','layout9'],
    			],
			]
		);
        $this->add_control(
					'addcart_color',
					[
						'label' 	=> esc_html__( 'Button Add To Cart Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .add_to_cart_button' => 'color: {{VALUE}};',
                            '{{WRAPPER}} .jws_products.jws_products_layout6 .jws_products_item .jws_item_inner .single_add_to_cart_button' => 'color: {{VALUE}};',
                            '{{WRAPPER}} .jws_products .jws_products_item .jws_image_thumbnail_product .add_to_cart_button span' => 'color: {{VALUE}};',
						],
                        'condition' => [
    					   'products_layouts' => ['layout4','layout6','layout7','layout8','layout9'],
    				    ],
					]
		);
        $this->add_control(
					'addcart_bgcolor',
					[
						'label' 	=> esc_html__( 'Button Add To Cart Background Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .add_to_cart_button' => 'background-color: {{VALUE}};',
                            '{{WRAPPER}} .jws_products.jws_products_layout6 .jws_products_item .jws_item_inner .single_add_to_cart_button' => 'background-color: {{VALUE}};',
                            '{{WRAPPER}} .jws_products .jws_products_item .jws_image_thumbnail_product .add_to_cart_button span' => 'background-color: {{VALUE}};',
						],
                        'condition' => [
    					   'products_layouts' => ['layout4','layout6','layout7','layout8','layout9'],
    				    ],
					]
		);
        $this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'addcart_border',
					'label' 	=> esc_html__( 'Button Add To Cart Border', 'netfx' ),
					'selector' => 	'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .add_to_cart_button , {{WRAPPER}} .jws_products.jws_products_layout6 .jws_products_item .jws_item_inner .single_add_to_cart_button,{{WRAPPER}} .jws_products .jws_products_item .jws_image_thumbnail_product .add_to_cart_button span',
                    'condition' => [
					   'products_layouts' => ['layout4','layout6','layout7','layout8','layout9'],
				    ],
				]
		);
        
        $this->add_control(
			'product_select',
			[
				'label' => esc_html__( 'Button Select Size', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition' => [
    				'products_layouts' => ['layout6'],
    			],
			]
		);
        $this->add_control(
					'select_color',
					[
						'label' 	=> esc_html__( 'Button Select Size Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .jws_choose_option' => 'color: {{VALUE}};',
						],
                        'condition' => [
    					   'products_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_control(
					'select_bgcolor',
					[
						'label' 	=> esc_html__( 'Button Select Size Background Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .jws_choose_option' => 'background-color: {{VALUE}};',
						],
                        'condition' => [
    					   'products_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'select_border',
					'label' 	=> esc_html__( 'Button Select Size Border', 'netfx' ),
					'selector' => 	'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .jws_choose_option , {{WRAPPER}} .jws_products .jws_products_item.selectoptions-show .jws_item_inner .selectoptions-swap .variations',
                    'condition' => [
					   'products_layouts' => ['layout6'],
				    ],
				]
		);
        $this->add_control(
					'select_sub_color',
					[
						'label' 	=> esc_html__( 'Sub Option Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item.selectoptions-show .jws_item_inner .selectoptions-swap .variations .tawcvs-swatches .swatch' => 'color: {{VALUE}};',
						],
                        'condition' => [
    					   'products_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_control(
					'select_sub_bgcolor',
					[
						'label' 	=> esc_html__( 'Sub Option Background', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item.selectoptions-show .jws_item_inner .selectoptions-swap .variations' => 'background-color: {{VALUE}};',
						],
                        'condition' => [
    					   'products_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_control(
					'select_sub_avtive_color',
					[
						'label' 	=> esc_html__( 'Sub ACtive Option Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item.selectoptions-show .jws_item_inner .selectoptions-swap .variations  .tawcvs-swatches .swatch.selected' => 'color: {{VALUE}};',
						],
                        'condition' => [
    					   'products_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_control(
					'select_sub_avtive_bgcolor',
					[
						'label' 	=> esc_html__( 'Sub ACtive Option Background', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item.selectoptions-show .jws_item_inner .selectoptions-swap .variations  .tawcvs-swatches .swatch.selected' => 'background-color: {{VALUE}};',
						],
                        'condition' => [
    					   'products_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_control(
					'wishlist_color',
					[
						'label' 	=> esc_html__( 'Wishlist Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
                            '{{WRAPPER}} .jws_products_item .jws_image_thumbnail_product .product-wishlist-button a' => 'color: {{VALUE}};',
						],
					]
		);
        $this->add_control(
					'overlay',
					[
						'label' 	=> esc_html__( 'Overlay Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item .jws_image_thumbnail_product .overlay_image_thumbnail_product' => 'background: {{VALUE}};',
						],
					]
		);
        $this->end_controls_tab();

		$this->start_controls_tab(
				'info_hover',
				[
					'label'     => esc_html__( 'Hover', 'netfx' ),
				]
		);
         $this->add_control(
					'cat_color_hover',
					[
						'label' 	=> esc_html__( 'Category Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .cat-list a:hover ' => 'color: {{VALUE}};',
						],
					]
		);
        $this->add_control(
					'title_color_hover',
					[
						'label' 	=> esc_html__( 'Title Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .woocommerce-loop-product__title a:hover' => 'color: {{VALUE}};',
						],
					]
		);
        $this->add_control(
			'product_icon_hover',
			[
				'label' => esc_html__( 'Icon', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_control(
					'icon_color_hover',
					[
						'label' 	=> esc_html__( 'Icon Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products_item  .jws_inner_button li a:hover' => 'color: {{VALUE}};',
                            '{{WRAPPER}} .jws_products.jws_products_layout3 .jws_products_item .add_to_cart_button:hover' => 'color: {{VALUE}};',
						],
					]
		);
        $this->add_control(
					'icon_bgcolor_hover',
					[
						'label' 	=> esc_html__( 'Icon Background Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products_item .jws_inner_button li a:hover' => 'background-color: {{VALUE}};',
                            '{{WRAPPER}} .jws_products.jws_products_layout3 .jws_products_item .add_to_cart_button:hover' => 'background-color: {{VALUE}};',
						],
					]
		);
        $this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'icon_border_hover',
					'label' 	=> esc_html__( 'Icon Border', 'netfx' ),
					'selector' 	=> '{{WRAPPER}} .jws_products_item  .jws_inner_button li a:hover',
				]
		);
        $this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'icon_border_2_hover',
					'label' 	=> esc_html__( 'Icon Border', 'netfx' ),
					'selector' => 	'{{WRAPPER}} .jws_products.jws_products_layout3 .jws_products_item .add_to_cart_button:hover',
                    'condition' => [
					   'products_layouts' => 'layout3',
				    ],
				]
		);
        $this->add_control(
			'product_addcart_hover',
			[
				'label' => esc_html__( 'Button Add To Cart', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition' => [
    				'products_layouts' => ['layout4','layout6','layout7','layout8','layout9'],
    			],
			]
		);
        $this->add_control(
					'addcart_color_hover',
					[
						'label' 	=> esc_html__( 'Button Add To Cart Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .add_to_cart_button:hover' => 'color: {{VALUE}};',
                            '{{WRAPPER}} .jws_products .jws_products_item .jws_item_inner .single_add_to_cart_button:hover' => 'color: {{VALUE}};',
                            '{{WRAPPER}} .jws_products .jws_products_item .jws_image_thumbnail_product .add_to_cart_button:hover:before' => 'color: {{VALUE}};',
						],
                        'condition' => [
    					   'products_layouts' => ['layout4','layout6','layout7','layout8','layout9'],
    				    ],
					]
		);
        $this->add_control(
					'addcart_bgcolor_hover',
					[
						'label' 	=> esc_html__( 'Button Add To Cart Background Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .add_to_cart_button:hover' => 'background-color: {{VALUE}};',
                            '{{WRAPPER}} .jws_products .jws_products_item .jws_item_inner .single_add_to_cart_button:hover' => 'background-color: {{VALUE}};',
                            '{{WRAPPER}} .jws_products .jws_products_item .jws_image_thumbnail_product .add_to_cart_button:hover:before' => 'background-color: {{VALUE}};',
						],
                        'condition' => [
    					   'products_layouts' => ['layout4','layout6','layout7','layout8','layout9'],
    				    ],
					]
		);
        $this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'addcart_border_hover',
					'label' 	=> esc_html__( 'Button Add To Cart Border', 'netfx' ),
					'selector' => 	'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .add_to_cart_button:hover , {{WRAPPER}} .jws_products .jws_products_item .jws_item_inner .single_add_to_cart_button:hover , {{WRAPPER}} .jws_products .jws_products_item .jws_image_thumbnail_product .add_to_cart_button:hover:before',
                    'condition' => [
					   'products_layouts' => ['layout4','layout6','layout7','layout8','layout9'],
				    ],
				]
		);
          $this->add_control(
			'product_select_hover',
			[
				'label' => esc_html__( 'Button Select Size', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition' => [
    				'products_layouts' => ['layout6'],
    			],
			]
		);
        $this->add_control(
					'select_color_hover',
					[
						'label' 	=> esc_html__( 'Button Select Size Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .jws_choose_option:hover' => 'color: {{VALUE}};',
						],
                        'condition' => [
    					   'products_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_control(
					'select_bgcolor_hover',
					[
						'label' 	=> esc_html__( 'Button Select Size Background Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .jws_choose_option:hover' => 'background-color: {{VALUE}};',
						],
                        'condition' => [
    					   'products_layouts' => ['layout6'],
    				    ],
					]
		);
        $this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'select_border_hover',
					'label' 	=> esc_html__( 'Button Select Size Border', 'netfx' ),
					'selector' => 	'{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .jws_choose_option:hover',
                    'condition' => [
					   'products_layouts' => ['layout6'],
				    ],
				]
		);
        $this->add_control(
					'wishlist_color_hover',
					[
						'label' 	=> esc_html__( 'Wishlist Color', 'netfx' ),
						'type' 		=> Controls_Manager::COLOR,
						'default' 	=> '',
						'selectors' => [
							'{{WRAPPER}} .jws_products_item .jws_image_thumbnail_product .product-wishlist-button  a:hover' => 'color: {{VALUE}};',
						],
					]
		);
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->add_control(
			'product_title',
			[
				'label' => esc_html__( 'Title', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'product_title_typography',
				'label' => esc_html__( 'Typography', 'netfx'),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .jws_content_center_product h2 a',
			]
		);
        $this->add_control(
			'product_cat',
			[
				'label' => esc_html__( 'Category', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'product_cat_typography',
				'label' => esc_html__( 'Typography', 'netfx'),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .cat-list a',

			]
		);
        $this->add_control(
			'product_bf_countdown',
			[
				'label' => esc_html__( 'Text Before Countdown', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition' => [
					   'products_layouts' => ['layout7'],
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'product_bf_countdown_typography',
				'label' => esc_html__( 'Typography', 'netfx'),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .bf_countdown',
                'condition' => [
					   'products_layouts' => ['layout7'],
				],

			]
		);
        $this->add_control(
			'product_countdown',
			[
				'label' => esc_html__( 'Text Countdown', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition' => [
					   'products_layouts' => ['layout7'],
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'product_countdown_typography',
				'label' => esc_html__( 'Typography', 'netfx'),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .jws_product_sale_time',
                'condition' => [
					   'products_layouts' => ['layout7'],
				],

			]
		);
        $this->add_control(
			'product_sold',
			[
				'label' => esc_html__( 'Text Sold', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition' => [
					   'products_layouts' => ['layout7'],
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'product_sold_typography',
				'label' => esc_html__( 'Sold Typography', 'netfx'),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .jws_content_action_product .progress_bar_sold .sold_count',
                'condition' => [
					   'products_layouts' => ['layout7'],
				],

			]
		);
        $this->add_control(
			'product_bf_price',
			[
				'label' => esc_html__( 'Text Before Price', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition' => [
					   'products_layouts' => ['layout7'],
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'product_bf_price_typography',
				'label' => esc_html__( 'Typography', 'netfx'),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .bf_t',
                'condition' => [
					   'products_layouts' => ['layout7'],
				],

			]
		);
        $this->add_control(
			'productsale_price',
			[
				'label' => esc_html__( 'Price Sale', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'product_pricesale_typography',
				'label' => esc_html__( 'Typography', 'netfx'),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .product-item .product-inner .product-content .price del',

			]
		);
        $this->add_control(
			'product_price',
			[
				'label' => esc_html__( 'Price', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'product_price_typography',
				'label' => esc_html__( 'Typography', 'netfx'),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .product-item .product-inner .product-content .price',

			]
		);
        $this->add_control(
			'product_addcart_heading',
			[
				'label' => esc_html__( 'Button Add To Cart', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition' => [
					  'products_layouts' => ['layout4','layout6','layout7','layout8','layout9'],
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'addcart_typography',
				'label' => esc_html__( 'Typography', 'netfx'),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .add_to_cart_button , {{WRAPPER}} .selectoptions_form button , {{WRAPPER}} .jws_products .jws_products_item .jws_image_thumbnail_product .add_to_cart_button',
                'condition' => [
					   'products_layouts' => ['layout4','layout6','layout7','layout8','layout9'],
				],

			]
		);
        $this->add_control(
			'product_select_heading',
			[
				'label' => esc_html__( 'Button Select', 'netfx' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition' => [
					  'products_layouts' => ['layout6'],
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'select_typography',
				'label' => esc_html__( 'Typography', 'netfx'),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .jws_products .jws_products_item .jws_content_product .jws_choose_option',
                'condition' => [
					   'products_layouts' => ['layout6'],
				],

			]
		);
		$this->end_controls_section();
	}

       /**
	 * Register Pagination Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_style_pagination_controls() {

		$this->start_controls_section(
			'section_design_pagination',
			[
				'label'     => esc_html__( 'Pagination', 'netfx' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					 'products_layout_type' => ['grid','masonry','metro'],
					'pagination_type!'     => '',
				],
			]
		);

		$this->start_controls_tabs( 'pagination_tabs_style' );

			$this->start_controls_tab(
				'pagination_normal',
				[
					'label'     => esc_html__( 'Normal', 'netfx' ),
					'condition' => [
						 'products_layout_type' => ['grid','masonry','metro'],
						'pagination_type!'     => '',
					],
				]
			);

				$this->add_control(
					'pagination_color',
					[
						'label'     => esc_html__( 'Text Color', 'netfx' ),
						'type'      => Controls_Manager::COLOR,
						'scheme'    => [
							'type'  => Color::get_type(),
							'value' => Color::COLOR_4,
						],
						'selectors' => [
							'{{WRAPPER}} .jws_product_pagination   .jws-products-load-more span , {{WRAPPER}} .jws_product_pagination  .jws-products-view-all span , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li a , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li' => 'color: {{VALUE}};',
						],
						'condition' => [
							 'products_layout_type' => ['grid','masonry','metro'],
							'pagination_type!'     => '',
						],
					]
				);

				$this->add_control(
					'pagination_background_color',
					[
						'label'     => esc_html__( 'Background Color', 'netfx' ),
						'type'      => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .jws_product_pagination  .jws-products-load-more span , {{WRAPPER}} .jws_product_pagination  .jws-products-view-all span , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li' => 'background-color: {{VALUE}};',
						],
						'condition' => [
							 'products_layout_type' => ['grid','masonry','metro'],
							'pagination_type!'     => '',
						],
					]
				);

				$this->add_control(
					'pagination_border_color',
					[
						'label'     => esc_html__( 'Border Color', 'netfx' ),
						'type'      => Controls_Manager::COLOR,
						'scheme'    => [
							'type'  => Color::get_type(),
							'value' => Color::COLOR_4,
						],
						'selectors' => [
							'{{WRAPPER}} .jws_product_pagination   .jws-products-load-more span , {{WRAPPER}} .jws_product_pagination  .jws-products-view-all span' => 'border-color: {{VALUE}};',
						],
						'condition' => [
							 'products_layout_type' => ['grid','masonry','metro'],
							'pagination_type!'     => '',
						],
					]
				);

			$this->end_controls_tab();

			$this->start_controls_tab(
				'pagination_hover',
				[
					'label'     => esc_html__( 'Hover', 'netfx' ),
					'condition' => [
						 'products_layout_type' => ['grid','masonry','metro'],
						'pagination_type!'     => '',
					],
				]
			);

				$this->add_control(
					'pagination_hover_color',
					[
						'label'     => esc_html__( 'Text Active / Hover Color', 'netfx' ),
						'type'      => Controls_Manager::COLOR,
						'default'   => '#ffffff',
						'selectors' => [
							'{{WRAPPER}} .jws_product_pagination   .jws-products-load-more span:hover , {{WRAPPER}} .jws_product_pagination  .jws-products-view-all span:hover , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li .current  , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li .prev , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li .next , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li a:hover ' => 'color: {{VALUE}};',
						],
						'condition' => [
							 'products_layout_type' => ['grid','masonry','metro'],
							'pagination_type!'     => '',
						],
					]
				);

				$this->add_control(
					'pagination_background_hover_color',
					[
						'label'     => esc_html__( 'Background Hover Color', 'netfx' ),
						'type'      => Controls_Manager::COLOR,
						'scheme'    => [
							'type'  => Color::get_type(),
							'value' => Color::COLOR_4,
						],
						'selectors' => [
                            '{{WRAPPER}} .jws_product_pagination  .jws-products-load-more:hover  span, {{WRAPPER}} .jws_product_pagination  .jws-products-view-all:hover span , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li .current, {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li .prev , {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li .next, {{WRAPPER}} .jws-pagination-number .jws_pagi_inner ul li a:hover' => 'background-color: {{VALUE}};',
						],
						'condition' => [
							 'products_layout_type' => ['grid','masonry','metro'],
							'pagination_type!'     => '',
						],
					]
				);

				$this->add_control(
					'pagination_border_hover_color',
					[
						'label'     => esc_html__( 'Border Hover Color', 'netfx' ),
						'type'      => Controls_Manager::COLOR,
						'scheme'    => [
							'type'  => Color::get_type(),
							'value' => Color::COLOR_4,
						],
						'selectors' => [
							'{{WRAPPER}} .jws_product_pagination  .jws-products-load-more:hover span , {{WRAPPER}} .jws_product_pagination  .jws-products-view-all:hover span' => 'border-color: {{VALUE}};',
						],
						'condition' => [
							 'products_layout_type' => ['grid','masonry','metro'],
							'pagination_type!'     => '',
						],
					]
				);

			$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'      => 'pagination_typography',
				'selector'  => '{{WRAPPER}} .jws_product_pagination  .jws-products-load-more span ,{{WRAPPER}} .jws_product_pagination  .jws-products-load-more span:before, {{WRAPPER}} .jws_product_pagination  .jws-products-view-all span, {{WRAPPER}} .jws_product_pagination  .jws-products-view-all span:before',
				'condition' => [
					 'products_layout_type' => ['grid','masonry','metro'],
					'pagination_type!'     => '',
				],

			]
		);
        
        $this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'pagination_product_border',
				'label' => esc_html__( 'Border', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws_product_pagination   .jws-products-load-more span , {{WRAPPER}} .jws_product_pagination  .jws-products-view-all span',
			]
		);
        $this->add_control(
					'pagination_radius',
					[
						'type' 			=> Controls_Manager::DIMENSIONS,
						'label' 		=> esc_html__( 'Border Radius', 'netfx' ),
						'size_units' 	=> [ 'px', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws_product_pagination   .jws-products-load-more span , {{WRAPPER}} .jws_product_pagination  .jws-products-view-all span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
		);
         $this->add_control(
					'pagination_padding',
					[
						'type' 			=> Controls_Manager::DIMENSIONS,
						'label' 		=> esc_html__( 'Padding', 'netfx' ),
						'size_units' 	=> [ 'px', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws_product_pagination   .jws-products-load-more span , {{WRAPPER}} .jws_product_pagination  .jws-products-view-all span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
		);
        $this->add_control(
					'pagination_margin',
					[
						'type' 			=> Controls_Manager::DIMENSIONS,
						'label' 		=> esc_html__( 'Margin', 'netfx' ),
						'size_units' 	=> [ 'px', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws_product_pagination   .jws-products-load-more span , {{WRAPPER}} .jws_product_pagination  .jws-products-view-all span , {{WRAPPER}} .jws_product_pagination ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
		);
        $this->add_control(
		'pagination_product_align',
				[
					'label' 		=> esc_html__( 'Align', 'netfx' ),
					'type' 			=> Controls_Manager::CHOOSE,
					'default' 		=> 'left',
					'options' 		=> [
						'left'    		=> [
							'title' 	=> esc_html__( 'Left', 'netfx' ),
							'icon' 		=> 'eicon-h-align-left',
						],
						'center' 		=> [
							'title' 	=> esc_html__( 'Center', 'netfx' ),
							'icon' 		=> 'eicon-h-align-center',
						],
						'right' 		=> [
							'title' 	=> esc_html__( 'Right', 'netfx' ),
							'icon' 		=> 'eicon-h-align-right',
						],
					],
                    'selectors' => [
							'{{WRAPPER}} .jws_product_pagination ' => 'text-align: {{VALUE}};',
					],
					'frontend_available' => true,
				]
		);
		$this->end_controls_section();
	}

	/**
	 * Register Navigation Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_style_navigation_controls() {
		$this->start_controls_section(
			'section_style_navigation',
			[
				'label'     => esc_html__( 'Navigation', 'netfx' ),
				'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
					'products_layout_type' => 'slider',
					'navigation'           => [ 'arrows', 'dots', 'both' ],
				],
			]
		);

		$this->add_control(
			'heading_style_arrows',
			[
				'label'     => esc_html__( 'Arrows', 'netfx' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition' => [
					'products_layout_type' => 'slider',
				],
			]
		);

		$this->add_control(
			'arrows_size',
			[
				'label'     => esc_html__( 'Size', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'min' => 20,
						'max' => 60,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .jws_product_nav_slider > div > span:before' => 'font-size: {{SIZE}}{{UNIT}};',
				],
                'condition' => [
					'products_layout_type' => 'slider',
				],
			]
		);
        $this->add_control(
			'arrows_width',
			[
				'label'     => esc_html__( 'Width', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'min' => 20,
						'max' => 60,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .jws_product_nav_slider > div' => 'width: {{SIZE}}{{UNIT}};',
				],
                'condition' => [
					'products_layout_type' => 'slider',
				],
			]
		);
        $this->add_control(
			'arrows_height',
			[
				'label'     => esc_html__( 'Height', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'min' => 20,
						'max' => 60,
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .jws_product_nav_slider > div' => 'line-height: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
				],
                'condition' => [
					'products_layout_type' => 'slider',
				],
			]
		);
         $this->add_responsive_control(
					'arrows_radius',
					[
						'type' 			=> Controls_Manager::DIMENSIONS,
						'label' 		=> esc_html__( 'Border Radius', 'netfx' ),
						'size_units' 	=> [ 'px', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws_product_nav_slider > div' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
                        'condition' => [
        					'products_layout_type' => 'slider',
        				],
					]
		);
		$this->start_controls_tabs( 'arrow_tabs_style' );
			$this->start_controls_tab(
				'arrow_style_normal',
				[
					'label'     => esc_html__( 'Normal', 'netfx' ),
				]
			);
				$this->add_control(
					'arrows_color',
					[
						'label'     => esc_html__( 'Color', 'netfx' ),
						'type'      => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .jws_product_nav_slider > div' => 'color: {{VALUE}};',
						],
                        'condition' => [
        					'products_layout_type' => 'slider',
        				],
					]
				);
				$this->add_control(
					'arrows_bg_color',
					[
						'label'     => esc_html__( 'Background Color', 'netfx' ),
						'type'      => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .jws_product_nav_slider > div' => 'background-color: {{VALUE}};',
						],
                        'condition' => [
        					'products_layout_type' => 'slider',
        				],
					]
				);
			$this->end_controls_tab();

			$this->start_controls_tab(
				'arrow_style_hover',
				[
					'label'     => esc_html__( 'Hover', 'netfx' ),
				]
			);
				$this->add_control(
					'arrows_hover_color',
					[
						'label'     => esc_html__( 'Hover Color', 'netfx' ),
						'type'      => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .jws_product_nav_slider > div:hover' => 'color: {{VALUE}};',
						],
                        'condition' => [
        					'products_layout_type' => 'slider',
        				],
					]
				);
				$this->add_control(
					'arrows_hover_bg_color',
					[
						'label'     => esc_html__( 'Background Hover Color', 'netfx' ),
						'type'      => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .jws_product_nav_slider > div:hover' => 'background-color: {{VALUE}};',
						],
                        'condition' => [
        					'products_layout_type' => 'slider',
        				],
					]
				);
			$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'heading_style_dots',
			[
				'label'     => esc_html__( 'Dots', 'netfx' ),
				'type'      => Controls_Manager::HEADING,
				'separator' => 'before',
                'condition' => [
        					'products_layout_type' => 'slider',
        		],
			]
		);

		$this->add_control(
			'dots_size',
			[
				'label'     => esc_html__( 'Size', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'min' => 5,
						'max' => 15,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .jws-woo-products-slider .slick-dots li button:before' => 'font-size: {{SIZE}}{{UNIT}};',
				],
                'condition' => [
        					'products_layout_type' => 'slider',
        		],
			]
		);

		$this->add_control(
			'dots_color',
			[
				'label'     => esc_html__( 'Color', 'netfx' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-woo-products-slider .slick-dots li button:before' => 'color: {{VALUE}};',
				],
                'condition' => [
        					'products_layout_type' => 'slider',
        		],
			]
		);

		$this->end_controls_section();
	}
    /**
	 * Get WooCommerce Product Categories.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function get_product_categories() {

		$product_cat = array();

		$cat_args = array(
			'orderby'    => 'name',
			'order'      => 'asc',
			'hide_empty' => false,
		);

		$product_categories = get_terms( 'product_cat', $cat_args );

		if ( ! empty( $product_categories ) ) {

			foreach ( $product_categories as $key => $category ) {

				$product_cat[ $category->slug ] = $category->name;
			}
		}

		return $product_cat;
	}
     /**
	 * Get WooCommerce Product Attribute.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
    protected function get_product_attr() {
        $attributes = array();
        if (class_exists('Woocommerce')) {
            $attributes_tax = wc_get_attribute_taxonomies();
        }else {
            $attributes_tax = '';
        }
        foreach ($attributes_tax as $attribute) {
            $attributes[$attribute->attribute_name] = $attribute->attribute_label;
        }
        return $attributes;
    }
    /**
	 * Get WooCommerce Product Tags.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function get_product_tags() {

		$product_tag = array();

		$tag_args = array(
			'orderby'    => 'name',
			'order'      => 'asc',
			'hide_empty' => false,
		);

		$product_tag = get_terms( 'product_tag', $tag_args );

		if ( ! empty( $product_tag ) && class_exists('Woocommerce') ) {

			foreach ( $product_tag as $key => $tag ) {

				$product_tag[ $tag->slug ] = $tag->name;
			}
		}

		return $product_tag;
	}

	protected function render() {

	$settings = $this->get_settings_for_display();
        extract( $settings );
        $encoded_atts = json_encode( $settings );

			global $post;

			$query_args = [
				'post_type'      => 'product',
				'post_status'    => 'publish',
				'posts_per_page' => -1,
				'paged'          => 1,
				'post__not_in'   => array(),
			];

			if ( 'slider' != $settings['products_layout_type'] ) {
				if ( $settings['products_per_page'] > 0 ) {
					$query_args['posts_per_page'] = $settings['products_per_page'];
				}

				if ( '' !== $settings['pagination_type'] ) {

					$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : '1';
                    if( $settings['ajax_page'] > 1 ) $paged = $settings['ajax_page'];
					if ( isset( $_POST['page_number'] ) && '' != $_POST['page_number'] ) {
						$paged = $_POST['page_number'];
					}

					$query_args['paged'] = $paged;
				}
			} else {

				if ( $settings['slider_products_per_page'] > 0 ) {
					$query_args['posts_per_page'] = $settings['slider_products_per_page'];
				}
			}
          
			// Default ordering args.
			$ordering_args = WC()->query->get_catalog_ordering_args( $settings['orderby'], $settings['order'] );
            
			$query_args['orderby'] = $ordering_args['orderby'];
			$query_args['order']   = $ordering_args['order'];

			if ( 'sale' === $settings['filter_by'] ) {

				$query_args['post__in'] = array_merge( array( 0 ), wc_get_product_ids_on_sale() );
			} elseif ( 'featured' === $settings['filter_by'] ) {

				$product_visibility_term_ids = wc_get_product_visibility_term_ids();

				$query_args['tax_query'][] = [
					'taxonomy' => 'product_visibility',
					'field'    => 'term_taxonomy_id',
					'terms'    => $product_visibility_term_ids['featured'],
				];
			}

			if ( 'custom' === $settings['query_type'] ) {

				if ( ! empty( $settings['category_filter'] ) ) {

					$cat_operator = $settings['category_filter_rule'];

					$query_args['tax_query'][] = [
						'taxonomy' => 'product_cat',
						'field'    => 'slug',
						'terms'    => $settings['category_filter'],
						'operator' => $cat_operator,
					];
				}

				if ( ! empty( $settings['tag_filter'] ) ) {

					$tag_operator = $settings['tag_filter_rule'];

					$query_args['tax_query'][] = [
						'taxonomy' => 'product_tag',
						'field'    => 'slug',
						'terms'    => $settings['tag_filter'],
						'operator' => $tag_operator,
					];
				}

				if ( 0 < $settings['offset'] ) {

					/**
					 * Offset break the pagination. Using WordPress's work around
					 *
					 * @see https://codex.wordpress.org/Making_Custom_Queries_using_Offset_and_Pagination
					 */
					$query_args['offset_to_fix'] = $settings['offset'];
				}
			}

			if ( 'manual' === $settings['query_type'] ) {

				$manual_ids = $settings['query_manual_ids'];

				$query_args['post__in'] = $manual_ids;
			}

			if ( 'manual' !== $settings['query_type'] && 'main' !== $settings['query_type'] ) {

				if ( '' !== $settings['query_exclude_ids'] ) {

					$exclude_ids = $settings['query_exclude_ids'];

					$query_args['post__not_in'] = $exclude_ids;
				}

				if ( 'yes' === $settings['query_exclude_current'] ) {

					$query_args['post__not_in'][] = $post->ID;
				}
			}

			$query_args = apply_filters( 'jws_woo_product_query_args', $query_args, $settings );

			$products = new \WP_Query( $query_args ); 
            	include( 'content.php' );
	}
    
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}
}