<?php
namespace Elementor;
use Elementor\Core\Schemes\Color;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Widget_Base;
use Elementor\Group_Control_Border;
use Elementor\Controls_Manager;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class JWS_Services extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'jws_services';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Jws Services', 'netfx' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-site-search';
	}
    /**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
    public function get_script_depends() {
		return [ 'magnificPopup' ];
	}
	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'jws-elements' ];
	}
    
	/**
	 * Register Woo post Grid controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function _register_controls() {

		/* General Tab */
        $this->register_content_general_controls();
        $this->register_content_filter_controls();
		$this->register_content_grid_controls();
        $this->register_content_slider_controls();

 
	}

    /**
	 * Register Woo posts General Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	*/
	protected function register_content_general_controls() {

    		$this->start_controls_section(
    			'section_general_field',
    			[
    				'label' => esc_html__( 'General', 'netfx' ),
    				'tab'   => Controls_Manager::TAB_CONTENT,
    			]
    		);
            $this->add_control(
				'services_display',
				[
					'label'     => esc_html__( 'Display', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'gird',
					'options'   => [
						'gird'   => esc_html__( 'Grid', 'netfx' ),
						'slider'   => esc_html__( 'Slider', 'netfx' ),
					],
                    
				]
			);
            $this->add_control(
				'services_layouts',
				[
					'label'     => esc_html__( 'Layout', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'layout1',
					'options'   => [
						'layout1'   => esc_html__( 'Layout 1', 'netfx' ),
						'layout2'   => esc_html__( 'Layout 2', 'netfx' ),
                        'layout3'   => esc_html__( 'Layout 3', 'netfx' ),
                        'layout4'   => esc_html__( 'Layout 4 (Show in single service)', 'netfx' ),
					],
                    
				]
			);
            $this->add_control(
				'excerpt_length',
				[
					'label'     => esc_html__( 'Excerpt Length', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => '',
				]
			);
             $this->add_control(
				'excerpt_more',
				[
					'label'     => esc_html__( 'Excerpt More', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => ' ... ',
				]
			);
            $this->add_control(
				'readmore_text',
				[
					'label'     => esc_html__( 'Read More Text', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => 'Reading Continue...',
				]
			);
            $this->add_control(
				'icon',
				[
					'label' => esc_html__( 'Read More Icon', 'netfx' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'fab fa-wordpress',
                		'library' => 'fa-brands',
					],
				]
		  );
          $this->add_control(
				'services_image_size',
				[
					'label'     => esc_html__( 'Image Size', 'netfx' ),
					'type'      => Controls_Manager::TEXT,
					'default'   => 'full',
				]
		  );
          
          $this->add_control(
			'ajax_page',
			[
				'label' => esc_html__( 'ajax_page', 'netfx' ),
				'type' => Controls_Manager::HIDDEN,
				'default' => '',
			]
		  );
		$this->end_controls_section();
        $this->start_controls_section(
			'box_style',
			[
				'label' => esc_html__( 'Box', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_responsive_control(
					'service_padding',
					[
						'label' 		=> esc_html__( 'Padding', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-services-element .jws_services_item .jws_services_item_inner .jws_service_content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->add_responsive_control(
					'service_radius',
					[
						'label' 		=> esc_html__( 'Border Radius', 'netfx' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', 'em', '%' ],
						'selectors' 	=> [
							'{{WRAPPER}} .jws-services-element .jws_services_item .jws_services_item_inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],

						'separator' => 'before',
					]
		);
        $this->add_responsive_control(
			'column_gap',
			[
				'label'     => esc_html__( 'Columns Gap', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .jws-services-element .jws_services_item' => 'padding-right: calc( {{SIZE}}{{UNIT}}/2 ); padding-left: calc( {{SIZE}}{{UNIT}}/2 );',
					'{{WRAPPER}} .jws-services-element .row' => 'margin-left: calc( -{{SIZE}}{{UNIT}}/2 ); margin-right: calc( -{{SIZE}}{{UNIT}}/2 );',
				],
			]
		);

		$this->add_responsive_control(
			'row_gap',
			[
				'label'     => esc_html__( 'Rows Gap', 'netfx' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .jws-services-element .jws_services_item' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .jws-services-element .row' => 'margin-bottom: -{{SIZE}}{{UNIT}};',
				],
			]
		);
        $this->end_controls_section();
        $this->start_controls_section(
			'service_style_icon',
			[
				'label' => esc_html__( 'Icon', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        $this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-services-element .jws_services_item .jws_services_item_inner .jws_service_content .service_icon' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
				'icon_size',
				[
					'label' 		=> esc_html__( 'Icon Size', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .jws_services_item .jws_services_item_inner .icon-service' => 'font-size: {{SIZE}}px;',
                        '{{WRAPPER}} .jws_services_item .jws_services_item_inner .icon-service svg' => 'width: {{SIZE}}px;',
					],
				]
		);
        $this->add_control(
				'icon_spacing',
				[
					'label' 		=> esc_html__( 'Spacing', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .jws_services_item .jws_services_item_inner .icon-service' => 'margin-bottom: {{SIZE}}px;',
					],
				]
		); 
        $this->end_controls_section();
        $this->start_controls_section(
			'box_title_style',
			[
				'label' => esc_html__( 'Title', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Title Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-services-element .jws_services_item .jws_services_item_inner .jws_service_content .jws_service_title a' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'title_color_hover',
			[
				'label' => esc_html__( 'Title Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-services-element .jws_services_layout1 .jws_services_item .jws_services_item_inner:hover .jws_service_content .jws_service_title a,
                     {{WRAPPER}} .jws-services-element > div:not(.jws_services_layout1) .jws_services_item .jws_services_item_inner .jws_service_content .jws_service_title a:hover   
                    ' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-services-element .jws_services_item .jws_services_item_inner .jws_service_content .jws_service_title a',
			]
		);
        $this->add_control(
				'title_spacing',
				[
					'label' 		=> esc_html__( 'Spacing', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .jws-services-element .jws_services_item .jws_services_item_inner .jws_service_content .jws_service_title' => 'margin-bottom: {{SIZE}}px;',
					],
				]
		); 
        $this->end_controls_section();
        $this->start_controls_section(
			'excerpt_style',
			[
				'label' => esc_html__( 'Excerpt', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'excerpt_color',
			[
				'label' => esc_html__( 'Excerpt Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-services-element .jws_services_item .jws_services_item_inner .jws_service_content .jws_services_excerpt' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'excerpt_color_hover',
			[
				'label' => esc_html__( 'Excerpt Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-services-element .jws_services_layout1 .jws_services_item .jws_services_item_inner:hover .jws_service_content .jws_services_excerpt' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'excerpt_typography',
				'label' => esc_html__( 'Typography', 'netfx' ),
				'selector' => '{{WRAPPER}} .jws-services-element .jws_services_item .jws_services_item_inner .jws_service_content .jws_services_excerpt',
			]
		);
        $this->add_control(
				'excerpt_spacing',
				[
					'label' 		=> esc_html__( 'Spacing', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .jws-services-element .jws_services_item .jws_services_item_inner .jws_service_content .jws_services_excerpt' => 'margin-bottom: {{SIZE}}px;',
					],
				]
		); 
        $this->end_controls_section();
        $this->start_controls_section(
			'readmore_style',
			[
				'label' => esc_html__( 'Read More', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'reicon_color',
			[
				'label' => esc_html__( 'Icon Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-services-element .jws_services_item .jws_services_item_inner .jws_services_readmore a' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'reicon_color_hover',
			[
				'label' => esc_html__( 'Icon Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-services-element .jws_services_layout1 .jws_services_item .jws_services_item_inner:hover .jws_service_content .jws_services_readmore a ,
                    {{WRAPPER}} .jws-services-element > div:not(.jws_services_layout1) .jws_services_item .jws_services_item_inner  .jws_services_readmore a:hover 
                    ' => 'color: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'reicon_bgcolor',
			[
				'label' => esc_html__( 'Icon background Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-services-element .jws_services_item .jws_services_item_inner .jws_services_readmore a' => 'background: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'reicon_bgcolor_hover',
			[
				'label' => esc_html__( 'Icon background Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-services-element .jws_services_layout1 .jws_services_item .jws_services_item_inner:hover .jws_service_content .jws_services_readmore a,
                     {{WRAPPER}} .jws-services-element > div:not(.jws_services_layout1) .jws_services_item .jws_services_item_inner .jws_services_readmore a:hover 
                    ' => 'background: {{VALUE}}',
				],
			]
		);
        $this->end_controls_section();
        $this->start_controls_section(

			'section_icon_style',

			[

				'label' => esc_html__( 'Icon', 'netfx' ),

				'tab' => Controls_Manager::TAB_STYLE,

			]

		);

		$this->add_control(

			'icon_color_svg',

			[

				'label' => esc_html__( 'Icon Color', 'netfx' ),

				'type' => Controls_Manager::COLOR,


				'selectors' => [

					'{{WRAPPER}} .icon-service svg' => 'fill: {{VALUE}};',

				],

			]

		);
        
		$this->add_control(

			'icon_hover_color',

			[

				'label' => esc_html__( 'Icon Hover Color', 'netfx' ),

				'type' => Controls_Manager::COLOR,

				'selectors' => [

					'{{WRAPPER}} .service-item:hover .elementor-service .icon-service svg' => 'fill: {{VALUE}};',

				],

			]

		);

         $this->add_responsive_control(
				'image_width',
				[
					'label' 		=> esc_html__( 'Logo Width', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 300,
							'step' => 1,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .icon-service img' => 'height: {{SIZE}}px',
                        '{{WRAPPER}} .icon-service svg' => 'width: {{SIZE}}px;height:{{SIZE}}px;',
                        
					],
				]
		);
		$this->end_controls_section();
        $this->start_controls_section(
			'overlay_style',
			[
				'label' => esc_html__( 'Overlay', 'netfx' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_control(
			'overlay_bgcolor',
			[
				'label' => esc_html__( 'Icon background Color', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-services-element .jws_services_layout1 .jws_services_item .jws_services_item_inner .jws_service_overlay' => 'background: {{VALUE}}',
				],
			]
		);
        $this->add_control(
			'overlay_bgcolor_hover',
			[
				'label' => esc_html__( 'Icon background Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .jws-services-element .jws_services_layout1 .jws_services_item .jws_services_item_inner:hover .jws_service_overlay' => 'background: {{VALUE}}',
				],
			]
		);
        $this->end_controls_section();
	}
    	/**
	 * Register Woo posts Filter Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_content_filter_controls() {

		$this->start_controls_section(
			'section_filter_field',
			[
				'label' => esc_html__( 'Query', 'netfx' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
				'services_per_page',
				[
					'label'     => esc_html__( 'posts Per Page', 'netfx' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => '8',
					'condition' => [
						'query_type!'  => 'main',
					],
				]
			);
		$this->add_control(
				'query_type',
				[
					'label'   => esc_html__( 'Source', 'netfx' ),
					'type'    => Controls_Manager::SELECT,
					'default' => 'all',
					'options' => [
						'all'    => esc_html__( 'All posts', 'netfx' ),
						'custom' => esc_html__( 'Custom Query', 'netfx' ),
						'manual' => esc_html__( 'Manual Selection', 'netfx' ),
					],
				]
);

			$this->add_control(
				'category_filter_rule',
				[
					'label'     => esc_html__( 'Category Filter Rule', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'IN',
					'options'   => [
						'IN'     => esc_html__( 'Match Categories', 'netfx' ),
						'NOT IN' => esc_html__( 'Exclude Categories', 'netfx' ),
					],
					'condition' => [
						'query_type' => 'custom',
					],
				]
			);
			$this->add_control(
				'category_filter',
				[
					'label'     => esc_html__( 'Select Categories', 'netfx' ),
					'type'      => Controls_Manager::SELECT2,
					'multiple'  => true,
					'default'   => '',
					'options'   => $this->get_services_categories(),
					'condition' => [
						'query_type' => 'custom',
					],
				]
			);
            
            
			$this->add_control(
				'tag_filter_rule',
				[
					'label'     => esc_html__( 'Tag Filter Rule', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'IN',
					'options'   => [
						'IN'     => esc_html__( 'Match Tags', 'netfx' ),
						'NOT IN' => esc_html__( 'Exclude Tags', 'netfx' ),
					],
					'condition' => [
						'query_type' => 'custom',
					],
				]
			);
			$this->add_control(
				'tag_filter',
				[
					'label'     => esc_html__( 'Select Tags', 'netfx' ),
					'type'      => Controls_Manager::SELECT2,
					'multiple'  => true,
					'default'   => '',
					'options'   => $this->get_services_tags(),
					'condition' => [
						'query_type' => 'custom',
					],
				]
			);
			$this->add_control(
				'offset',
				[
					'label'       => esc_html__( 'Offset', 'netfx' ),
					'type'        => Controls_Manager::NUMBER,
					'default'     => 0,
					'description' => esc_html__( 'Number of post to displace or pass over.', 'netfx' ),
					'condition'   => [
						'query_type' => 'custom',
					],
				]
			);

			$this->add_control(
				'query_manual_ids',
				[
					'label'     => esc_html__( 'Select posts', 'netfx' ),
					'type'      => 'jws-query-posts',
					'post_type' => 'services',
					'multiple'  => true,
					'condition' => [
						'query_type' => 'manual',
					],
				]
			);

			/* Exclude */
			$this->add_control(
				'query_exclude',
				[
					'label'     => esc_html__( 'Exclude', 'netfx' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'query_type!' => [ 'manual', 'main' ],
					],
				]
			);
			$this->add_control(
				'query_exclude_ids',
				[
					'label'       => esc_html__( 'Select posts', 'netfx' ),
					'type'        => 'jws-query-posts',
					'post_type'   => 'services',
					'multiple'    => true,
					'description' => esc_html__( 'Select posts to exclude from the query.', 'netfx' ),
					'condition'   => [
						'query_type!' => [ 'manual', 'main' ],
					],
				]
			);
			$this->add_control(
				'query_exclude_current',
				[
					'label'        => esc_html__( 'Exclude Current post', 'netfx' ),
					'type'         => Controls_Manager::SWITCHER,
					'label_on'     => esc_html__( 'Yes', 'netfx' ),
					'label_off'    => esc_html__( 'No', 'netfx' ),
					'return_value' => 'yes',
					'default'      => '',
					'description'  => esc_html__( 'Enable this option to remove current post from the query.', 'netfx' ),
					'condition'    => [
						'query_type!' => [ 'manual', 'main' ],
					],
				]
			);

			/* Advanced Filter */
			$this->add_control(
				'query_advanced',
				[
					'label'     => esc_html__( 'Advanced', 'netfx' ),
					'type'      => Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'query_type!' => 'main',
					],
				]
			);
			$this->add_control(
				'filter_by',
				[
					'label'     => esc_html__( 'Filter By', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => '',
					'options'   => [
						''         => esc_html__( 'None', 'netfx' ),
						'featured' => esc_html__( 'Featured', 'netfx' ),
						'sale'     => esc_html__( 'Sale', 'netfx' ),
					],
					'condition' => [
						'query_type!' => 'main',
					],
				]
			);
			$this->add_control(
				'orderby',
				[
					'label'     => esc_html__( 'Order by', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'date',
					'options'   => [
						'date'       => esc_html__( 'Date', 'netfx' ),
						'title'      => esc_html__( 'Title', 'netfx' ),
						'price'      => esc_html__( 'Price', 'netfx' ),
						'popularity' => esc_html__( 'Popularity', 'netfx' ),
						'rating'     => esc_html__( 'Rating', 'netfx' ),
						'rand'       => esc_html__( 'Random', 'netfx' ),
						'menu_order' => esc_html__( 'Menu Order', 'netfx' ),
					],
					'condition' => [
						'query_type!' => 'main',
					],
				]
			);
			$this->add_control(
				'order',
				[
					'label'     => esc_html__( 'Order', 'netfx' ),
					'type'      => Controls_Manager::SELECT,
					'default'   => 'desc',
					'options'   => [
						'desc' => esc_html__( 'Descending', 'netfx' ),
						'asc'  => esc_html__( 'Ascending', 'netfx' ),
					],
					'condition' => [
						'query_type!' => 'main',
					],
				]
			);

		$this->end_controls_section();
	}
    
   
	/**
	 * Register grid Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_content_grid_controls() {
		$this->start_controls_section(
			'section_grid_options',
			[
				'label'     => esc_html__( 'Grid Options', 'netfx' ),
				'type'      => Controls_Manager::SECTION,
			]
		);
		$this->add_responsive_control(
				'services_columns',
				[
					'label'          => esc_html__( 'Columns', 'netfx' ),
					'type'           => Controls_Manager::SELECT,
					'default'        => '12',
					'options'        => [
						'12' => '1',
						'6' => '2',
						'4' => '3',
						'3' => '4',
						'20' => '5',
						'2' => '6',
					],
				]
			);
		$this->end_controls_section();
	}
    
    
        /**
	 * Register Slider Controls.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function register_content_slider_controls() {
		$this->start_controls_section(
			'section_slider_options',
			[
				'label'     => esc_html__( 'Slider Options', 'netfx' ),
				'type'      => Controls_Manager::SECTION,
				'condition' => [
					'services_display' => ['slider'],
				],
			]
		);

		$this->add_control(
			'navigation',
			[
				'label'     => esc_html__( 'Navigation', 'netfx' ),
				'type'      => Controls_Manager::SELECT,
				'default'   => 'both',
				'options'   => [
                    'both' => esc_html__( 'Arrows And Dots', 'netfx' ),
					'arrows' => esc_html__( 'Arrows', 'netfx' ),
                    'dots' => esc_html__( 'Dots', 'netfx' ),
					'none'   => esc_html__( 'None', 'netfx' ),
				],
			]
		);

		$this->add_responsive_control(
			'slides_to_show',
			[
				'label'          => esc_html__( 'posts to Show', 'netfx' ),
				'type'           => Controls_Manager::NUMBER,
				'default'        => 1,
				'tablet_default' => 1,
				'mobile_default' => 1,
			]
		);

		$this->add_responsive_control(
			'slides_to_scroll',
			[
				'label'          => esc_html__( 'posts to Scroll', 'netfx' ),
				'type'           => Controls_Manager::NUMBER,
				'default'        => 1,
				'tablet_default' => 1,
				'mobile_default' => 1,
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'        => esc_html__( 'Autoplay', 'netfx' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => '',
			]
		);
		$this->add_control(
			'autoplay_speed',
			[
				'label'     => esc_html__( 'Autoplay Speed', 'netfx' ),
				'type'      => Controls_Manager::NUMBER,
				'default'   => 5000,
				'selectors' => [
					'{{WRAPPER}} .slick-slide-bg' => 'animation-duration: calc({{VALUE}}ms*1.2); transition-duration: calc({{VALUE}}ms)',
				],
				'condition' => [
					'autoplay'             => 'yes',
				],
			]
		);
		$this->add_control(
			'pause_on_hover',
			[
				'label'        => esc_html__( 'Pause on Hover', 'netfx' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition'    => [
					'autoplay'             => 'yes',
				],
			]
		);

		$this->add_control(
			'infinite',
			[
				'label'        => esc_html__( 'Infinite Loop', 'netfx' ),
				'type'         => Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default'      => 'yes',
			]
		);

		$this->add_control(
			'transition_speed',
			[
				'label'     => esc_html__( 'Transition Speed (ms)', 'netfx' ),
				'type'      => Controls_Manager::NUMBER,
				'default'   => 500,
			]
		);
		$this->end_controls_section();
	}
    

    /**
	 * Get WooCommerce post Categories.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function get_services_categories() {

		$services_cat = array();

		$cat_args = array(
			'orderby'    => 'name',
			'order'      => 'asc',
			'hide_empty' => false,
		);

		$services_categories = get_terms( 'services_cat', $cat_args );
        
 

		if ( ! empty( $services_categories ) && !isset($services_categories->errors) ) {

			foreach ( $services_categories as $key => $category ) {

				$services_cat[ $category->slug ] = $category->name;
			}
		}

		return $services_cat;
	}
    /**
	 * Get WooCommerce post Tags.
	 *
	 * @since 0.0.1
	 * @access protected
	 */
	protected function get_services_tags() {

		$services_tag = array();

		$tag_args = array(
			'orderby'    => 'name',
			'order'      => 'asc',
			'hide_empty' => false,
		);

		$services_tag = get_terms( 'services_tag', $tag_args );

		if ( ! empty( $services_tag ) && !isset($services_tag->errors) ) {

			foreach ( $services_tag as $key => $tag ) {

				$services_tag[ $tag->slug ] = $tag->name;
			}
		}

		return $services_tag;
	}
	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings();
        extract( $settings );
        $encoded_atts = json_encode( $settings );

			global $post;

			$query_args = [
				'post_type'      => 'services',
				'post_status'    => 'publish',
				'posts_per_page' => -1,
				'paged'          => 1,
				'post__not_in'   => array(),
			];

		    if ( $settings['services_per_page'] > 0 ) {
					$query_args['posts_per_page'] = $settings['services_per_page'];
			}
			$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : '1';
			// Default ordering args.
			$ordering_args = WC()->query->get_catalog_ordering_args( $settings['orderby'], $settings['order'] );

			$query_args['orderby'] = $ordering_args['orderby'];
			$query_args['order']   = $ordering_args['order'];


			if ( 'custom' === $settings['query_type'] ) {

				if ( ! empty( $settings['category_filter'] ) ) {

					$cat_operator = $settings['category_filter_rule'];

					$query_args['tax_query'][] = [
						'taxonomy' => 'services_cat',
						'field'    => 'slug',
						'terms'    => $settings['category_filter'],
						'operator' => $cat_operator,
					];
				}

				if ( ! empty( $settings['tag_filter'] ) ) {

					$tag_operator = $settings['tag_filter_rule'];

					$query_args['tax_query'][] = [
						'taxonomy' => 'services_tag',
						'field'    => 'slug',
						'terms'    => $settings['tag_filter'],
						'operator' => $tag_operator,
					];
				}

				if ( 0 < $settings['offset'] ) {

					/**
					 * Offset break the pagination. Using WordPress's work around
					 *
					 * @see https://codex.wordpress.org/Making_Custom_Queries_using_Offset_and_Pagination
					 */
					$query_args['offset_to_fix'] = $settings['offset'];
				}
			}

			if ( 'manual' === $settings['query_type'] ) {

				$manual_ids = $settings['query_manual_ids'];

				$query_args['post__in'] = $manual_ids;
			}

			if ( 'manual' !== $settings['query_type'] && 'main' !== $settings['query_type'] ) {

				if ( '' !== $settings['query_exclude_ids'] ) {

					$exclude_ids = $settings['query_exclude_ids'];

					$query_args['post__not_in'] = $exclude_ids;
				}

				if ( 'yes' === $settings['query_exclude_current'] ) {

					$query_args['post__not_in'][] = $post->ID;
				}
			}

			$query_args = apply_filters( 'jws_services_query_args', $query_args, $settings );

			$services = new \WP_Query( $query_args );
            
            
            
      $class_row = 'row';  
      $class_row .= ' jws_services_'.$settings['services_layouts'].'';
      
      $class_column = 'jws_services_item';
      $class_column .= ' col-xl-'.$settings['services_columns'].'';
      $class_column .= (!empty($settings['services_columns_tablet'])) ? ' col-lg-'.$settings['services_columns_tablet'].'' : ' col-lg-'.$settings['services_columns'].'' ;
       $class_column .= (!empty($settings['services_columns_tablet'])) ? ' col-md-'.$settings['services_columns_tablet'].'' : ' col-md-'.$settings['services_columns'].'' ;
      $class_column .= (!empty($settings['services_columns_mobile'])) ? ' col-'.$settings['services_columns_mobile'].'' :  ' col-'.$settings['services_columns'].'';
      
      if($settings['services_display'] == 'slider') {
            $class_row .= ' jws_services_'.$settings['services_display'].'';
            $class_column .= ' slick-slide';
            $dots = ($settings['navigation'] == 'dots' || $settings['navigation'] == 'both') ? 'true' : 'false';
            $arrows = ($settings['navigation'] == 'arrows' || $settings['navigation'] == 'both') ? 'true' : 'false';
            $autoplay = ($settings['autoplay'] == 'yes') ? 'true' : 'false';
            $pause_on_hover = ($settings['pause_on_hover'] == 'yes') ? 'true' : 'false';
            $infinite = ($settings['infinite'] == 'yes') ? 'true' : 'false';
            $autoplay_speed = ($settings['autoplay_speed']) ? $settings['autoplay_speed'] : '0';
            $data_slick = 'data-slick=\'{"slidesToShow":'.$settings['slides_to_show'].' ,"slidesToScroll": '.$settings['slides_to_scroll'].', "autoplay": '.$autoplay.',"arrows": '.$arrows.', "dots":'.$dots.', "autoplaySpeed": '.$autoplay_speed.',"pauseOnHover":'.$pause_on_hover.',"nfinite":'.$infinite.',
            "speed": '.$settings['transition_speed'].', "responsive":[{"breakpoint": 1024,"settings":{"slidesToShow": '.$settings['slides_to_show_tablet'].',"slidesToScroll": '.$settings['slides_to_scroll_tablet'].'}},
            {"breakpoint": 768,"settings":{"slidesToShow": '.$settings['slides_to_show_mobile'].',"slidesToScroll": '.$settings['slides_to_scroll_mobile'].'}}]}\''; 
       }else {
            $data_slick = '';
       }
      ?>
 
		
		<div class="jws-services-element">
            <div class="<?php echo esc_attr($class_row); ?>" <?php echo wp_kses_post( $data_slick); ?>>
                <?php 
                           	
                    $i = 1;
                    if ($services->have_posts()) :
                        while ( $services->have_posts() ) :
                    			$services->the_post();
                                ?>
                                    <div class="<?php echo esc_attr($class_column) ?> <?php if(($i == 2 && $settings['services_layouts']=="layout3") ||($i == 2 && $settings['services_layouts']=='layout-service3')) echo 'active';?>" >

                                            <?php
                                           include( 'layout/'.$settings['services_layouts'].'.php' );
                                            ?>
        
                                    </div>
                                    <?php
                                     $i++;
                        endwhile;    
                    endif;
                
                	wp_reset_postdata();
                   
                ?>
            </div>
        </div>

	<?php }
    
	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}
}